@@ -652,6 +652,9 @@ public final class ActiveMQDefaultConfiguration {
    // Whether or not to report JVM thread metrics
    private static final boolean DEFAULT_JVM_THREAD_METRICS = false;
 
+   // Whether or not to report executor service metrics
+   private static final boolean DEFAULT_EXECUTOR_SERVICE_METRICS = false;
+
    public static final String DEFAULT_UUID_NAMESPACE = "";
 
    @Deprecated(forRemoval = true)
@@ -717,10 +720,10 @@ public final class ActiveMQDefaultConfiguration {
    private static final boolean DEFAULT_MIRROR_ACK_MANAGER_WARN_UNACKED = false;
    private static final boolean DEFAULT_MIRROR_PAGE_TRANSACTION = false;
 
+   private static final boolean DEFAULT_PURGE_PAGE_FOLDERS = false;
 
    private static final int DEFAULT_CLUSTER_TOPOLOGY_SCANNER_ATTEMPTS = 30;
 
-
    /**
     * If {@code true} then the ActiveMQ Artemis Server will make use of any Protocol Managers that are in available on
     * the classpath. If false then only the core protocol will be available, unless in Embedded mode where users can
@@ -1879,6 +1882,10 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_JVM_THREAD_METRICS;
    }
 
+   public static boolean getDefaultExecutorServiceMetrics() {
+      return DEFAULT_EXECUTOR_SERVICE_METRICS;
+   }
+
    public static String getDefaultUuidNamespace() {
       return DEFAULT_UUID_NAMESPACE;
    }
@@ -2013,6 +2020,10 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_MIRROR_PAGE_TRANSACTION;
    }
 
+   public static boolean getPurgePageFolders() {
+      return DEFAULT_PURGE_PAGE_FOLDERS;
+   }
+
    /**
     * the initial size of the intermediate message buffer used for queues
     */
