@@ -16,6 +16,8 @@
  */
 package org.apache.activemq.artemis.core.protocol.core.impl;
 
+import java.util.Objects;
+
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.Unpooled;
 import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
@@ -399,8 +401,8 @@ public class PacketImpl implements Packet {
       buffer.readerIndex(PACKET_HEADERS_SIZE);
 
       newNettyBuffer.writeBytes(buffer, buffer.readableBytes() - skipBytes);
-      buffer.setIndex( read, writ );
-      newNettyBuffer.setIndex( 0, writ - PACKET_HEADERS_SIZE - skipBytes);
+      buffer.setIndex(read, writ);
+      newNettyBuffer.setIndex(0, writ - PACKET_HEADERS_SIZE - skipBytes);
 
       return newNettyBuffer;
    }
@@ -435,7 +437,9 @@ public class PacketImpl implements Packet {
       return true;
    }
 
-   /** extensions of this class are supposed to use getPacketString to provide toString functionality */
+   /**
+    * extensions of this class are supposed to use getPacketString to provide toString functionality
+    */
    @Override
    public final String toString() {
       return getPacketString() + "]";
@@ -447,25 +451,21 @@ public class PacketImpl implements Packet {
 
    @Override
    public int hashCode() {
-      final int prime = 31;
-      int result = 1;
-      result = prime * result + (int) (channelID ^ (channelID >>> 32));
-      result = prime * result + size;
-      result = prime * result + type;
-      return result;
+      return Objects.hash(channelID, size, type);
    }
 
-
    @Override
    public boolean equals(Object obj) {
       if (this == obj) {
          return true;
       }
-      if (!(obj instanceof PacketImpl)) {
+      if (!(obj instanceof PacketImpl other)) {
          return false;
       }
-      PacketImpl other = (PacketImpl) obj;
-      return (channelID == other.channelID) && (size == other.size) && (type != other.type);
+
+      return channelID == other.channelID &&
+             size == other.size &&
+             type != other.type;
    }
 
    private int stringEncodeSize(final String str) {
