@@ -16,6 +16,8 @@
  */
 package org.apache.activemq.artemis.core.remoting.impl.netty;
 
+import static org.apache.activemq.artemis.core.remoting.impl.netty.TransportConstants.NETTY_HTTP_HEADER_PREFIX;
+
 import javax.net.ssl.SNIHostName;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLEngine;
@@ -123,6 +125,7 @@ import org.apache.activemq.artemis.spi.core.remoting.ssl.SSLContextFactoryProvid
 import org.apache.activemq.artemis.utils.ConfigurationHelper;
 import org.apache.activemq.artemis.utils.FutureLatch;
 import org.apache.activemq.artemis.utils.IPV6Util;
+import org.apache.activemq.artemis.utils.PasswordMaskingUtil;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import java.lang.invoke.MethodHandles;
@@ -153,6 +156,7 @@ public class NettyConnector extends AbstractConnector {
    public static final String ACTIVEMQ_TRUSTSTORE_TYPE_PROP_NAME = "org.apache.activemq.ssl.trustStoreType";
    public static final String ACTIVEMQ_TRUSTSTORE_PATH_PROP_NAME = "org.apache.activemq.ssl.trustStore";
    public static final String ACTIVEMQ_TRUSTSTORE_PASSWORD_PROP_NAME = "org.apache.activemq.ssl.trustStorePassword";
+   public static final String ACTIVEMQ_SSL_PASSWORD_CODEC_CLASS_PROP_NAME = "org.apache.activemq.ssl.passwordCodec";
 
    // Constants for HTTP upgrade
    // These constants are exposed publicly as they are used on the server-side to fetch
@@ -168,8 +172,10 @@ public class NettyConnector extends AbstractConnector {
    public static final Map<String, Object> DEFAULT_CONFIG;
 
    static {
-      // Disable resource leak detection for performance reasons by default
-      ResourceLeakDetector.setLevel(Level.DISABLED);
+      // Disable default Netty leak detection if the Netty leak detection level system properties are not in use
+      if (System.getProperty("io.netty.leakDetectionLevel") == null && System.getProperty("io.netty.leakDetection.level") == null) {
+         ResourceLeakDetector.setLevel(Level.DISABLED);
+      }
 
       // Set default Configuration
       Map<String, Object> config = new HashMap<>();
@@ -178,7 +184,6 @@ public class NettyConnector extends AbstractConnector {
       DEFAULT_CONFIG = Collections.unmodifiableMap(config);
    }
 
-
    private final boolean serverConnection;
 
    private Class<? extends Channel> channelClazz;
@@ -206,19 +211,19 @@ public class NettyConnector extends AbstractConnector {
    // will be handled by the server's http server.
    private boolean httpUpgradeEnabled;
 
-   private boolean proxyEnabled;
+   private boolean socksEnabled;
 
-   private String proxyHost;
+   private String socksHost;
 
-   private int proxyPort;
+   private int socksPort;
 
-   private SocksVersion proxyVersion;
+   private SocksVersion socksVersion;
 
-   private String proxyUsername;
+   private String socksUsername;
 
-   private String proxyPassword;
+   private String socksPassword;
 
-   private boolean proxyRemoteDNS;
+   private boolean socksRemoteDNS;
 
    private boolean useServlet;
 
@@ -230,6 +235,8 @@ public class NettyConnector extends AbstractConnector {
 
    private int localPort;
 
+   private String passwordCodecClass;
+
    private String keyStoreProvider;
 
    private String keyStoreType;
@@ -306,6 +313,8 @@ public class NettyConnector extends AbstractConnector {
 
    private final ClientProtocolManager protocolManager;
 
+   private final Map<String, String> httpHeaders;
+
    public NettyConnector(final Map<String, Object> configuration,
                          final BufferHandler handler,
                          final BaseConnectionLifeCycleListener<?> listener,
@@ -324,6 +333,7 @@ public class NettyConnector extends AbstractConnector {
                          final ClientProtocolManager protocolManager) {
       this(configuration, handler, listener, closeExecutor, threadPool, scheduledThreadPool, protocolManager, false);
    }
+
    public NettyConnector(final Map<String, Object> configuration,
                          final BufferHandler handler,
                          final BaseConnectionLifeCycleListener<?> listener,
@@ -357,26 +367,33 @@ public class NettyConnector extends AbstractConnector {
          httpMaxClientIdleTime = ConfigurationHelper.getLongProperty(TransportConstants.HTTP_CLIENT_IDLE_PROP_NAME, TransportConstants.DEFAULT_HTTP_CLIENT_IDLE_TIME, configuration);
          httpClientIdleScanPeriod = ConfigurationHelper.getLongProperty(TransportConstants.HTTP_CLIENT_IDLE_SCAN_PERIOD, TransportConstants.DEFAULT_HTTP_CLIENT_SCAN_PERIOD, configuration);
          httpRequiresSessionId = ConfigurationHelper.getBooleanProperty(TransportConstants.HTTP_REQUIRES_SESSION_ID, TransportConstants.DEFAULT_HTTP_REQUIRES_SESSION_ID, configuration);
+         httpHeaders = new HashMap<>();
+         for (Map.Entry<String, Object> header : configuration.entrySet()) {
+            if (header.getKey().startsWith(NETTY_HTTP_HEADER_PREFIX)) {
+               httpHeaders.put(header.getKey().substring(NETTY_HTTP_HEADER_PREFIX.length()), header.getValue().toString());
+            }
+         }
       } else {
          httpMaxClientIdleTime = 0;
          httpClientIdleScanPeriod = -1;
          httpRequiresSessionId = false;
+         httpHeaders = Collections.emptyMap();
       }
 
       httpUpgradeEnabled = ConfigurationHelper.getBooleanProperty(TransportConstants.HTTP_UPGRADE_ENABLED_PROP_NAME, TransportConstants.DEFAULT_HTTP_UPGRADE_ENABLED, configuration);
 
-      proxyEnabled = ConfigurationHelper.getBooleanProperty(TransportConstants.PROXY_ENABLED_PROP_NAME, TransportConstants.DEFAULT_PROXY_ENABLED, configuration);
-      if (proxyEnabled) {
-         proxyHost = ConfigurationHelper.getStringProperty(TransportConstants.PROXY_HOST_PROP_NAME, TransportConstants.DEFAULT_PROXY_HOST, configuration);
-         proxyPort = ConfigurationHelper.getIntProperty(TransportConstants.PROXY_PORT_PROP_NAME, TransportConstants.DEFAULT_PROXY_PORT, configuration);
+      socksEnabled = ConfigurationHelper.getBooleanProperty(TransportConstants.SOCKS_ENABLED_PROP_NAME, TransportConstants.DEFAULT_SOCKS_ENABLED, configuration);
+      if (socksEnabled) {
+         socksHost = ConfigurationHelper.getStringProperty(TransportConstants.SOCKS_HOST_PROP_NAME, TransportConstants.DEFAULT_SOCKS_HOST, configuration);
+         socksPort = ConfigurationHelper.getIntProperty(TransportConstants.SOCKS_PORT_PROP_NAME, TransportConstants.DEFAULT_SOCKS_PORT, configuration);
 
-         int socksVersionNumber = ConfigurationHelper.getIntProperty(TransportConstants.PROXY_VERSION_PROP_NAME, TransportConstants.DEFAULT_PROXY_VERSION, configuration);
-         proxyVersion = SocksVersion.valueOf((byte) socksVersionNumber);
+         int socksVersionNumber = ConfigurationHelper.getIntProperty(TransportConstants.SOCKS_VERSION_PROP_NAME, TransportConstants.DEFAULT_SOCKS_VERSION, configuration);
+         socksVersion = SocksVersion.valueOf((byte) socksVersionNumber);
 
-         proxyUsername = ConfigurationHelper.getStringProperty(TransportConstants.PROXY_USERNAME_PROP_NAME, TransportConstants.DEFAULT_PROXY_USERNAME, configuration);
-         proxyPassword = ConfigurationHelper.getStringProperty(TransportConstants.PROXY_PASSWORD_PROP_NAME, TransportConstants.DEFAULT_PROXY_PASSWORD, configuration);
+         socksUsername = ConfigurationHelper.getStringProperty(TransportConstants.SOCKS_USERNAME_PROP_NAME, TransportConstants.DEFAULT_SOCKS_USERNAME, configuration);
+         socksPassword = ConfigurationHelper.getStringProperty(TransportConstants.SOCKS_PASSWORD_PROP_NAME, TransportConstants.DEFAULT_SOCKS_PASSWORD, configuration);
 
-         proxyRemoteDNS = ConfigurationHelper.getBooleanProperty(TransportConstants.PROXY_REMOTE_DNS_PROP_NAME, TransportConstants.DEFAULT_PROXY_REMOTE_DNS, configuration);
+         socksRemoteDNS = ConfigurationHelper.getBooleanProperty(TransportConstants.SOCKS_REMOTE_DNS_PROP_NAME, TransportConstants.SOCKS_PROXY_REMOTE_DNS, configuration);
       }
 
       remotingThreads = ConfigurationHelper.getIntProperty(TransportConstants.NIO_REMOTING_THREADS_PROPNAME, -1, configuration);
@@ -395,6 +412,8 @@ public class NettyConnector extends AbstractConnector {
 
       localPort = ConfigurationHelper.getIntProperty(TransportConstants.LOCAL_PORT_PROP_NAME, TransportConstants.DEFAULT_LOCAL_PORT, configuration);
       if (sslEnabled) {
+         passwordCodecClass = ConfigurationHelper.getStringProperty(ActiveMQDefaultConfiguration.getPropPasswordCodec(), TransportConstants.DEFAULT_PASSWORD_CODEC_CLASS, configuration);
+
          keyStoreProvider = ConfigurationHelper.getStringProperty(TransportConstants.KEYSTORE_PROVIDER_PROP_NAME, TransportConstants.DEFAULT_KEYSTORE_PROVIDER, configuration);
 
          keyStoreType = ConfigurationHelper.getStringProperty(TransportConstants.KEYSTORE_TYPE_PROP_NAME, TransportConstants.DEFAULT_KEYSTORE_TYPE, configuration);
@@ -438,6 +457,7 @@ public class NettyConnector extends AbstractConnector {
          keyStorePath = TransportConstants.DEFAULT_KEYSTORE_PATH;
          keyStorePassword = TransportConstants.DEFAULT_KEYSTORE_PASSWORD;
          keyStoreAlias = TransportConstants.DEFAULT_KEYSTORE_ALIAS;
+         passwordCodecClass = TransportConstants.DEFAULT_PASSWORD_CODEC_CLASS;
          trustStoreProvider = TransportConstants.DEFAULT_TRUSTSTORE_PROVIDER;
          trustStoreType = TransportConstants.DEFAULT_TRUSTSTORE_TYPE;
          trustStorePath = TransportConstants.DEFAULT_TRUSTSTORE_PATH;
@@ -592,8 +612,14 @@ public class NettyConnector extends AbstractConnector {
             realTrustStoreType = trustStoreType;
             realTrustStorePassword = trustStorePassword;
          } else {
+            String tempPasswordCodecClass = Stream.of(System.getProperty(ACTIVEMQ_SSL_PASSWORD_CODEC_CLASS_PROP_NAME), passwordCodecClass).map(v -> useDefaultSslContext ? passwordCodecClass : v).filter(Objects::nonNull).findFirst().orElse(null);
+
             realKeyStorePath = Stream.of(System.getProperty(ACTIVEMQ_KEYSTORE_PATH_PROP_NAME), System.getProperty(JAVAX_KEYSTORE_PATH_PROP_NAME), keyStorePath).map(v -> useDefaultSslContext ? keyStorePath : v).filter(Objects::nonNull).findFirst().orElse(null);
-            realKeyStorePassword = Stream.of(System.getProperty(ACTIVEMQ_KEYSTORE_PASSWORD_PROP_NAME), System.getProperty(JAVAX_KEYSTORE_PASSWORD_PROP_NAME), keyStorePassword).map(v -> useDefaultSslContext ? keyStorePassword : v).filter(Objects::nonNull).findFirst().orElse(null);
+            String tempKeyStorePassword = Stream.of(System.getProperty(ACTIVEMQ_KEYSTORE_PASSWORD_PROP_NAME), System.getProperty(JAVAX_KEYSTORE_PASSWORD_PROP_NAME), keyStorePassword).map(v -> useDefaultSslContext ? keyStorePassword : v).filter(Objects::nonNull).findFirst().orElse(null);
+            if (tempKeyStorePassword != null && !tempKeyStorePassword.equals(keyStorePassword)) {
+               tempKeyStorePassword = processSslPasswordProperty(tempKeyStorePassword, tempPasswordCodecClass);
+            }
+            realKeyStorePassword = tempKeyStorePassword;
             realKeyStoreAlias = keyStoreAlias;
 
             Pair<String, String> keyStoreCompat = SSLSupport.getValidProviderAndType(Stream.of(System.getProperty(ACTIVEMQ_KEYSTORE_PROVIDER_PROP_NAME), System.getProperty(JAVAX_KEYSTORE_PROVIDER_PROP_NAME), keyStoreProvider).map(v -> useDefaultSslContext ? keyStoreProvider : v).filter(Objects::nonNull).findFirst().orElse(null),
@@ -602,7 +628,11 @@ public class NettyConnector extends AbstractConnector {
             realKeyStoreType = keyStoreCompat.getB();
 
             realTrustStorePath = Stream.of(System.getProperty(ACTIVEMQ_TRUSTSTORE_PATH_PROP_NAME), System.getProperty(JAVAX_TRUSTSTORE_PATH_PROP_NAME), trustStorePath).map(v -> useDefaultSslContext ? trustStorePath : v).filter(Objects::nonNull).findFirst().orElse(null);
-            realTrustStorePassword = Stream.of(System.getProperty(ACTIVEMQ_TRUSTSTORE_PASSWORD_PROP_NAME), System.getProperty(JAVAX_TRUSTSTORE_PASSWORD_PROP_NAME), trustStorePassword).map(v -> useDefaultSslContext ? trustStorePassword : v).filter(Objects::nonNull).findFirst().orElse(null);
+            String tempTrustStorePassword = Stream.of(System.getProperty(ACTIVEMQ_TRUSTSTORE_PASSWORD_PROP_NAME), System.getProperty(JAVAX_TRUSTSTORE_PASSWORD_PROP_NAME), trustStorePassword).map(v -> useDefaultSslContext ? trustStorePassword : v).filter(Objects::nonNull).findFirst().orElse(null);
+            if (tempTrustStorePassword != null && !tempTrustStorePassword.equals(trustStorePassword)) {
+               tempTrustStorePassword = processSslPasswordProperty(tempTrustStorePassword, tempPasswordCodecClass);
+            }
+            realTrustStorePassword = tempTrustStorePassword;
 
             Pair<String, String> trustStoreCompat = SSLSupport.getValidProviderAndType(Stream.of(System.getProperty(ACTIVEMQ_TRUSTSTORE_PROVIDER_PROP_NAME), System.getProperty(JAVAX_TRUSTSTORE_PROVIDER_PROP_NAME), trustStoreProvider).map(v -> useDefaultSslContext ? trustStoreProvider : v).filter(Objects::nonNull).findFirst().orElse(null),
                                                                                        Stream.of(System.getProperty(ACTIVEMQ_TRUSTSTORE_TYPE_PROP_NAME), System.getProperty(JAVAX_TRUSTSTORE_TYPE_PROP_NAME), trustStoreType).map(v -> useDefaultSslContext ? trustStoreType : v).filter(Objects::nonNull).findFirst().orElse(null));
@@ -621,30 +651,24 @@ public class NettyConnector extends AbstractConnector {
          realTrustStorePassword = null;
       }
 
-      bootstrap.handler(new ChannelInitializer<Channel>() {
+      bootstrap.handler(new ChannelInitializer<>() {
          @Override
          public void initChannel(Channel channel) throws Exception {
             final ChannelPipeline pipeline = channel.pipeline();
 
-            if (proxyEnabled && (proxyRemoteDNS || !isTargetLocalHost())) {
-               InetSocketAddress proxyAddress = new InetSocketAddress(proxyHost, proxyPort);
-               ProxyHandler proxyHandler;
-               switch (proxyVersion) {
-                  case SOCKS5:
-                     proxyHandler = new Socks5ProxyHandler(proxyAddress, proxyUsername, proxyPassword);
-                     break;
-                  case SOCKS4a:
-                     proxyHandler = new Socks4ProxyHandler(proxyAddress, proxyUsername);
-                     break;
-                  default:
-                     throw new IllegalArgumentException("Unknown SOCKS proxy version");
-               }
+            if (socksEnabled && (socksRemoteDNS || !isTargetLocalHost())) {
+               InetSocketAddress proxyAddress = new InetSocketAddress(socksHost, socksPort);
+               ProxyHandler proxyHandler = switch (socksVersion) {
+                  case SOCKS5 -> new Socks5ProxyHandler(proxyAddress, socksUsername, socksPassword);
+                  case SOCKS4a -> new Socks4ProxyHandler(proxyAddress, socksUsername);
+                  default -> throw new IllegalArgumentException("Unknown SOCKS proxy version");
+               };
 
                channel.pipeline().addLast(proxyHandler);
 
-               logger.debug("Using a SOCKS proxy at {}:{}", proxyHost, proxyPort);
+               logger.debug("Using a SOCKS proxy at {}:{}", socksHost, socksPort);
 
-               if (proxyRemoteDNS) {
+               if (socksRemoteDNS) {
                   bootstrap.resolver(NoopAddressResolverGroup.INSTANCE);
                }
             }
@@ -726,7 +750,7 @@ public class NettyConnector extends AbstractConnector {
 
                pipeline.addLast(new HttpObjectAggregator(Integer.MAX_VALUE));
 
-               pipeline.addLast(new HttpHandler());
+               pipeline.addLast(new HttpHandler(httpHeaders));
             }
 
             if (httpUpgradeEnabled) {
@@ -755,6 +779,15 @@ public class NettyConnector extends AbstractConnector {
       logger.debug("Started {} Netty Connector version {} to {}:{}", connectorType, TransportConstants.NETTY_VERSION, host, port);
    }
 
+   private String processSslPasswordProperty(String password, String codecClass) {
+      try {
+         return PasswordMaskingUtil.resolveMask(password, codecClass);
+      } catch (Exception e) {
+         ActiveMQClientLogger.LOGGER.errorCreatingNettyConnection(e);
+         throw new RuntimeException(e);
+      }
+   }
+
    private SSLEngine loadJdkSslEngine(final SSLContextConfig sslContextConfig) throws Exception {
       final SSLContext context = SSLContextFactoryProvider.getSSLContextFactory()
          .getSSLContext(sslContextConfig, configuration);
@@ -806,7 +839,7 @@ public class NettyConnector extends AbstractConnector {
       channelClazz = null;
 
       for (Connection connection : connections.values()) {
-         listener.connectionDestroyed(connection.getID());
+         listener.connectionDestroyed(connection.getID(), false);
       }
 
       connections.clear();
@@ -825,8 +858,9 @@ public class NettyConnector extends AbstractConnector {
    /**
     * Create and return a connection from this connector.
     * <p>
-    * This method must NOT throw an exception if it fails to create the connection
-    * (e.g. network is not available), in this case it MUST return null.<br>
+    * This method must NOT throw an exception if it fails to create the connection (e.g. network is not available), in
+    * this case it MUST return null.
+    * <p>
     * This version can be used for testing purposes.
     *
     * @param onConnect a callback that would be called right after {@link Bootstrap#connect()}
@@ -842,7 +876,7 @@ public class NettyConnector extends AbstractConnector {
 
    public NettyConnection createConnection(Consumer<ChannelFuture> onConnect, String host, int port) {
       InetSocketAddress remoteDestination;
-      if (proxyEnabled && proxyRemoteDNS) {
+      if (socksEnabled && socksRemoteDNS) {
          remoteDestination = InetSocketAddress.createUnresolved(IPV6Util.stripBracketsAndZoneID(host), port);
       } else {
          remoteDestination = new InetSocketAddress(IPV6Util.stripBracketsAndZoneID(host), port);
@@ -1016,10 +1050,9 @@ public class NettyConnector extends AbstractConnector {
       public void channelRead0(ChannelHandlerContext ctx, HttpObject msg) throws Exception {
          logger.debug("Received msg={}", msg);
 
-         if (msg instanceof HttpResponse) {
-            HttpResponse response = (HttpResponse) msg;
-            if (response.status().code() == HttpResponseStatus.SWITCHING_PROTOCOLS.code() && response.headers().get(HttpHeaderNames.UPGRADE).equals(ACTIVEMQ_REMOTING)) {
-               String accept = response.headers().get(SEC_ACTIVEMQ_REMOTING_ACCEPT);
+         if (msg instanceof HttpResponse httpResponse) {
+            if (httpResponse.status().code() == HttpResponseStatus.SWITCHING_PROTOCOLS.code() && httpResponse.headers().get(HttpHeaderNames.UPGRADE).equals(ACTIVEMQ_REMOTING)) {
+               String accept = httpResponse.headers().get(SEC_ACTIVEMQ_REMOTING_ACCEPT);
                String expectedResponse = createExpectedResponse(MAGIC_NUMBER, ctx.channel().attr(REMOTING_KEY).get());
 
                if (expectedResponse.equals(accept)) {
@@ -1065,7 +1098,7 @@ public class NettyConnector extends AbstractConnector {
       }
    }
 
-   class HttpHandler extends ChannelDuplexHandler {
+   public class HttpHandler extends ChannelDuplexHandler {
 
       private Channel channel;
 
@@ -1084,9 +1117,15 @@ public class NettyConnector extends AbstractConnector {
       private boolean handshaking = false;
 
       private String cookie;
+      private Map<String, String> headers;
 
-      HttpHandler() throws Exception {
+      HttpHandler(Map<String, String> headers) throws Exception {
          url = new URI("http", null, host, port, servletPath, null, null).toString();
+         this.headers = headers;
+      }
+
+      public Map<String, String> getHeaders() {
+         return headers;
       }
 
       @Override
@@ -1130,7 +1169,7 @@ public class NettyConnector extends AbstractConnector {
 
       @Override
       public void write(final ChannelHandlerContext ctx, final Object msg, ChannelPromise promise) throws Exception {
-         if (msg instanceof ByteBuf) {
+         if (msg instanceof ByteBuf buf) {
             if (httpRequiresSessionId && !active) {
                if (handshaking) {
                   handshaking = true;
@@ -1140,10 +1179,11 @@ public class NettyConnector extends AbstractConnector {
                   }
                }
             }
-
-            ByteBuf buf = (ByteBuf) msg;
             FullHttpRequest httpRequest = new DefaultFullHttpRequest(HttpVersion.HTTP_1_1, HttpMethod.POST, url, buf);
-            httpRequest.headers().add(HttpHeaderNames.HOST, NettyConnector.this.host);
+            httpRequest.headers().add(HttpHeaderNames.HOST, String.format("%s:%d", host, port));
+            for (Map.Entry<String, String> header : headers.entrySet()) {
+               httpRequest.headers().add(header.getKey(), header.getValue());
+            }
             if (cookie != null) {
                httpRequest.headers().add(HttpHeaderNames.COOKIE, cookie);
             }
@@ -1170,7 +1210,10 @@ public class NettyConnector extends AbstractConnector {
 
             if (!waitingGet && System.currentTimeMillis() > lastSendTime + httpMaxClientIdleTime) {
                FullHttpRequest httpRequest = new DefaultFullHttpRequest(HttpVersion.HTTP_1_1, HttpMethod.GET, url);
-               httpRequest.headers().add(HttpHeaderNames.HOST, NettyConnector.this.host);
+               httpRequest.headers().add(HttpHeaderNames.HOST, String.format("%s:%d", host, port));
+               for (Map.Entry<String, String> header : headers.entrySet()) {
+                  httpRequest.headers().add(header.getKey(), header.getValue());
+               }
                waitingGet = true;
                channel.writeAndFlush(httpRequest);
             }
@@ -1205,27 +1248,17 @@ public class NettyConnector extends AbstractConnector {
       }
 
       @Override
-      public void connectionDestroyed(final Object connectionID) {
+      public void connectionDestroyed(final Object connectionID, boolean failed) {
          if (connections.remove(connectionID) != null) {
             // Execute on different thread to avoid deadlocks
-            closeExecutor.execute(new Runnable() {
-               @Override
-               public void run() {
-                  listener.connectionDestroyed(connectionID);
-               }
-            });
+            closeExecutor.execute(() -> listener.connectionDestroyed(connectionID, failed));
          }
       }
 
       @Override
       public void connectionException(final Object connectionID, final ActiveMQException me) {
          // Execute on different thread to avoid deadlocks
-         closeExecutor.execute(new Runnable() {
-            @Override
-            public void run() {
-               listener.connectionException(connectionID, me);
-            }
-         });
+         closeExecutor.execute(() -> listener.connectionException(connectionID, me));
       }
 
       @Override
@@ -1366,4 +1399,3 @@ public class NettyConnector extends AbstractConnector {
       }
    }
 }
-
