@@ -23,6 +23,7 @@ import java.util.Set;
 import io.netty.handler.codec.socksx.SocksVersion;
 import io.netty.util.Version;
 import org.apache.activemq.artemis.api.config.ActiveMQDefaultConfiguration;
+import org.apache.activemq.artemis.utils.DefaultSensitiveStringCodec;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import java.lang.invoke.MethodHandles;
@@ -35,12 +36,20 @@ public class TransportConstants {
 
    public static final String SSL_ENABLED_PROP_NAME = "sslEnabled";
 
+   public static final String PROXY_PROTOCOL_ENABLED_PROP_NAME = "proxyProtocolEnabled";
+
+   public static final String SSL_AUTO_RELOAD_PROP_NAME = "sslAutoReload";
+
+   public static final boolean DEFAULT_SSL_AUTO_RELOAD = false;
+
    public static final String HTTP_ENABLED_PROP_NAME = "httpEnabled";
 
    public static final String HTTP_CLIENT_IDLE_PROP_NAME = "httpClientIdleTime";
 
    public static final String HTTP_CLIENT_IDLE_SCAN_PERIOD = "httpClientIdleScanPeriod";
 
+   public static final String NETTY_HTTP_HEADER_PREFIX = "nettyHttpHeader.";
+
    public static final String HTTP_RESPONSE_TIME_PROP_NAME = "httpResponseTime";
 
    public static final String HTTP_SERVER_SCAN_PERIOD_PROP_NAME = "httpServerScanPeriod";
@@ -61,10 +70,10 @@ public class TransportConstants {
 
    public static final String USE_KQUEUE_PROP_NAME = "useKQueue";
 
-   @Deprecated
    /**
     * @deprecated Use USE_GLOBAL_WORKER_POOL_PROP_NAME
     */
+   @Deprecated
    public static final String USE_NIO_GLOBAL_WORKER_POOL_PROP_NAME = "useNioGlobalWorkerPool";
 
    public static final String USE_GLOBAL_WORKER_POOL_PROP_NAME = "useGlobalWorkerPool";
@@ -138,14 +147,15 @@ public class TransportConstants {
    public static final String NETTY_VERSION;
 
    /**
-    * Disable Nagle's algorithm.<br>
+    * Disable Nagle's algorithm.
+    * <p>
     * Valid for (client) Sockets.
     *
     * @see <a
-    * href="http://design.jboss.org/jbossorg/branding/Javadocs/doc/api/org/jboss/netty/channel/socket/SocketChannelConfig.html#setTcpNoDelay%28boolean%29">
-    * Netty note on this option</a>
-    * @see <a href="http://docs.oracle.com/javase/8/docs/technotes/guides/net/socketOpt.html">Oracle
-    * doc on tcpNoDelay</a>
+    * href="https://netty.io/4.1/api/io/netty/channel/socket/SocketChannelConfig.html#setTcpNoDelay-boolean-">Netty note
+    * on this option</a>
+    * @see <a href="http://docs.oracle.com/javase/8/docs/technotes/guides/net/socketOpt.html">Oracle doc on
+    * tcpNoDelay</a>
     */
    public static final String TCP_NODELAY_PROPNAME = "tcpNoDelay";
 
@@ -153,10 +163,10 @@ public class TransportConstants {
 
    public static final String TCP_RECEIVEBUFFER_SIZE_PROPNAME = "tcpReceiveBufferSize";
 
-   @Deprecated
    /**
     * @deprecated Use REMOTING_THREADS_PROPNAME
     */
+   @Deprecated
    public static final String NIO_REMOTING_THREADS_PROPNAME = "nioRemotingThreads";
 
    public static final String WRITE_BUFFER_LOW_WATER_MARK_PROPNAME = "writeBufferLowWaterMark";
@@ -178,19 +188,19 @@ public class TransportConstants {
 
    public static final int STOMP_DEFAULT_CONSUMER_WINDOW_SIZE = 10 * 1024; // 10K
 
-   public static final String PROXY_ENABLED_PROP_NAME = "socksEnabled";
+   public static final String SOCKS_ENABLED_PROP_NAME = "socksEnabled";
 
-   public static final String PROXY_HOST_PROP_NAME = "socksHost";
+   public static final String SOCKS_HOST_PROP_NAME = "socksHost";
 
-   public static final String PROXY_PORT_PROP_NAME = "socksPort";
+   public static final String SOCKS_PORT_PROP_NAME = "socksPort";
 
-   public static final String PROXY_VERSION_PROP_NAME = "socksVersion";
+   public static final String SOCKS_VERSION_PROP_NAME = "socksVersion";
 
-   public static final String PROXY_USERNAME_PROP_NAME = "socksUsername";
+   public static final String SOCKS_USERNAME_PROP_NAME = "socksUsername";
 
-   public static final String PROXY_PASSWORD_PROP_NAME = "socksPassword";
+   public static final String SOCKS_PASSWORD_PROP_NAME = "socksPassword";
 
-   public static final String PROXY_REMOTE_DNS_PROP_NAME = "socksRemoteDNS";
+   public static final String SOCKS_REMOTE_DNS_PROP_NAME = "socksRemoteDNS";
 
    public static final String AUTO_START = "autoStart";
 
@@ -198,6 +208,8 @@ public class TransportConstants {
 
    public static final boolean DEFAULT_SSL_ENABLED = false;
 
+   public static final boolean DEFAULT_PROXY_PROTOCOL_ENABLED = false;
+
    public static final String DEFAULT_SNIHOST_CONFIG = null;
 
    public static final boolean DEFAULT_USE_GLOBAL_WORKER_POOL = true;
@@ -264,6 +276,8 @@ public class TransportConstants {
 
    public static final String DEFAULT_KEYSTORE_ALIAS = null;
 
+   public static final String DEFAULT_PASSWORD_CODEC_CLASS = DefaultSensitiveStringCodec.class.getName();
+
    public static final boolean DEFAULT_TCP_NODELAY = true;
 
    public static final int DEFAULT_TCP_SENDBUFFER_SIZE = 1024 * 1024;
@@ -334,40 +348,56 @@ public class TransportConstants {
 
    public static final int DEFAULT_WEB_SOCKET_MAX_FRAME_PAYLOAD_LENGTH = 65536;
 
+   public static final String WEB_SOCKET_ENCODER_TYPE = "webSocketEncoderType";
+
+   public static final String DEFAULT_WEB_SOCKET_ENCODER_TYPE = "binary";
+
    public static final String HANDSHAKE_TIMEOUT = "handshake-timeout";
 
    public static final int DEFAULT_HANDSHAKE_TIMEOUT = 10;
 
+   /*
+    * Defines if the WS acceptor allows a client to request compression via WS extensions for
+    * per message deflate. By default this is not enabled and the WS upgrade response will not
+    * carry any compression support headers when the client indicates it supports compression.
+    */
+   public static final String WEB_SOCKET_COMPRESSION_SUPPORTED = "webSocketCompressionSupported";
+
+   public static final boolean DEFAULT_WEB_SOCKET_COMPRESSION_SUPPORTED = false;
+
    public static final String QUIET_PERIOD = "quietPeriod";
 
    public static final String DISABLE_STOMP_SERVER_HEADER = "disableStompServerHeader";
 
-   /** We let this to be defined as a System Variable, as we need a different timeout over our testsuite.
-    *  When running on a real server, this is the default we want.
-    *  When running on a test suite, we need it to be 0, You should see a property on the main pom.xml.
+   /**
+    * We let this to be defined as a System Variable, as we need a different timeout over our testsuite. When running on
+    * a real server, this is the default we want. When running on a test suite, we need it to be 0, You should see a
+    * property on the main pom.xml.
     */
    public static final int DEFAULT_QUIET_PERIOD = parseDefaultVariable("DEFAULT_QUIET_PERIOD", 100);
 
    public static final String SHUTDOWN_TIMEOUT = "shutdownTimeout";
 
-   /** We let this to be defined as a System Variable, as we need a different timeout over our testsuite.
-    *  When running on a real server, this is the default we want.
-    *  When running on a test suite, we need it to be 0, You should see a property on the main pom.xml */
+   /**
+    * We let this to be defined as a System Variable, as we need a different timeout over our testsuite. When running on
+    * a real server, this is the default we want. When running on a test suite, we need it to be 0, You should see a
+    * property on the main pom.xml
+    */
    public static final int DEFAULT_SHUTDOWN_TIMEOUT = parseDefaultVariable("DEFAULT_SHUTDOWN_TIMEOUT", 3_000);
 
-   public static final boolean DEFAULT_PROXY_ENABLED = false;
+   public static final boolean DEFAULT_SOCKS_ENABLED = false;
 
-   public static final String DEFAULT_PROXY_HOST = null;
+   public static final String DEFAULT_SOCKS_HOST = null;
 
-   public static final int DEFAULT_PROXY_PORT = 0;
+   public static final int DEFAULT_SOCKS_PORT = 0;
 
-   public static final byte DEFAULT_PROXY_VERSION = SocksVersion.SOCKS5.byteValue();
+   public static final byte DEFAULT_SOCKS_VERSION = SocksVersion.SOCKS5.byteValue();
 
-   public static final String DEFAULT_PROXY_USERNAME = null;
+   public static final String DEFAULT_SOCKS_USERNAME = null;
 
-   public static final String DEFAULT_PROXY_PASSWORD = null;
+   public static final String DEFAULT_SOCKS_PASSWORD = null;
 
-   public static final boolean DEFAULT_PROXY_REMOTE_DNS = false;
+   public static final boolean SOCKS_PROXY_REMOTE_DNS = false;
 
    public static final String ROUTER = "router";
 
@@ -389,6 +419,7 @@ public class TransportConstants {
    static {
       Set<String> allowableAcceptorKeys = new HashSet<>();
       allowableAcceptorKeys.add(TransportConstants.SSL_ENABLED_PROP_NAME);
+      allowableAcceptorKeys.add(TransportConstants.SSL_AUTO_RELOAD_PROP_NAME);
       allowableAcceptorKeys.add(TransportConstants.HTTP_RESPONSE_TIME_PROP_NAME);
       allowableAcceptorKeys.add(TransportConstants.HTTP_SERVER_SCAN_PERIOD_PROP_NAME);
       allowableAcceptorKeys.add(TransportConstants.HTTP_UPGRADE_ENABLED_PROP_NAME);
@@ -452,6 +483,7 @@ public class TransportConstants {
       allowableAcceptorKeys.add(TransportConstants.DISABLE_STOMP_SERVER_HEADER);
       allowableAcceptorKeys.add(TransportConstants.AUTO_START);
       allowableAcceptorKeys.add(TransportConstants.ROUTER);
+      allowableAcceptorKeys.add(TransportConstants.PROXY_PROTOCOL_ENABLED_PROP_NAME);
 
       ALLOWABLE_ACCEPTOR_KEYS = Collections.unmodifiableSet(allowableAcceptorKeys);
 
@@ -498,13 +530,13 @@ public class TransportConstants {
       allowableConnectorKeys.add(TransportConstants.NIO_REMOTING_THREADS_PROPNAME);
       allowableConnectorKeys.add(TransportConstants.REMOTING_THREADS_PROPNAME);
       allowableConnectorKeys.add(TransportConstants.BATCH_DELAY);
-      allowableConnectorKeys.add(TransportConstants.PROXY_ENABLED_PROP_NAME);
-      allowableConnectorKeys.add(TransportConstants.PROXY_HOST_PROP_NAME);
-      allowableConnectorKeys.add(TransportConstants.PROXY_PORT_PROP_NAME);
-      allowableConnectorKeys.add(TransportConstants.PROXY_VERSION_PROP_NAME);
-      allowableConnectorKeys.add(TransportConstants.PROXY_USERNAME_PROP_NAME);
-      allowableConnectorKeys.add(TransportConstants.PROXY_PASSWORD_PROP_NAME);
-      allowableConnectorKeys.add(TransportConstants.PROXY_REMOTE_DNS_PROP_NAME);
+      allowableConnectorKeys.add(TransportConstants.SOCKS_ENABLED_PROP_NAME);
+      allowableConnectorKeys.add(TransportConstants.SOCKS_HOST_PROP_NAME);
+      allowableConnectorKeys.add(TransportConstants.SOCKS_PORT_PROP_NAME);
+      allowableConnectorKeys.add(TransportConstants.SOCKS_VERSION_PROP_NAME);
+      allowableConnectorKeys.add(TransportConstants.SOCKS_USERNAME_PROP_NAME);
+      allowableConnectorKeys.add(TransportConstants.SOCKS_PASSWORD_PROP_NAME);
+      allowableConnectorKeys.add(TransportConstants.SOCKS_REMOTE_DNS_PROP_NAME);
       allowableConnectorKeys.add(ActiveMQDefaultConfiguration.getPropMaskPassword());
       allowableConnectorKeys.add(ActiveMQDefaultConfiguration.getPropPasswordCodec());
       allowableConnectorKeys.add(TransportConstants.NETTY_CONNECT_TIMEOUT);
