@@ -29,6 +29,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 
 import io.netty.buffer.ByteBuf;
@@ -141,8 +142,8 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    protected static final int VALUE_NOT_PRESENT = -1;
 
    /**
-    * This has been made public just for testing purposes: it's not stable
-    * and developers shouldn't rely on this for developing purposes.
+    * This has been made public just for testing purposes: it's not stable and developers shouldn't rely on this for
+    * developing purposes.
     */
    public enum MessageDataScanningStatus {
       NOT_SCANNED(0), RELOAD_PERSISTENCE(1), SCANNED(2);
@@ -211,6 +212,12 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    protected byte priority = DEFAULT_MESSAGE_PRIORITY;
 
    protected boolean isPaged;
+   protected volatile boolean routed = false;
+
+   @Override
+   public void routed() {
+      this.routed = true;
+   }
 
    // The Proton based AMQP message section that are retained in memory, these are the
    // mutable portions of the Message as the broker sees it, although AMQP defines that
@@ -235,10 +242,8 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    /**
     * Creates a new {@link AMQPMessage} instance from binary encoded message data.
     *
-    * @param messageFormat
-    *       The Message format tag given the in Transfer that carried this message
-    * @param extraProperties
-    *       Broker specific extra properties that should be carried with this message
+    * @param messageFormat   The Message format tag given the in Transfer that carried this message
+    * @param extraProperties Broker specific extra properties that should be carried with this message
     */
    public AMQPMessage(long messageFormat, TypedProperties extraProperties, CoreMessageObjectPools coreMessageObjectPools) {
       this.messageFormat = messageFormat;
@@ -269,7 +274,7 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
       if (messageAnnotations == null) {
          return null;
       }
-      HashMap newAnnotation = new HashMap();
+      Map newAnnotation = new HashMap();
       messageAnnotations.getValue().forEach((a, b) -> {
          // These properties should not be copied when re-routing the messages
          if (!a.toString().startsWith("x-opt-ORIG") && !a.toString().equals("x-opt-routing-type")) {
@@ -303,9 +308,11 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
       isPaged = true;
    }
 
-   /** This will return application properties without attempting to decode it.
-    * That means, if applicationProperties were never parsed before, this will return null, even if there is application properties.
-    *  This was created as an internal method for testing, as we need to validate if the application properties are not decoded until needed. */
+   /**
+    * This will return application properties without attempting to decode it. That means, if applicationProperties were
+    * never parsed before, this will return null, even if there is application properties. This was created as an
+    * internal method for testing, as we need to validate if the application properties are not decoded until needed.
+    */
    protected ApplicationProperties getDecodedApplicationProperties() {
       return applicationProperties;
    }
@@ -322,16 +329,15 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    // must be used to make changes to mutable portions of the message.
 
    /**
-    * Creates and returns a Proton-J MessageImpl wrapper around the message data. Changes to
-    * the returned Message are not reflected in this message.
+    * Creates and returns a Proton-J MessageImpl wrapper around the message data. Changes to the returned Message are
+    * not reflected in this message.
     *
     * @return a MessageImpl that wraps the AMQP message data in this {@link AMQPMessage}
     */
    public final MessageImpl getProtonMessage() {
 
-      if (getData() == null) {
-         throw new NullPointerException("Data is not initialized");
-      }
+      Objects.requireNonNull(getData(), "Data is not initialized");
+
       ensureScanning();
 
       MessageImpl protonMessage = null;
@@ -362,10 +368,8 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    }
 
    /**
-    * Returns a copy of the message Header if one is present, changes to the returned
-    * Header instance do not affect the original Message.
-    *
-    * @return a copy of the Message Header if one exists or null if none present.
+    * {@return a <em>copy</em> of this message's {@code Header} if one exists or {@code null} if none present; changes
+    * to the returned {@code Header} instance do not affect the original message}
     */
    public final Header getHeader() {
       ensureScanning();
@@ -373,12 +377,16 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    }
 
 
-   /** Returns the current already scanned header. */
+   /**
+    * {@return the current, already scanned {@code Header}}
+    */
    final Header getCurrentHeader() {
       return header;
    }
 
-   /** Return the current already scanned properties.*/
+   /**
+    * {@return the current already scanned {@coce Properties}}
+    */
    final Properties getCurrentProperties() {
       return properties;
    }
@@ -401,10 +409,8 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    }
 
    /**
-    * Returns a copy of the MessageAnnotations in the message if present or null.  Changes to the
-    * returned DeliveryAnnotations instance do not affect the original Message.
-    *
-    * @return a copy of the {@link DeliveryAnnotations} present in the message or null if non present.
+    * {@return a <em>copy</em> of the {@link DeliveryAnnotations} present in the message or {@code null} if non
+    * present; changes to the returned DeliveryAnnotations instance do not affect the original message}
     */
    public final DeliveryAnnotations getDeliveryAnnotations() {
       ensureScanning();
@@ -413,15 +419,15 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
 
    /**
     * Sets the delivery annotations to be included when encoding the message for sending it on the wire.
+    * <p>
+    * The broker can add additional message annotations as long as the annotations being added follow the rules from the
+    * spec. If the user adds something that the remote doesn't understand and it is not prefixed with "x-opt" the remote
+    * can just kill the link. See:
+    * <p>
+    * http://docs.oasis-open.org/amqp/core/v1.0/os/amqp-core-messaging-v1.0-os.html#type-annotations
     *
-    * The broker can add additional message annotations as long as the annotations being added follow the
-    * rules from the spec. If the user adds something that the remote doesn't understand and it is not
-    * prefixed with "x-opt" the remote can just kill the link. See:
-    *
-    *     http://docs.oasis-open.org/amqp/core/v1.0/os/amqp-core-messaging-v1.0-os.html#type-annotations
-    *
-    * @deprecated use MessageReference.setProtocolData(deliveryAnnotations)
     * @param deliveryAnnotations delivery annotations used in the sendBuffer() method
+    * @deprecated use {@link MessageReference#setProtocolData(Class, Object)}
     */
    @Deprecated
    public final void setDeliveryAnnotationsForSendBuffer(DeliveryAnnotations deliveryAnnotations) {
@@ -429,10 +435,8 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    }
 
    /**
-    * Returns a copy of the DeliveryAnnotations in the message if present or null.  Changes to the
-    * returned MessageAnnotations instance do not affect the original Message.
-    *
-    * @return a copy of the {@link MessageAnnotations} present in the message or null if non present.
+    * {@return a <em>copy</em> of the message's {@link MessageAnnotations} or {@code null} if none present; changes to
+    * the returned {@link MessageAnnotations} instance do not affect the original message}
     */
    public final MessageAnnotations getMessageAnnotations() {
       ensureScanning();
@@ -440,10 +444,8 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    }
 
    /**
-    * Returns a copy of the message Properties if one is present, changes to the returned
-    * Properties instance do not affect the original Message.
-    *
-    * @return a copy of the Message Properties if one exists or null if none present.
+    * {@return a <em>copy</em> of the message's {@link Properties} if one exists or {@code null} if none present;
+    * changes to the returned {@link Properties} instance do not affect the original message}
     */
    public final Properties getProperties() {
       ensureScanning();
@@ -451,28 +453,27 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    }
 
    /**
-    * Returns a copy of the {@link ApplicationProperties} present in the message if present or null.
-    * Changes to the returned MessageAnnotations instance do not affect the original Message.
-    *
-    * @return a copy of the {@link ApplicationProperties} present in the message or null if non present.
+    * {@return a <em>copy</em> of the message's {@link ApplicationProperties} or {@code null} if none present; changes
+    * to the returned {@link ApplicationProperties} instance do not affect the original message}
     */
    public final ApplicationProperties getApplicationProperties() {
       ensureScanning();
       return scanForMessageSection(applicationPropertiesPosition, ApplicationProperties.class);
    }
 
-   /** This is different from toString, as this will print an expanded version of the buffer
-    *  in Hex and programmers's readable format */
+   /**
+    * This is different from toString, as this will print an expanded version of the buffer in Hex and programmers's
+    * readable format
+    */
    public final String toDebugString() {
       return ByteUtil.debugByteArray(getData().array());
    }
 
    /**
-    * Retrieves the AMQP Section that composes the body of this message by decoding a
-    * fresh copy from the encoded message data.  Changes to the returned value are not
-    * reflected in the value encoded in the original message.
+    * Retrieves the AMQP Section that composes the body of this message by decoding a fresh copy from the encoded
+    * message data.  Changes to the returned value are not reflected in the value encoded in the original message.
     *
-    * @return the Section that makes up the body of this message.
+    * @return the Section that makes up the body of this message
     */
    public final Section getBody() {
       ensureScanning();
@@ -484,11 +485,10 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    }
 
    /**
-    * Retrieves the AMQP Footer encoded in the data of this message by decoding a
-    * fresh copy from the encoded message data.  Changes to the returned value are not
-    * reflected in the value encoded in the original message.
+    * Retrieves the AMQP Footer encoded in the data of this message by decoding a fresh copy from the encoded message
+    * data.  Changes to the returned value are not reflected in the value encoded in the original message.
     *
-    * @return the Footer that was encoded into this AMQP Message.
+    * @return the Footer that was encoded into this AMQP Message
     */
    public final Footer getFooter() {
       ensureScanning();
@@ -543,7 +543,8 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
       return lazyDecodeApplicationProperties(getData().duplicate().position(0));
    }
 
-   protected ApplicationProperties lazyDecodeApplicationProperties(ReadableBuffer data) {
+   // need to synchronize access to lazyDecodeApplicationProperties to avoid clashes with getMemoryEstimate
+   protected synchronized ApplicationProperties lazyDecodeApplicationProperties(ReadableBuffer data) {
       if (applicationProperties == null && applicationPropertiesPosition != VALUE_NOT_PRESENT) {
          applicationProperties = scanForMessageSection(data, applicationPropertiesPosition, ApplicationProperties.class);
          if (owner != null && memoryEstimate != -1) {
@@ -552,7 +553,9 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
 
             // it is difficult to track the updates for paged messages
             // for that reason we won't do it if paged
-            if (!isPaged) {
+            // we also only do the update if the message was previously routed
+            // so if a debug method or an interceptor changed the size before routing we would get a different size
+            if (!isPaged && routed) {
                ((PagingStore) owner).addSize(addition, false);
                final int updatedEstimate = memoryEstimate + addition;
                memoryEstimate = updatedEstimate;
@@ -589,7 +592,7 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
             map = new HashMap<>();
             this.applicationProperties = new ApplicationProperties(map);
          } else {
-            map = Collections.EMPTY_MAP;
+            map = Collections.emptyMap();
          }
       }
 
@@ -609,7 +612,7 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
             map = new HashMap<>();
             this.messageAnnotations = new MessageAnnotations(map);
          } else {
-            map = Collections.EMPTY_MAP;
+            map = Collections.emptyMap();
          }
       }
 
@@ -763,9 +766,8 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    // utilities for checking memory usage and encoded size characteristics.
 
    /**
-    * Would be called by the Artemis Core components to encode the message into
-    * the provided send buffer.  Because of how Proton message data handling works
-    * this method is not currently used by the AMQP protocol head and will not be
+    * Would be called by the Artemis Core components to encode the message into the provided send buffer.  Because of
+    * how Proton message data handling works this method is not currently used by the AMQP protocol head and will not be
     * called for out-bound sends.
     *
     * @see #getSendBuffer(int, MessageReference) for the actual method used for message sends.
@@ -780,15 +782,12 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    /**
     * Gets a ByteBuf from the Message that contains the encoded bytes to be sent on the wire.
     * <p>
-    * When possible this method will present the bytes to the caller without copying them into
-    * a new buffer copy.  If copying is needed a new Netty buffer is created and returned. The
-    * caller should ensure that the reference count on the returned buffer is always decremented
-    * to avoid a leak in the case of a copied buffer being returned.
+    * When possible this method will present the bytes to the caller without copying them into a new buffer copy.  If
+    * copying is needed a new Netty buffer is created and returned. The caller should ensure that the reference count on
+    * the returned buffer is always decremented to avoid a leak in the case of a copied buffer being returned.
     *
-    * @param deliveryCount
-    *       The new delivery count for this message.
-    *
-    * @return a Netty ByteBuf containing the encoded bytes of this Message instance.
+    * @param deliveryCount The new delivery count for this message.
+    * @return a Netty ByteBuf containing the encoded bytes of this Message instance
     */
    public ReadableBuffer getSendBuffer(int deliveryCount, MessageReference reference) {
       ensureMessageDataScanned();
@@ -810,7 +809,9 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
       }
    }
 
-   /** it will create a copy with the relevant delivery annotation and its copy */
+   /**
+    * it will create a copy with the relevant delivery annotation and its copy
+    */
    protected ReadableBuffer createDeliveryCopy(int deliveryCount, DeliveryAnnotations deliveryAnnotations) {
       ReadableBuffer duplicate = getData().duplicate();
 
@@ -917,8 +918,8 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
       for (SimpleString name : getPropertyNames()) {
          Object value = getObjectProperty(name.toString());
          //some property is Binary, which is not available for management console
-         if (value instanceof Binary) {
-            value = ((Binary)value).getArray();
+         if (value instanceof Binary binary) {
+            value = binary.getArray();
          }
          map.put(applicationPropertiesPrefix + name, JsonUtil.truncate(value, valueSizeLimit));
       }
@@ -1183,12 +1184,12 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    }
 
    /**
-    * Before we added AMQP into Artemis the name getUserID was already taken by JMSMessageID.
-    * We cannot simply change the names now as it would break the API for existing clients.
-    *
+    * Before we added AMQP into Artemis the name getUserID was already taken by JMSMessageID. We cannot simply change
+    * the names now as it would break the API for existing clients.
+    * <p>
     * This is to return and read the proper AMQP userID.
     *
-    * @return the UserID value in the AMQP Properties if one is present.
+    * @return the UserID value in the AMQP Properties if one is present
     */
    public final Object getAMQPUserID() {
       ensureMessageDataScanned();
@@ -1241,8 +1242,7 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
 
    @Override
    public final String getAddress() {
-      SimpleString addressSimpleString = getAddressSimpleString();
-      return addressSimpleString == null ? null : addressSimpleString.toString();
+      return Objects.toString(getAddressSimpleString(), null);
    }
 
    @Override
@@ -1343,7 +1343,7 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
          properties = new Properties();
       }
 
-      properties.setReplyTo(address != null ? address.toString() : null);
+      properties.setReplyTo(Objects.toString(address, null));
       return this;
    }
 
@@ -1466,10 +1466,10 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
          Object objscheduledTime = getMessageAnnotation(AMQPMessageSupport.SCHEDULED_DELIVERY_TIME);
          Object objdelay = getMessageAnnotation(AMQPMessageSupport.SCHEDULED_DELIVERY_DELAY);
 
-         if (objscheduledTime != null && objscheduledTime instanceof Number) {
-            this.scheduledTime = ((Number) objscheduledTime).longValue();
-         } else if (objdelay != null && objdelay instanceof Number) {
-            this.scheduledTime = System.currentTimeMillis() + ((Number) objdelay).longValue();
+         if (objscheduledTime != null && objscheduledTime instanceof Number number) {
+            this.scheduledTime = number.longValue();
+         } else if (objdelay != null && objdelay instanceof Number number) {
+            this.scheduledTime = System.currentTimeMillis() + number.longValue();
          } else {
             this.scheduledTime = 0;
          }
@@ -1615,13 +1615,13 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
 
    private Object getApplicationObjectProperty(String key) {
       Object value = getApplicationPropertiesMap(false).get(key);
-      if (value instanceof Number) {
+      if (value instanceof Number number) {
          // AMQP Numeric types must be converted to a compatible value.
          if (value instanceof UnsignedInteger ||
              value instanceof UnsignedByte ||
              value instanceof UnsignedLong ||
              value instanceof UnsignedShort) {
-            return ((Number) value).longValue();
+            return number.longValue();
          }
       } else if (value instanceof Binary) {
          // Binary wrappers must be unwrapped into a byte[] form.
@@ -1643,19 +1643,16 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
 
    @Override
    public final String getStringProperty(String key) throws ActiveMQPropertyConversionException {
-      switch (key) {
-         case MessageUtil.TYPE_HEADER_NAME_STRING:
-            return properties.getSubject();
-         case MessageUtil.CONNECTION_ID_PROPERTY_NAME_STRING:
-            return getConnectionID();
-         default:
-            return (String) getApplicationPropertiesMap(false).get(key);
-      }
+      return switch (key) {
+         case MessageUtil.TYPE_HEADER_NAME_STRING -> properties.getSubject();
+         case MessageUtil.CONNECTION_ID_PROPERTY_NAME_STRING -> getConnectionID();
+         default -> (String) getApplicationPropertiesMap(false).get(key);
+      };
    }
 
    @Override
    public final Set<SimpleString> getPropertyNames() {
-      HashSet<SimpleString> values = new HashSet<>();
+      Set<SimpleString> values = new HashSet<>();
       for (Object k : getApplicationPropertiesMap(false).keySet()) {
          values.add(SimpleString.of(k.toString(), getPropertyKeysPool()));
       }
@@ -1676,8 +1673,7 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    public final byte[] getBytesProperty(String key) throws ActiveMQPropertyConversionException {
       final Object value = getApplicationPropertiesMap(false).get(key);
 
-      if (value instanceof Binary) {
-         final Binary binary = (Binary) value;
+      if (value instanceof Binary binary) {
 
          if (binary.getArray() == null) {
             return null;
@@ -1863,9 +1859,9 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
 
    @Override
    public final org.apache.activemq.artemis.api.core.Message putObjectProperty(String key, Object value) throws ActiveMQPropertyConversionException {
-      if (value instanceof byte[]) {
+      if (value instanceof byte[] bytes) {
          // Prevent error from proton encoding, byte array must be wrapped in a Binary type.
-         putBytesProperty(key, (byte[]) value);
+         putBytesProperty(key, bytes);
       } else {
          getApplicationPropertiesMap(true).put(key, value);
       }
@@ -1902,7 +1898,7 @@ public abstract class AMQPMessage extends RefCountMessage implements org.apache.
    public String toString() {
       MessageDataScanningStatus scanningStatus = getDataScanningStatus();
       Map<String, Object> applicationProperties = scanningStatus == MessageDataScanningStatus.SCANNED ?
-         getApplicationPropertiesMap(false) : Collections.EMPTY_MAP;
+         getApplicationPropertiesMap(false) : Collections.emptyMap();
 
       return this.getClass().getSimpleName() + "( [durable=" + isDurable() +
          ", messageID=" + getMessageID() +
