@@ -16,8 +16,6 @@
  */
 package org.apache.activemq.artemis.protocol.amqp.broker;
 
-import static org.apache.activemq.artemis.protocol.amqp.proton.AmqpSupport.getReceiverPriority;
-
 import java.lang.invoke.MethodHandles;
 import java.util.concurrent.Executor;
 
@@ -82,6 +80,8 @@ import org.apache.qpid.proton.engine.Receiver;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import static org.apache.activemq.artemis.protocol.amqp.proton.AmqpSupport.getReceiverPriority;
+
 public class AMQPSessionCallback implements SessionCallback {
 
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
@@ -204,7 +204,7 @@ public class AMQPSessionCallback implements SessionCallback {
 
       String name = UUIDGenerator.getInstance().generateStringUUID();
 
-      if (connection.isBridgeConnection())  {
+      if (connection.isBrokerConnection())  {
          serverSession = manager.getServer().createInternalSession(name, ActiveMQClient.DEFAULT_MIN_LARGE_MESSAGE_SIZE, protonSPI.getProtonConnectionDelegate(), // RemotingConnection remotingConnection,
                                                            false, // boolean autoCommitSends
                                                            false, // boolean autoCommitAcks,
@@ -231,21 +231,15 @@ public class AMQPSessionCallback implements SessionCallback {
    }
 
    /**
-    * Creates a server consume that reads from the given named queue and forwards the read messages to
-    * the AMQP sender to dispatch to the remote peer. The consumer priority value is extracted from the
-    * remote link properties that were assigned by the remote receiver.
-    *
-    * @param protonSender
-    *    The {@link ProtonServerReceiverContext} that will be attached to the resulting consumer
-    * @param queue
-    *    The target queue that the consumer reads from.
-    * @param filter
-    *    The filter assigned to the consumer of the target queue.
-    * @param browserOnly
-    *    Should the consumer act as a browser on the target queue.
-    *
-    * @return a new {@link ServerConsumer} attached to the given queue.
+    * Creates a server consume that reads from the given named queue and forwards the read messages to the AMQP sender
+    * to dispatch to the remote peer. The consumer priority value is extracted from the remote link properties that were
+    * assigned by the remote receiver.
     *
+    * @param protonSender The {@link ProtonServerReceiverContext} that will be attached to the resulting consumer
+    * @param queue        The target queue that the consumer reads from.
+    * @param filter       The filter assigned to the consumer of the target queue.
+    * @param browserOnly  Should the consumer act as a browser on the target queue.
+    * @return a new {@link ServerConsumer} attached to the given queue
     * @throws Exception if an error occurs while creating the consumer instance.
     */
    public ServerConsumer createSender(ProtonServerSenderContext protonSender,
@@ -256,22 +250,15 @@ public class AMQPSessionCallback implements SessionCallback {
    }
 
    /**
-    * Creates a server consume that reads from the given named queue and forwards the read messages to
-    * the AMQP sender to dispatch to the remote peer.
-    *
-    * @param protonSender
-    *    The {@link ProtonServerReceiverContext} that will be attached to the resulting consumer
-    * @param queue
-    *    The target queue that the consumer reads from.
-    * @param filter
-    *    The filter assigned to the consumer of the target queue.
-    * @param browserOnly
-    *    Should the consumer act as a browser on the target queue.
-    * @param priority
-    *    The priority to assign the new consumer (server defaults are used if not set).
-    *
-    * @return a new {@link ServerConsumer} attached to the given queue.
+    * Creates a server consume that reads from the given named queue and forwards the read messages to the AMQP sender
+    * to dispatch to the remote peer.
     *
+    * @param protonSender The {@link ProtonServerReceiverContext} that will be attached to the resulting consumer
+    * @param queue        The target queue that the consumer reads from.
+    * @param filter       The filter assigned to the consumer of the target queue.
+    * @param browserOnly  Should the consumer act as a browser on the target queue.
+    * @param priority     The priority to assign the new consumer (server defaults are used if not set).
+    * @return a new {@link ServerConsumer} attached to the given queue
     * @throws Exception if an error occurs while creating the consumer instance.
     */
    public ServerConsumer createSender(ProtonServerSenderContext protonSender,
@@ -344,6 +331,14 @@ public class AMQPSessionCallback implements SessionCallback {
       }
    }
 
+   public void createTemporaryAddress(SimpleString address) throws Exception {
+      try {
+         serverSession.createAddress(new AddressInfo(address, RoutingType.MULTICAST).setTemporary(true), false);
+      } catch (ActiveMQSecurityException se) {
+         throw ActiveMQAMQPProtocolMessageBundle.BUNDLE.securityErrorCreatingTempDestination(se.getMessage());
+      }
+   }
+
    public void createUnsharedDurableQueue(SimpleString address,
                                           RoutingType routingType,
                                           SimpleString queueName,
@@ -523,36 +518,33 @@ public class AMQPSessionCallback implements SessionCallback {
                           Receiver receiver,
                           Delivery delivery,
                           SimpleString address,
+                          RoutingType routingType,
                           RoutingContext routingContext,
                           Message message) throws Exception {
 
       context.incrementSettle();
 
-      RoutingType routingType = null;
-      if (address != null) {
+      final SimpleString messageAddress = message.getAddressSimpleString();
+      final SimpleString selectedAddress;
+
+      if (!context.isAnonymousRelay()) {
          // set Fixed-address producer if the message.properties.to address differs from the producer
-         if (!address.toString().equals(message.getAddress())) {
+         if (!address.equals(messageAddress)) {
             message.setAddress(address);
          }
-         routingType = context.getDefRoutingType();
-      } else {
-         // Anonymous-relay producer, message must carry a To value
-         address = message.getAddressSimpleString();
-         if (address == null) {
-            // Errors are not currently handled as required by AMQP 1.0 anonterm-v1.0
-            rejectMessage(context, delivery, Symbol.valueOf("failed"), "Missing 'to' field for message sent to an anonymous producer");
-            return;
-         }
 
-         routingType = message.getRoutingType();
-         if (routingType == null) {
-            routingType = context.getRoutingType(receiver, address);
-         }
+         selectedAddress = address;
+      } else if (messageAddress == null) {
+         // Anonymous-relay producer, message must carry a To value
+         // Errors are not currently handled as required by AMQP 1.0 anonterm-v1.0
+         rejectMessage(context, delivery, Symbol.valueOf("failed"), "Missing 'to' field for message sent to an anonymous producer");
+         return;
+      } else {
+         selectedAddress = messageAddress;
       }
 
-      //here check queue-autocreation
-      if (!checkAddressAndAutocreateIfPossible(address, routingType)) {
-         ActiveMQException e = ActiveMQAMQPProtocolMessageBundle.BUNDLE.addressDoesntExist(address.toString());
+      if (!checkAddressAndAutocreateIfPossible(selectedAddress, routingType)) {
+         ActiveMQException e = ActiveMQAMQPProtocolMessageBundle.BUNDLE.addressDoesntExist(selectedAddress.toString());
          if (transaction != null) {
             transaction.markAsRollbackOnly(e);
          }
@@ -562,7 +554,7 @@ public class AMQPSessionCallback implements SessionCallback {
       OperationContext oldcontext = recoverContext();
 
       try {
-         PagingStore store = manager.getServer().getPagingManager().getPageStore(message.getAddressSimpleString());
+         PagingStore store = manager.getServer().getPagingManager().getPageStore(selectedAddress);
          if (store != null && store.isRejectingMessages()) {
             // We drop pre-settled messages (and abort any associated Tx)
             String amqpAddress = delivery.getLink().getTarget().getAddress();
@@ -577,7 +569,7 @@ public class AMQPSessionCallback implements SessionCallback {
          } else {
             message.setConnectionID(receiver.getSession().getConnection().getRemoteContainer());
             // We need to transfer IO execution to a different thread otherwise we may deadlock netty loop
-            sessionExecutor.execute(() -> inSessionSend(context, transaction, message, delivery, receiver, routingContext));
+            sessionExecutor.execute(() -> inSessionSend(context, transaction, message, selectedAddress, routingType, delivery, receiver, routingContext));
          }
       } catch (Exception e) {
          onSendFailed(message, transaction, e);
@@ -609,19 +601,20 @@ public class AMQPSessionCallback implements SessionCallback {
 
          }
       });
-
    }
 
    private void inSessionSend(final ProtonServerReceiverContext context,
                               final Transaction transaction,
                               final Message message,
+                              final SimpleString address,
+                              final RoutingType routingType,
                               final Delivery delivery,
                               final Receiver receiver,
                               final RoutingContext routingContext) {
       OperationContext oldContext = recoverContext();
       try {
          if (invokeIncoming(message, (ActiveMQProtonRemotingConnection) transportConnection.getProtocolConnection()) == null) {
-            serverSession.send(transaction, message, directDeliver, receiver.getName(), false, routingContext);
+            serverSession.send(transaction, address, routingType, message, directDeliver, receiver.getName(), false, routingContext);
 
             afterIO(new IOCallback() {
                @Override
@@ -668,8 +661,8 @@ public class AMQPSessionCallback implements SessionCallback {
       }
 
       if (transaction != null) {
-         if (cause instanceof ActiveMQException) {
-            transaction.markAsRollbackOnly((ActiveMQException) cause);
+         if (cause instanceof ActiveMQException activeMQException) {
+            transaction.markAsRollbackOnly(activeMQException);
          } else {
             transaction.markAsRollbackOnly(
                new ActiveMQInternalErrorException("Delivery failure triggered TXN to be marked as rollback only", cause));
@@ -684,7 +677,9 @@ public class AMQPSessionCallback implements SessionCallback {
       });
    }
 
-   /** Will execute a Runnable on an Address when there's space in memory*/
+   /**
+    * Will execute a Runnable on an Address when there's space in memory
+    */
    public void flow(final SimpleString address,
                     Runnable runnable) {
       try {
@@ -720,7 +715,8 @@ public class AMQPSessionCallback implements SessionCallback {
       storageManager.setContext(oldContext);
    }
 
-   /** Set the proper operation context in the Thread Local.
+   /**
+    * Set the proper operation context in the Thread Local.
     *  Return the old context*/
    public OperationContext recoverContext() {
       OperationContext oldContext = storageManager.getContext();
@@ -811,16 +807,12 @@ public class AMQPSessionCallback implements SessionCallback {
    }
 
    /**
-    * Adds key / value based metadata into the underlying server session implementation
-    * for use by the connection resources.
-    *
-    * @param key
-    *    The key to add into the linked server session.
-    * @param value
-    *    The value to add into the linked server session attached to the given key.
-    *
-    * @return this {@link AMQPSessionCallback} instance.
+    * Adds key / value based metadata into the underlying server session implementation for use by the connection
+    * resources.
     *
+    * @param key   The key to add into the linked server session.
+    * @param value The value to add into the linked server session attached to the given key.
+    * @return this {@link AMQPSessionCallback} instance
     * @throws Exception if an error occurs while adding the metadata.
     */
    public AMQPSessionCallback addMetaData(String key, String value) throws Exception {
@@ -854,6 +846,10 @@ public class AMQPSessionCallback implements SessionCallback {
       serverSession.deleteQueue(address);
    }
 
+   public void removeTemporaryAddress(SimpleString address) throws Exception {
+      serverSession.deleteAddress(address);
+   }
+
    public RoutingType getDefaultRoutingType(SimpleString address) {
       return manager.getServer().getAddressSettingsRepository().getMatch(address.toString()).getDefaultAddressRoutingType();
    }
