@@ -16,20 +16,6 @@
  */
 package org.apache.activemq.artemis.protocol.amqp.converter.message;
 
-import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_DATA;
-import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_NULL;
-import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_SEQUENCE;
-import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_UNKNOWN;
-import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_VALUE_BINARY;
-import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_VALUE_LIST;
-import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.JMS_AMQP_ORIGINAL_ENCODING;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.ObjectInputStream;
@@ -42,7 +28,6 @@ import java.util.UUID;
 
 import org.apache.activemq.artemis.core.buffers.impl.ResetLimitWrappedActiveMQBuffer;
 import org.apache.activemq.artemis.core.message.impl.CoreMessage;
-
 import org.apache.activemq.artemis.protocol.amqp.broker.AMQPMessage;
 import org.apache.activemq.artemis.protocol.amqp.converter.AMQPConverter;
 import org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport;
@@ -59,7 +44,21 @@ import org.apache.qpid.proton.amqp.messaging.AmqpSequence;
 import org.apache.qpid.proton.amqp.messaging.AmqpValue;
 import org.apache.qpid.proton.amqp.messaging.Data;
 import org.apache.qpid.proton.amqp.messaging.MessageAnnotations;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+
+import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_DATA;
+import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_NULL;
+import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_SEQUENCE;
+import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_UNKNOWN;
+import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_VALUE_BINARY;
+import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.AMQP_VALUE_LIST;
+import static org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport.JMS_AMQP_ORIGINAL_ENCODING;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.fail;
 
 public class JMSMappingOutboundTransformerTest {
 
@@ -106,14 +105,14 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof Data);
-      assertTrue(((Data) amqp.getBody()).getValue() instanceof Binary);
+      assertInstanceOf(Data.class, amqp.getBody());
+      assertInstanceOf(Binary.class, ((Data) amqp.getBody()).getValue());
       assertEquals(4, ((Data) amqp.getBody()).getValue().getLength());
 
       Binary amqpData = ((Data) amqp.getBody()).getValue();
       Binary inputData = new Binary(expectedPayload);
 
-      assertTrue(inputData.equals(amqpData));
+      assertEquals(inputData, amqpData);
    }
 
    @Test
@@ -125,8 +124,8 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
-      assertTrue(((AmqpValue) amqp.getBody()).getValue() instanceof Binary);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
+      assertInstanceOf(Binary.class, ((AmqpValue) amqp.getBody()).getValue());
       assertEquals(0, ((Binary) ((AmqpValue) amqp.getBody()).getValue()).getLength());
    }
 
@@ -141,14 +140,14 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
-      assertTrue(((AmqpValue) amqp.getBody()).getValue() instanceof Binary);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
+      assertInstanceOf(Binary.class, ((AmqpValue) amqp.getBody()).getValue());
       assertEquals(4, ((Binary) ((AmqpValue) amqp.getBody()).getValue()).getLength());
 
       Binary amqpData = (Binary) ((AmqpValue) amqp.getBody()).getValue();
       Binary inputData = new Binary(expectedPayload);
 
-      assertTrue(inputData.equals(amqpData));
+      assertEquals(inputData, amqpData);
    }
 
    // ----- MapMessage type tests --------------------------------------------//
@@ -161,8 +160,8 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
-      assertTrue(((AmqpValue) amqp.getBody()).getValue() instanceof Map);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
+      assertInstanceOf(Map.class, ((AmqpValue) amqp.getBody()).getValue());
    }
 
    @Test
@@ -176,8 +175,8 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
-      assertTrue(((AmqpValue) amqp.getBody()).getValue() instanceof Map);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
+      assertInstanceOf(Map.class, ((AmqpValue) amqp.getBody()).getValue());
 
       @SuppressWarnings("unchecked")
       Map<Object, Object> amqpMap = (Map<Object, Object>) ((AmqpValue) amqp.getBody()).getValue();
@@ -198,14 +197,14 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
-      assertTrue(((AmqpValue) amqp.getBody()).getValue() instanceof Map);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
+      assertInstanceOf(Map.class, ((AmqpValue) amqp.getBody()).getValue());
 
       @SuppressWarnings("unchecked")
       Map<Object, Object> amqpMap = (Map<Object, Object>) ((AmqpValue) amqp.getBody()).getValue();
 
       assertEquals(3, amqpMap.size());
-      assertTrue("string".equals(amqpMap.get("property-1")));
+      assertEquals("string", amqpMap.get("property-1"));
    }
 
    //----- StreamMessage type tests -----------------------------------------//
@@ -220,7 +219,7 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
 
       AmqpValue list = (AmqpValue) amqp.getBody();
 
@@ -241,7 +240,7 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
 
       AmqpValue list = (AmqpValue) amqp.getBody();
 
@@ -262,8 +261,8 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpSequence);
-      assertTrue(((AmqpSequence) amqp.getBody()).getValue() instanceof List);
+      assertInstanceOf(AmqpSequence.class, amqp.getBody());
+      assertInstanceOf(List.class, ((AmqpSequence) amqp.getBody()).getValue());
 
       @SuppressWarnings("unchecked")
       List<Object> amqpList = ((AmqpSequence) amqp.getBody()).getValue();
@@ -281,7 +280,7 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof Data);
+      assertInstanceOf(Data.class, amqp.getBody());
       assertEquals(5, ((Data) amqp.getBody()).getValue().getLength());
    }
 
@@ -294,7 +293,7 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof Data);
+      assertInstanceOf(Data.class, amqp.getBody());
       assertEquals(5, ((Data) amqp.getBody()).getValue().getLength());
    }
 
@@ -306,12 +305,12 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof Data);
-      assertFalse(0 == ((Data) amqp.getBody()).getValue().getLength());
+      assertInstanceOf(Data.class, amqp.getBody());
+      assertNotEquals(0, ((Data) amqp.getBody()).getValue().getLength());
 
       Object value = deserialize(((Data) amqp.getBody()).getValue().getArray());
       assertNotNull(value);
-      assertTrue(value instanceof UUID);
+      assertInstanceOf(UUID.class, value);
    }
 
    @Test
@@ -323,12 +322,12 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof Data);
-      assertFalse(0 == ((Data) amqp.getBody()).getValue().getLength());
+      assertInstanceOf(Data.class, amqp.getBody());
+      assertNotEquals(0, ((Data) amqp.getBody()).getValue().getLength());
 
       Object value = deserialize(((Data) amqp.getBody()).getValue().getArray());
       assertNotNull(value);
-      assertTrue(value instanceof UUID);
+      assertInstanceOf(UUID.class, value);
    }
 
    @Test
@@ -340,13 +339,13 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
-      assertTrue(((AmqpValue) amqp.getBody()).getValue() instanceof Binary);
-      assertFalse(0 == ((Binary) ((AmqpValue) amqp.getBody()).getValue()).getLength());
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
+      assertInstanceOf(Binary.class, ((AmqpValue) amqp.getBody()).getValue());
+      assertNotEquals(0, ((Binary) ((AmqpValue) amqp.getBody()).getValue()).getLength());
 
       Object value = deserialize(((Binary) ((AmqpValue) amqp.getBody()).getValue()).getArray());
       assertNotNull(value);
-      assertTrue(value instanceof UUID);
+      assertInstanceOf(UUID.class, value);
    }
 
    @Test
@@ -358,8 +357,8 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
-      assertTrue(((AmqpValue) amqp.getBody()).getValue() instanceof Binary);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
+      assertInstanceOf(Binary.class, ((AmqpValue) amqp.getBody()).getValue());
       assertEquals(5, ((Binary) ((AmqpValue) amqp.getBody()).getValue()).getLength());
    }
 
@@ -373,7 +372,7 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
       assertNull(((AmqpValue) amqp.getBody()).getValue());
    }
 
@@ -386,7 +385,7 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
       assertEquals(contentString, ((AmqpValue) amqp.getBody()).getValue());
    }
 
@@ -399,7 +398,7 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
       assertEquals(contentString, ((AmqpValue) amqp.getBody()).getValue());
    }
 
@@ -412,7 +411,7 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof AmqpValue);
+      assertInstanceOf(AmqpValue.class, amqp.getBody());
 
       AmqpValue value = (AmqpValue) amqp.getBody();
 
@@ -429,8 +428,8 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof Data);
-      assertTrue(((Data) amqp.getBody()).getValue() instanceof Binary);
+      assertInstanceOf(Data.class, amqp.getBody());
+      assertInstanceOf(Binary.class, ((Data) amqp.getBody()).getValue());
 
       Binary data = ((Data) amqp.getBody()).getValue();
       String contents = new String(data.getArray(), data.getArrayOffset(), data.getLength(), StandardCharsets.UTF_8);
@@ -447,8 +446,8 @@ public class JMSMappingOutboundTransformerTest {
       AMQPMessage amqp = AMQPConverter.getInstance().fromCore(outbound.getInnerMessage(), null);
 
       assertNotNull(amqp.getBody());
-      assertTrue(amqp.getBody() instanceof Data);
-      assertTrue(((Data) amqp.getBody()).getValue() instanceof Binary);
+      assertInstanceOf(Data.class, amqp.getBody());
+      assertInstanceOf(Binary.class, ((Data) amqp.getBody()).getValue());
 
       Binary data = ((Data) amqp.getBody()).getValue();
       String contents = new String(data.getArray(), data.getArrayOffset(), data.getLength(), StandardCharsets.UTF_8);
@@ -479,13 +478,13 @@ public class JMSMappingOutboundTransformerTest {
       Map<Symbol, Object> maMap = ma == null ? null : ma.getValue();
       if (maMap != null) {
          Object actualValue = maMap.get(AMQPMessageSupport.JMS_DEST_TYPE_MSG_ANNOTATION);
-         assertEquals("Unexpected annotation value", expectedAnnotationValue, actualValue);
+         assertEquals(expectedAnnotationValue, actualValue, "Unexpected annotation value");
       } else if (expectedAnnotationValue != null) {
          fail("Expected annotation value, but there were no annotations");
       }
 
       if (jmsDestination != null) {
-         assertEquals("Unexpected 'to' address", jmsDestination, amqp.getAddress());
+         assertEquals(jmsDestination, amqp.getAddress(), "Unexpected 'to' address");
       }
    }
 
@@ -512,13 +511,13 @@ public class JMSMappingOutboundTransformerTest {
       Map<Symbol, Object> maMap = ma == null ? null : ma.getValue();
       if (maMap != null) {
          Object actualValue = maMap.get(AMQPMessageSupport.JMS_REPLY_TO_TYPE_MSG_ANNOTATION);
-         assertEquals("Unexpected annotation value", expectedAnnotationValue, actualValue);
+         assertEquals(expectedAnnotationValue, actualValue, "Unexpected annotation value");
       } else if (expectedAnnotationValue != null) {
          fail("Expected annotation value, but there were no annotations");
       }
 
       if (jmsReplyTo != null) {
-         assertEquals("Unexpected 'reply-to' address", jmsReplyTo, amqp.getReplyTo().toString());
+         assertEquals(jmsReplyTo, amqp.getReplyTo().toString(), "Unexpected 'reply-to' address");
       }
    }
 
@@ -527,15 +526,10 @@ public class JMSMappingOutboundTransformerTest {
    private String createDestination(byte destType) {
       String prefix = PrefixUtil.getURIPrefix(TEST_ADDRESS);
       String address = PrefixUtil.removePrefix(TEST_ADDRESS, prefix);
-      switch (destType) {
-         case QUEUE_TYPE:
-         case TOPIC_TYPE:
-         case TEMP_QUEUE_TYPE:
-         case TEMP_TOPIC_TYPE:
-            return address;
-         default:
-            throw new IllegalArgumentException("Invliad Destination Type given/");
-      }
+      return switch (destType) {
+         case QUEUE_TYPE, TOPIC_TYPE, TEMP_QUEUE_TYPE, TEMP_TOPIC_TYPE -> address;
+         default -> throw new IllegalArgumentException("Invliad Destination Type given/");
+      };
    }
 
    private CoreMessageWrapper createMessage() {
