@@ -17,6 +17,9 @@
 package org.apache.activemq.artemis.protocol.amqp.proton;
 
 import java.util.List;
+import java.util.concurrent.Executors;
+import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import io.netty.buffer.Unpooled;
@@ -24,6 +27,7 @@ import org.apache.activemq.artemis.api.core.ActiveMQAddressFullException;
 import org.apache.activemq.artemis.api.core.ActiveMQException;
 import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.artemis.core.persistence.impl.nullpm.NullStorageManager;
+import org.apache.activemq.artemis.core.server.ActiveMQServer;
 import org.apache.activemq.artemis.core.server.RoutingContext;
 import org.apache.activemq.artemis.core.transaction.Transaction;
 import org.apache.activemq.artemis.protocol.amqp.broker.AMQPMessage;
@@ -34,11 +38,13 @@ import org.apache.activemq.artemis.protocol.amqp.converter.AMQPMessageSupport;
 import org.apache.activemq.artemis.protocol.amqp.exceptions.ActiveMQAMQPException;
 import org.apache.activemq.artemis.protocol.amqp.util.NettyReadable;
 import org.apache.activemq.artemis.protocol.amqp.util.NettyWritable;
+import org.apache.activemq.artemis.utils.Wait;
 import org.apache.qpid.proton.amqp.Symbol;
 import org.apache.qpid.proton.amqp.messaging.Accepted;
 import org.apache.qpid.proton.amqp.messaging.Modified;
 import org.apache.qpid.proton.amqp.messaging.Outcome;
 import org.apache.qpid.proton.amqp.messaging.Rejected;
+import org.apache.qpid.proton.amqp.messaging.Released;
 import org.apache.qpid.proton.amqp.messaging.Source;
 import org.apache.qpid.proton.amqp.transport.DeliveryState;
 import org.apache.qpid.proton.codec.ReadableBuffer;
@@ -179,7 +185,10 @@ public class ProtonServerReceiverContextTest {
       verify(mockDelivery, times(1)).settle();
 
       verify(mockReceiver, times(1)).getDrain();
-      if (!drain) {
+      if (drain) {
+         verify(mockReceiver, times(1)).getQueued();
+         verify(mockReceiver, times(1)).getCredit();
+      } else {
          verify(mockReceiver, times(1)).flow(1);
       }
       verifyNoMoreInteractions(mockReceiver);
@@ -226,7 +235,7 @@ public class ProtonServerReceiverContextTest {
       source.setDefaultOutcome(defaultOutcome);
       when(mockReceiver.getSource()).thenReturn(source);
 
-      doThrow(deliveryException).when(mockSession).serverSend(eq(rc), nullable(Transaction.class), eq(mockReceiver), eq(mockDelivery), nullable(SimpleString.class), any(RoutingContext.class), nullable(AMQPMessage.class));
+      doThrow(deliveryException).when(mockSession).serverSend(eq(rc), nullable(Transaction.class), eq(mockReceiver), eq(mockDelivery), nullable(SimpleString.class), any(), any(RoutingContext.class), nullable(AMQPMessage.class));
 
       rc.onMessage(mockDelivery);
 
@@ -243,6 +252,116 @@ public class ProtonServerReceiverContextTest {
       assertEquals(900, ProtonServerReceiverContext.calculatedUpdateRefill(2000, 1000, 100));
    }
 
+   @Test
+   public void testStopDrainsOffCredit() throws Exception {
+      final ScheduledExecutorService scheduler = Executors.newScheduledThreadPool(1);
+
+      try {
+         ActiveMQServer mockServer = mock(ActiveMQServer.class);
+         when(mockServer.getScheduledPool()).thenReturn(scheduler);
+
+         Receiver mockReceiver = mock(Receiver.class);
+         AMQPConnectionContext mockConnContext = mock(AMQPConnectionContext.class);
+
+         when(mockConnContext.getAmqpCredits()).thenReturn(100);
+         when(mockConnContext.getAmqpLowCredits()).thenReturn(30);
+
+         when(mockConnContext.getProtocolManager()).thenReturn(mock(ProtonProtocolManager.class));
+
+         AMQPSessionCallback mockSessionSpi = mock(AMQPSessionCallback.class);
+         when(mockSessionSpi.getStorageManager()).thenReturn(new NullStorageManager());
+         when(mockSessionSpi.createStandardMessage(any(), any())).thenAnswer((Answer<AMQPStandardMessage>) invocation -> new AMQPStandardMessage(0, createAMQPMessageBuffer(), null, null));
+
+         AMQPSessionContext mockProtonContext = mock(AMQPSessionContext.class);
+         when(mockProtonContext.getServer()).thenReturn(mockServer);
+         when(mockProtonContext.getSessionSPI()).thenReturn(mockSessionSpi);
+
+         ProtonServerReceiverContext rc = new ProtonServerReceiverContext(mockSessionSpi, mockConnContext, mockProtonContext, mockReceiver);
+
+         AtomicBoolean stopped = new AtomicBoolean();
+
+         when(mockReceiver.getCredit()).thenReturn(100);
+
+         rc.stop(10_000, (rcvr, didStop) -> stopped.set(true));
+
+         assertFalse(stopped.get());
+
+         verify(mockReceiver, times(1)).drain(0);
+         verify(mockReceiver, times(1)).draining();
+         verify(mockReceiver, times(2)).getCredit();
+         verify(mockReceiver, times(1)).getQueued();
+         verify(mockReceiver, times(1)).drain(0);
+      } finally {
+         scheduler.shutdown();
+      }
+   }
+
+   @Test
+   public void testDrainInitiatedWhenDeliveryMarkedFailed() throws Exception {
+      final ScheduledExecutorService scheduler = Executors.newScheduledThreadPool(1);
+
+      try {
+         ActiveMQServer mockServer = mock(ActiveMQServer.class);
+         when(mockServer.getScheduledPool()).thenReturn(scheduler);
+
+         Source source = new Source();
+         source.setOutcomes(new Symbol[]{Accepted.DESCRIPTOR_SYMBOL, Rejected.DESCRIPTOR_SYMBOL,
+                                         Modified.DESCRIPTOR_SYMBOL, Released.DESCRIPTOR_SYMBOL});
+
+         Receiver mockReceiver = mock(Receiver.class);
+         when(mockReceiver.getSource()).thenReturn(source);
+
+         ProtonProtocolManager mockProtocolManager = mock(ProtonProtocolManager.class);
+         when(mockProtocolManager.getLinkQuiesceTimeout()).thenReturn(100);
+         when(mockProtocolManager.isDrainOnTransientDeliveryErrors()).thenReturn(true);
+
+         AMQPConnectionContext mockConnContext = mock(AMQPConnectionContext.class);
+         when(mockConnContext.getAmqpCredits()).thenReturn(100);
+         when(mockConnContext.getAmqpLowCredits()).thenReturn(30);
+         when(mockConnContext.getProtocolManager()).thenReturn(mockProtocolManager);
+
+         doAnswer(invocation -> {
+            final Runnable target = invocation.getArgument(0, Runnable.class);
+            target.run();
+            return null;
+         }).when(mockConnContext).runNow(any(Runnable.class));
+
+         doAnswer(invocation -> {
+            final Runnable target = invocation.getArgument(0, Runnable.class);
+            target.run();
+            return null;
+         }).when(mockConnContext).runLater(any(Runnable.class));
+
+         AMQPSessionCallback mockSessionSpi = mock(AMQPSessionCallback.class);
+         when(mockSessionSpi.getStorageManager()).thenReturn(new NullStorageManager());
+         when(mockSessionSpi.createStandardMessage(any(), any())).thenAnswer((Answer<AMQPStandardMessage>) invocation -> new AMQPStandardMessage(0, createAMQPMessageBuffer(), null, null));
+
+         AMQPSessionContext mockProtonContext = mock(AMQPSessionContext.class);
+         when(mockProtonContext.getServer()).thenReturn(mockServer);
+         when(mockProtonContext.getSessionSPI()).thenReturn(mockSessionSpi);
+
+         ProtonServerReceiverContext rc = new ProtonServerReceiverContext(mockSessionSpi, mockConnContext, mockProtonContext, mockReceiver);
+
+         when(mockReceiver.getCredit()).thenReturn(100);
+
+         Delivery mockDelivery = mock(Delivery.class);
+         when(mockDelivery.getLink()).thenReturn(mockReceiver);
+         when(mockReceiver.current()).thenReturn(mockDelivery);
+
+         rc.incrementSettle();
+         rc.deliveryFailed(mockDelivery, mockReceiver, new ActiveMQAddressFullException("full"));
+
+         Wait.assertTrue(() -> rc.isClosed(), 5000, 50);
+
+         verify(mockReceiver, times(1)).drain(0);
+         verify(mockReceiver, times(2)).getCredit();
+         verify(mockReceiver, times(1)).drain(0);
+         verify(mockReceiver, times(1)).getSource();
+      } finally {
+         scheduler.shutdown();
+      }
+   }
+
    private ReadableBuffer createAMQPMessageBuffer() {
       MessageImpl message = (MessageImpl) Message.Factory.create();
       message.setContentType(AMQPMessageSupport.OCTET_STREAM_CONTENT_TYPE);
