@@ -28,6 +28,7 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.ListIterator;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Executor;
@@ -37,6 +38,7 @@ import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLongFieldUpdater;
 
 import org.apache.activemq.advisory.AdvisorySupport;
+import org.apache.activemq.artemis.api.core.ActiveMQAddressDoesNotExistException;
 import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
 import org.apache.activemq.artemis.api.core.ActiveMQException;
 import org.apache.activemq.artemis.api.core.ActiveMQExceptionType;
@@ -68,8 +70,9 @@ import org.apache.activemq.artemis.core.server.MessageReference;
 import org.apache.activemq.artemis.core.server.ServerConsumer;
 import org.apache.activemq.artemis.core.server.ServerSession;
 import org.apache.activemq.artemis.core.server.SlowConsumerDetectionListener;
-import org.apache.activemq.artemis.core.server.TempQueueObserver;
+import org.apache.activemq.artemis.core.server.TempResourceObserver;
 import org.apache.activemq.artemis.core.server.impl.RefsOperation;
+import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.core.transaction.ResourceManager;
 import org.apache.activemq.artemis.core.transaction.Transaction;
 import org.apache.activemq.artemis.core.transaction.TransactionOperationAbstract;
@@ -84,6 +87,7 @@ import org.apache.activemq.artemis.utils.collections.ConcurrentHashSet;
 import org.apache.activemq.command.ActiveMQDestination;
 import org.apache.activemq.command.ActiveMQMessage;
 import org.apache.activemq.command.ActiveMQTempQueue;
+import org.apache.activemq.command.ActiveMQTempTopic;
 import org.apache.activemq.command.ActiveMQTopic;
 import org.apache.activemq.command.BrokerInfo;
 import org.apache.activemq.command.BrokerSubscriptionInfo;
@@ -133,7 +137,7 @@ import org.slf4j.LoggerFactory;
 /**
  * Represents an activemq connection.
  */
-public class OpenWireConnection extends AbstractRemotingConnection implements SecurityAuth, TempQueueObserver {
+public class OpenWireConnection extends AbstractRemotingConnection implements SecurityAuth, TempResourceObserver {
 
 
    private final Object lockSend = new Object();
@@ -174,18 +178,16 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    private volatile boolean noLocal;
 
    /**
-    * Openwire doesn't sen transactions associated with any sessions.
-    * It will however send beingTX / endTX as it would be doing it with XA Transactions.
-    * But always without any association with Sessions.
-    * This collection will hold nonXA transactions. Hopefully while they are in transit only.
+    * Openwire doesn't sen transactions associated with any sessions. It will however send beingTX / endTX as it would
+    * be doing it with XA Transactions. But always without any association with Sessions. This collection will hold
+    * nonXA transactions. Hopefully while they are in transit only.
     */
    private final Map<TransactionId, Transaction> txMap = new ConcurrentHashMap<>();
 
    private final ActiveMQServer server;
 
    /**
-    * This is to be used with connection operations that don't have a session.
-    * Such as TM operations.
+    * This is to be used with connection operations that don't have a session. Such as TM operations.
     */
    private ServerSession internalSession;
 
@@ -207,6 +209,14 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
 
    private String validatedUser = null;
 
+   public void block() {
+      openWireActor.pauseProcessing();
+   }
+
+   public void unblock() {
+      openWireActor.resumeProcessing();
+   }
+
    public OpenWireConnection(Connection connection,
                              ActiveMQServer server,
                              OpenWireProtocolManager openWireProtocolManager,
@@ -283,13 +293,6 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       LAST_SENT_UPDATER.lazySet(this, System.currentTimeMillis());
    }
 
-   /**
-    * Log packaged into a separate method for performance reasons.
-    */
-   private static void traceBufferReceived(Object connectionID, Command command) {
-      logger.trace("connectionID: {} RECEIVED: {}", connectionID, (command == null ? "NULL" : command));
-   }
-
    @Override
    public void bufferReceived(Object connectionID, ActiveMQBuffer buffer) {
       super.bufferReceived(connectionID, buffer);
@@ -297,10 +300,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       try {
          Command command = (Command) inWireFormat.unmarshal(buffer);
 
-         // log the openwire command
-         if (logger.isTraceEnabled()) {
-            traceBufferReceived(connectionID, command);
-         }
+         logCommand(command, true);
 
          final ThresholdActor<Command> localVisibleActor = openWireActor;
          if (localVisibleActor != null) {
@@ -373,8 +373,8 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
                setLastCommand(null);
             }
 
-            if (response instanceof ExceptionResponse) {
-               Throwable cause = ((ExceptionResponse)response).getException();
+            if (response instanceof ExceptionResponse exceptionResponse) {
+               Throwable cause = exceptionResponse.getException();
                if (!responseRequired) {
                   serviceException(cause);
                   response = null;
@@ -413,7 +413,9 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       }
    }
 
-   /** It will send the response through the operation context, as soon as everything is confirmed on disk */
+   /**
+    * It will send the response through the operation context, as soon as everything is confirmed on disk
+    */
    private void sendAsyncResponse(final int commandId, final Response response) throws Exception {
       if (response != null) {
          operationContext.executeOnCompletion(new IOCallback() {
@@ -526,21 +528,12 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       return state;
    }
 
-   /**
-    * Log packaged into a separate method for performance reasons.
-    */
-   private static void tracePhysicalSend(Connection transportConnection, Command command) {
-      logger.trace("connectionID: {} SENDING: {}", (transportConnection == null ? "" : transportConnection.getID()), (command == null ? "NULL" : command));
-   }
-
    public void physicalSend(Command command) throws IOException {
       if (this.protocolManager.invokeOutgoing(command, this) != null) {
          return;
       }
 
-      if (logger.isTraceEnabled()) {
-         tracePhysicalSend(transportConnection, command);
-      }
+      logCommand(command, false);
 
       try {
          final ByteSequence bytes = outWireFormat.marshal(command);
@@ -708,6 +701,10 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    }
 
    private void disconnect(ActiveMQException me, String reason, boolean fail) {
+      ThresholdActor<Command> localActor = openWireActor;
+      if (localActor != null) {
+         localActor.flush();
+      }
 
       if (context == null || destroyed) {
          return;
@@ -762,7 +759,6 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
 
    @Override
    public void fail(ActiveMQException me, String message) {
-
       final ThresholdActor<Command> localVisibleActor = openWireActor;
       if (localVisibleActor != null) {
          localVisibleActor.requestShutdown();
@@ -886,8 +882,8 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    }
 
    private static int getSize(Command command) {
-      if (command instanceof ActiveMQMessage) {
-         return ((ActiveMQMessage) command).getSize();
+      if (command instanceof ActiveMQMessage activeMQMessage) {
+         return activeMQMessage.getSize();
       } else {
          return MINIMAL_SIZE_ESTIAMTE;
       }
@@ -991,7 +987,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
          ss.addConsumer(info);
          info.setLastDeliveredSequenceId(RemoveInfo.LAST_DELIVERED_UNKNOWN);
 
-         if (consumersList.size() == 0) {
+         if (consumersList.isEmpty()) {
             return;
          }
 
@@ -1041,7 +1037,10 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    }
 
    public void addKnownDestination(final SimpleString address) {
-      knownDestinations.add(address);
+      AddressSettings addressSettings = server.getAddressSettingsRepository().getMatch(address.toString());
+      if (!addressSettings.isAutoDeleteAddresses() && !addressSettings.isAutoDeleteQueues()) {
+         knownDestinations.add(address);
+      }
    }
 
    public boolean containsKnownDestination(final SimpleString address) {
@@ -1049,11 +1048,19 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    }
 
    @Override
-   public void tempQueueDeleted(SimpleString bindingName) {
-      ActiveMQDestination dest = new ActiveMQTempQueue(bindingName.toString());
+   public void tempQueueDeleted(SimpleString queueName) {
+      tempDestinationDeleted(queueName, new ActiveMQTempQueue(queueName.toString()));
+   }
+
+   @Override
+   public void tempAddressDeleted(SimpleString addressName) {
+      tempDestinationDeleted(addressName, new ActiveMQTempTopic(addressName.toString()));
+   }
+
+   private void tempDestinationDeleted(SimpleString name, ActiveMQDestination dest) {
       state.removeTempDestination(dest);
       if (logger.isDebugEnabled()) {
-         logger.debug("{} removed temp destination from state: {} ; {}", this, bindingName, state.getTempDestinations().size());
+         logger.debug("{} removed temp destination from state: {} ; {}", this, name, state.getTempDestinations().size());
       }
 
       if (!AdvisorySupport.isAdvisoryTopic(dest)) {
@@ -1109,8 +1116,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
 
       @Override
       public void onSlowConsumer(ServerConsumer consumer) {
-         if (consumer.getProtocolData() != null && consumer.getProtocolData() instanceof AMQConsumer) {
-            AMQConsumer amqConsumer = (AMQConsumer) consumer.getProtocolData();
+         if (consumer.getProtocolData() != null && consumer.getProtocolData() instanceof AMQConsumer amqConsumer) {
             ActiveMQTopic topic = AdvisorySupport.getSlowConsumerAdvisoryTopic(amqConsumer.getOpenwireDestination());
             ActiveMQMessage advisoryMessage = new ActiveMQMessage();
             try {
@@ -1152,19 +1158,23 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    }
 
    public void removeDestination(ActiveMQDestination dest) throws Exception {
+      if (!dest.isTemporary()) {
+         // this should not really happen so I'm not creating a Logger for this
+         logger.warn("OpenWire client sending a queue remove towards {}", dest.getPhysicalName());
+      }
       if (dest.isQueue()) {
-
-         if (!dest.isTemporary()) {
-            // this should not really happen,
-            // so I'm not creating a Logger for this
-            logger.warn("OpenWire client sending a queue remove towards {}", dest.getPhysicalName());
-         }
          try {
             server.destroyQueue(SimpleString.of(dest.getPhysicalName()), getRemotingConnection());
          } catch (ActiveMQNonExistentQueueException neq) {
             //this is ok, ActiveMQ 5 allows this and will actually do it quite often
             logger.debug("queue never existed");
          }
+      } else {
+         try {
+            server.removeAddressInfo(SimpleString.of(dest.getPhysicalName()), getRemotingConnection(), true);
+         } catch (ActiveMQAddressDoesNotExistException neq) {
+            logger.debug("address never existed");
+         }
       }
 
       if (!AdvisorySupport.isAdvisoryTopic(dest)) {
@@ -1256,18 +1266,21 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
 
          // Avoid replaying dup commands
          if (!ss.getProducerIds().contains(info.getProducerId())) {
-            ActiveMQDestination destination = info.getDestination();
+            final ActiveMQDestination destination = info.getDestination();
+            final AMQSession session = getSession(info.getProducerId().getParentId());
 
-            if (destination != null && !AdvisorySupport.isAdvisoryTopic(destination)) {
-               OpenWireConnection.this.addDestination(new DestinationInfo(getContext().getConnectionId(), DestinationInfo.ADD_OPERATION_TYPE, destination));
+            if (destination != null) {
+               session.checkDestinationForSendPermission(destination);
+
+               if (!AdvisorySupport.isAdvisoryTopic(destination)) {
+                  OpenWireConnection.this.addDestination(new DestinationInfo(getContext().getConnectionId(), DestinationInfo.ADD_OPERATION_TYPE, destination));
+               }
             }
 
             ss.addProducer(info);
-            getSession(info.getProducerId().getParentId()).getCoreSession().addProducer(
-                  info.getProducerId().toString(),
-                  OpenWireProtocolManagerFactory.OPENWIRE_PROTOCOL_NAME,
-                  info.getDestination() != null ? info.getDestination().getPhysicalName() : null);
-
+            session.getCoreSession().addProducer(info.getProducerId().toString(),
+                                                 OpenWireProtocolManagerFactory.OPENWIRE_PROTOCOL_NAME,
+                                                 info.getDestination() != null ? info.getDestination().getPhysicalName() : null);
          }
          return null;
       }
@@ -1419,8 +1432,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       }
 
       /**
-       * Openwire will redeliver rolled back references.
-       * We need to return those here.
+       * Openwire will redeliver rolled back references. We need to return those here.
        */
       private void returnReferences(Transaction tx, AMQSession session) throws Exception {
          if (session == null || session.isClosed()) {
@@ -1485,7 +1497,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       @Override
       public Response processAddSession(SessionInfo info) throws Exception {
          // Avoid replaying dup commands
-         if (!state.getSessionIds().contains(info.getSessionId())) {
+         if (state != null && !state.getSessionIds().contains(info.getSessionId())) {
             addSession(info);
             state.addSession(info);
          }
@@ -1908,4 +1920,25 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    public CoreMessageObjectPools getCoreMessageObjectPools() {
       return coreMessageObjectPools;
    }
+
+   public void logCommand(Command command, boolean in) {
+      if (logger.isTraceEnabled()) {
+         StringBuilder message = new StringBuilder()
+            .append("OpenWire(")
+            .append(getRemoteAddress())
+            .append(", ")
+            .append(this.getID())
+            .append("):");
+
+         if (in) {
+            message.append(" IN << ");
+         } else {
+            message.append("OUT >> ");
+         }
+
+         message.append((Objects.requireNonNullElse(command, "NULL")));
+
+         logger.trace(message.toString());
+      }
+   }
 }
