@@ -18,6 +18,7 @@ package org.apache.activemq.artemis.core.protocol.openwire;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -55,7 +56,7 @@ public class OpenWireMessageConverterTest {
 
    final OpenWireFormatFactory formatFactory = new OpenWireFormatFactory();
    final WireFormat openWireFormat =  formatFactory.createWireFormat();
-   final byte[] content = new byte[] {'a','a'};
+   final byte[] content = new byte[] {'a', 'a'};
    final String address = "Q";
    final ActiveMQDestination destination = new ActiveMQQueue(address);
    final UUID nodeUUID = UUIDGenerator.getInstance().generateUUID();
@@ -119,7 +120,7 @@ public class OpenWireMessageConverterTest {
 
       MessageDispatch messageDispatch = OpenWireMessageConverter.createMessageDispatch(messageReference, coreMessage, openWireFormat, amqConsumer, nodeUUID, 0);
 
-      assertTrue(messageDispatch.getMessage().getProperty(bytesPropertyKey) instanceof String);
+      assertInstanceOf(String.class, messageDispatch.getMessage().getProperty(bytesPropertyKey));
    }
 
    @Test
@@ -187,7 +188,7 @@ public class OpenWireMessageConverterTest {
 
    @Test
    public void testStringCorrelationId() throws Exception {
-      final String CORRELATION_ID = RandomUtil.randomString();
+      final String CORRELATION_ID = RandomUtil.randomUUIDString();
 
       ICoreMessage coreMessage = new CoreMessage().initBuffer(8);
       coreMessage.setCorrelationID(CORRELATION_ID);
@@ -200,7 +201,7 @@ public class OpenWireMessageConverterTest {
 
    @Test
    public void testBytesCorrelationId() throws Exception {
-      final byte[] CORRELATION_ID = RandomUtil.randomString().getBytes(StandardCharsets.UTF_8);
+      final byte[] CORRELATION_ID = RandomUtil.randomUUIDString().getBytes(StandardCharsets.UTF_8);
 
       ICoreMessage coreMessage = new CoreMessage().initBuffer(8);
       coreMessage.setCorrelationID(CORRELATION_ID);
@@ -226,7 +227,7 @@ public class OpenWireMessageConverterTest {
 
    @Test
    public void testLegacyCorrelationId() throws Exception {
-      final String CORRELATION_ID = RandomUtil.randomString();
+      final String CORRELATION_ID = RandomUtil.randomUUIDString();
 
       ICoreMessage coreMessage = new CoreMessage().initBuffer(8);
       coreMessage.putStringProperty(OpenWireConstants.JMS_CORRELATION_ID_PROPERTY, SimpleString.of(CORRELATION_ID));
@@ -272,7 +273,7 @@ public class OpenWireMessageConverterTest {
 
    @Test
    public void testLegacyOriginalDestination() throws Exception {
-      final String DESTINATION = RandomUtil.randomString().replace("-", "");
+      final String DESTINATION = RandomUtil.randomUUIDString().replace("-", "");
 
       ActiveMQMessage classicMessage = new ActiveMQMessage();
       classicMessage.setOriginalDestination(new ActiveMQQueue(DESTINATION));
@@ -289,7 +290,7 @@ public class OpenWireMessageConverterTest {
 
    @Test
    public void testLegacyReplyTo() throws Exception {
-      final String DESTINATION = RandomUtil.randomString().replace("-", "");
+      final String DESTINATION = RandomUtil.randomUUIDString().replace("-", "");
 
       ActiveMQMessage classicMessage = new ActiveMQMessage();
       classicMessage.setJMSReplyTo(new ActiveMQQueue(DESTINATION));
