@@ -16,6 +16,7 @@
  */
 package org.apache.activemq.artemis.core.protocol.stomp;
 
+import java.lang.invoke.MethodHandles;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -24,7 +25,9 @@ import java.util.Set;
 import java.util.concurrent.BlockingDeque;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.LinkedBlockingDeque;
+import java.util.concurrent.atomic.AtomicInteger;
 
+import io.netty.channel.EventLoop;
 import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
 import org.apache.activemq.artemis.api.core.ActiveMQQueueExistsException;
 import org.apache.activemq.artemis.api.core.ICoreMessage;
@@ -41,6 +44,7 @@ import org.apache.activemq.artemis.core.server.LargeServerMessage;
 import org.apache.activemq.artemis.core.server.MessageReference;
 import org.apache.activemq.artemis.core.server.Queue;
 import org.apache.activemq.artemis.core.server.ServerConsumer;
+import org.apache.activemq.artemis.core.server.ServerProducer;
 import org.apache.activemq.artemis.core.server.ServerSession;
 import org.apache.activemq.artemis.core.server.impl.ServerSessionImpl;
 import org.apache.activemq.artemis.spi.core.protocol.RemotingConnection;
@@ -52,14 +56,18 @@ import org.apache.activemq.artemis.utils.PendingTask;
 import org.apache.activemq.artemis.utils.UUIDGenerator;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import java.lang.invoke.MethodHandles;
 
 import static org.apache.activemq.artemis.core.protocol.stomp.ActiveMQStompProtocolMessageBundle.BUNDLE;
+import static org.apache.activemq.artemis.core.protocol.stomp.StompProtocolManagerFactory.STOMP_PROTOCOL_NAME;
 
 public class StompSession implements SessionCallback {
 
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
+   private final String senderName = UUIDGenerator.getInstance().generateUUID().toString();
+
+   private boolean createProducer = true;
+
    private final StompProtocolManager manager;
 
    private final StompConnection connection;
@@ -72,13 +80,15 @@ public class StompSession implements SessionCallback {
 
    private final Map<Long, StompSubscription> subscriptions = new ConcurrentHashMap<>();
 
-   // key = message ID, value = consumer ID
-   private final Map<Long, Pair<Long, Integer>> messagesToAck = new ConcurrentHashMap<>();
+   // key = consumer ID and message ID, value = frame length
+   private final Map<Pair<Long, Long>, Integer> messagesToAck = new ConcurrentHashMap<>();
 
-   private volatile boolean noLocal = false;
+   private AtomicInteger noLocalSubscriptionCount = new AtomicInteger(0);
 
    private boolean txPending = false;
 
+   private final EventLoop eventLoop;
+
    public synchronized void begin() {
       txPending = true;
    }
@@ -95,6 +105,7 @@ public class StompSession implements SessionCallback {
       this.connection = connection;
       this.manager = manager;
       this.sessionContext = sessionContext;
+      eventLoop = connection.getTransportConnection().getEventLoop();
    }
 
    @Override
@@ -147,29 +158,22 @@ public class StompSession implements SessionCallback {
    }
 
    @Override
-   public int sendMessage(MessageReference ref,
-                          Message serverMessage,
-                          final ServerConsumer consumer,
-                          int deliveryCount) {
-
-      ICoreMessage  coreMessage = serverMessage.toCore();
-
-      ICoreMessage newServerMessage = serverMessage.toCore();
+   public int sendMessage(MessageReference ref, final ServerConsumer consumer, int deliveryCount) {
+      ICoreMessage message = ref.getMessage().toCore();
       try {
          StompSubscription subscription = subscriptions.get(consumer.getID());
          // subscription might be null if the consumer was closed
          if (subscription == null)
             return 0;
          StompFrame frame;
-         ActiveMQBuffer buffer = coreMessage.getDataBuffer();
 
-         frame = connection.createStompMessage(newServerMessage, buffer, subscription, deliveryCount);
+         frame = connection.createStompMessage(message, subscription, consumer, deliveryCount);
 
          int length = frame.getEncodedSize();
 
          if (subscription.getAck().equals(Stomp.Headers.Subscribe.AckModeValues.AUTO)) {
             if (manager.send(connection, frame)) {
-               final long messageID = newServerMessage.getMessageID();
+               final long messageID = message.getMessageID();
                final long consumerID = consumer.getID();
 
                // this will be called after the delivery is complete
@@ -178,22 +182,27 @@ public class StompSession implements SessionCallback {
                afterDeliveryTasks.offer(new PendingTask() {
                   @Override
                   public void run() throws Exception {
-                     //we ack and commit only if the send is successful
-                     session.acknowledge(consumerID, messageID);
-                     session.commit();
+                     eventLoop.execute(() -> {
+                        try {
+                           //we ack and commit only if the send is successful
+                           session.acknowledge(consumerID, messageID);
+                           session.commit();
+                        } catch (Throwable e) {
+                           logger.warn(e.getMessage(), e);
+                        }
+                     });
                   }
                });
             }
          } else {
-            messagesToAck.put(newServerMessage.getMessageID(), new Pair<>(consumer.getID(), length));
+            messagesToAck.put(new Pair<>(consumer.getID(), message.getMessageID()), length);
             // Must send AFTER adding to messagesToAck - or could get acked from client BEFORE it's been added!
             manager.send(connection, frame);
          }
 
          return length;
       } catch (Exception e) {
-         logger.debug("exception in sendMessage", e);
-
+         ActiveMQStompProtocolLogger.LOGGER.unableToSendMessageToClient(message, e);
          return 0;
       }
    }
@@ -208,7 +217,6 @@ public class StompSession implements SessionCallback {
 
    @Override
    public int sendLargeMessage(MessageReference ref,
-                               Message msg,
                                ServerConsumer consumer,
                                long bodySize,
                                int deliveryCount) {
@@ -217,12 +225,16 @@ public class StompSession implements SessionCallback {
 
    @Override
    public void closed() {
+      session.removeProducer(senderName);
    }
 
    @Override
-   public void disconnect(ServerConsumer consumerId, SimpleString queueName) {
+   public void disconnect(ServerConsumer consumerId, String errorDescription) {
       StompSubscription stompSubscription = subscriptions.remove(consumerId.getID());
       if (stompSubscription != null) {
+         if (stompSubscription.isNoLocal()) {
+            noLocalSubscriptionCount.decrementAndGet();
+         }
          StompFrame frame = connection.getFrameHandler().createStompFrame(Stomp.Responses.ERROR);
          frame.addHeader(Stomp.Headers.CONTENT_TYPE, "text/plain");
          frame.setBody("consumer with ID " + consumerId + " disconnected by server");
@@ -230,15 +242,27 @@ public class StompSession implements SessionCallback {
       }
    }
 
-   public void acknowledge(String messageID, String subscriptionID) throws Exception {
-      long id = Long.parseLong(messageID);
-      Pair<Long, Integer> pair = messagesToAck.get(id);
+   public static final char MESSAGE_ID_SEPARATOR = ',';
 
-      if (pair == null) {
-         throw BUNDLE.failToAckMissingID(id).setHandler(connection.getFrameHandler());
+   private static Pair<Long, Long> splitAndParse(String stompMessageID) {
+      int separatorPosition = stompMessageID.indexOf(MESSAGE_ID_SEPARATOR);
+      if (separatorPosition == -1)
+         return null;
+      long consumerID = Long.parseLong(stompMessageID, 0, separatorPosition, 10);
+      long messageID = Long.parseLong(stompMessageID, separatorPosition + 1, stompMessageID.length(), 10);
+      return new Pair<>(consumerID, messageID);
+   }
+
+   public void acknowledge(String messageID, String subscriptionID) throws Exception {
+      Pair<Long, Long> pair = splitAndParse(messageID);
+      Integer length = messagesToAck.remove(pair);
+
+      if (length == null) {
+         throw BUNDLE.failToAckMissingID(messageID).setHandler(connection.getFrameHandler());
       }
 
       long consumerID = pair.getA();
+      long id = pair.getB();
 
       StompSubscription sub = subscriptions.get(consumerID);
 
@@ -252,14 +276,26 @@ public class StompSession implements SessionCallback {
          session.individualAcknowledge(consumerID, id);
 
          if (sub.getConsumerWindowSize() != -1) {
-            session.receiveConsumerCredits(consumerID, messagesToAck.remove(id).getB());
+            session.receiveConsumerCredits(consumerID, length);
          }
       } else {
          List<Long> ackedRefs = session.acknowledge(consumerID, id);
 
          if (sub.getConsumerWindowSize() != -1) {
+            session.receiveConsumerCredits(consumerID, length);
             for (Long ackedID : ackedRefs) {
-               session.receiveConsumerCredits(consumerID, messagesToAck.remove(ackedID).getB());
+               if (ackedID != id) {
+                  length = messagesToAck.remove(new Pair<>(consumerID, ackedID));
+                  if (length != null) {
+                     session.receiveConsumerCredits(consumerID, length);
+                  }
+               }
+            }
+         } else {
+            for (Long ackedID : ackedRefs) {
+               if (ackedID != id) {
+                  messagesToAck.remove(new Pair<>(consumerID, ackedID));
+               }
             }
          }
       }
@@ -274,10 +310,11 @@ public class StompSession implements SessionCallback {
                                                    String destination,
                                                    String selector,
                                                    String ack,
+                                                   boolean noLocal,
                                                    Integer consumerWindowSize) throws Exception {
-      SimpleString address = SimpleString.toSimpleString(destination);
-      SimpleString queueName = SimpleString.toSimpleString(destination);
-      SimpleString selectorSimple = SimpleString.toSimpleString(selector);
+      SimpleString address = SimpleString.of(destination);
+      SimpleString queueName = SimpleString.of(destination);
+      SimpleString selectorSimple = SimpleString.of(selector);
       final int finalConsumerWindowSize;
 
       if (consumerWindowSize != null) {
@@ -297,21 +334,24 @@ public class StompSession implements SessionCallback {
             if (clientID == null) {
                throw BUNDLE.missingClientID();
             }
-            queueName = SimpleString.toSimpleString(clientID + "." + durableSubscriptionName);
+            queueName = SimpleString.of(clientID + "." + durableSubscriptionName);
             if (manager.getServer().locateQueue(queueName) == null) {
                try {
-                  session.createQueue(new QueueConfiguration(queueName).setAddress(address).setFilterString(selectorSimple));
+                  session.createQueue(QueueConfiguration.of(queueName).setAddress(address).setFilterString(selectorSimple));
                } catch (ActiveMQQueueExistsException e) {
                   // ignore; can be caused by concurrent durable subscribers
                }
             }
          } else {
             queueName = UUIDGenerator.getInstance().generateSimpleStringUUID();
-            session.createQueue(new QueueConfiguration(queueName).setAddress(address).setFilterString(selectorSimple).setDurable(false).setTemporary(true));
+            session.createQueue(QueueConfiguration.of(queueName).setAddress(address).setFilterString(selectorSimple).setDurable(false).setTemporary(true));
          }
       }
+      if (noLocal) {
+         noLocalSubscriptionCount.incrementAndGet();
+      }
       final ServerConsumer consumer = session.createConsumer(consumerID, queueName, multicast ? null : selectorSimple, false, false, 0);
-      StompSubscription subscription = new StompSubscription(subscriptionID, ack, queueName, multicast, finalConsumerWindowSize);
+      StompSubscription subscription = new StompSubscription(subscriptionID, ack, queueName, multicast, noLocal, finalConsumerWindowSize);
       subscriptions.put(consumerID, subscription);
       session.start();
       /*
@@ -331,6 +371,9 @@ public class StompSession implements SessionCallback {
          StompSubscription sub = entry.getValue();
          if (id != null && id.equals(sub.getID())) {
             iterator.remove();
+            if (sub.isNoLocal()) {
+               noLocalSubscriptionCount.decrementAndGet();
+            }
             SimpleString queueName = sub.getQueueName();
             session.closeConsumer(consumerID);
             Queue queue = manager.getServer().locateQueue(queueName);
@@ -342,7 +385,7 @@ public class StompSession implements SessionCallback {
       }
 
       if (durableSubscriptionName != null && clientID != null) {
-         SimpleString queueName = SimpleString.toSimpleString(clientID + "." + durableSubscriptionName);
+         SimpleString queueName = SimpleString.of(clientID + "." + durableSubscriptionName);
          if (manager.getServer().locateQueue(queueName) != null) {
             session.deleteQueue(queueName);
          }
@@ -370,19 +413,27 @@ public class StompSession implements SessionCallback {
       return sessionContext;
    }
 
-   public boolean isNoLocal() {
-      return noLocal;
+   public int getNoLocalSubscriptionCount() {
+      return noLocalSubscriptionCount.get();
    }
 
-   public void setNoLocal(boolean noLocal) {
-      this.noLocal = noLocal;
+   public int getSubscriptionCount() {
+      return subscriptions.size();
    }
 
    public void sendInternal(Message message, boolean direct) throws Exception {
-      session.send(message, direct);
+      if (createProducer) {
+         session.addProducer(senderName, STOMP_PROTOCOL_NAME, ServerProducer.ANONYMOUS);
+         createProducer = false;
+      }
+      session.send(message, direct, senderName);
    }
 
    public void sendInternalLarge(CoreMessage message, boolean direct) throws Exception {
+      if (createProducer) {
+         session.addProducer(senderName, STOMP_PROTOCOL_NAME, ServerProducer.ANONYMOUS);
+         createProducer = false;
+      }
       int headerSize = message.getHeadersAndPropertiesEncodeSize();
       if (headerSize >= connection.getMinLargeMessageSize()) {
          throw BUNDLE.headerTooBig();
@@ -390,7 +441,7 @@ public class StompSession implements SessionCallback {
 
       StorageManager storageManager = ((ServerSessionImpl) session).getStorageManager();
       long id = storageManager.generateID();
-      LargeServerMessage largeMessage = storageManager.createLargeMessage(id, message);
+      LargeServerMessage largeMessage = storageManager.createCoreLargeMessage(id, message);
 
       ActiveMQBuffer body = message.getReadOnlyBodyBuffer();
       byte[] bytes = new byte[body.readableBytes()];
@@ -402,7 +453,7 @@ public class StompSession implements SessionCallback {
 
       largeMessage.toMessage().putLongProperty(Message.HDR_LARGE_BODY_SIZE, bytes.length);
 
-      session.send(largeMessage.toMessage(), direct);
+      session.send(largeMessage.toMessage(), direct, senderName);
    }
 
 }
