@@ -28,58 +28,33 @@ import javax.security.auth.Subject;
 import java.io.PrintWriter;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 
 import org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory;
 import org.apache.activemq.artemis.service.extensions.xa.recovery.XARecoveryConfig;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
-/**
- * ActiveMQ Artemis ManagedConnectionFactory
- */
 public final class ActiveMQRAManagedConnectionFactory implements ManagedConnectionFactory, ResourceAdapterAssociation {
 
-   /**
-    * Serial version UID
-    */
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
+
    static final long serialVersionUID = -1452379518562456741L;
 
-   /**
-    * The resource adapter
-    */
    private ActiveMQResourceAdapter ra;
 
-   /**
-    * Connection manager
-    */
    private ConnectionManager cm;
 
-   /**
-    * The managed connection factory properties
-    */
    private final ActiveMQRAMCFProperties mcfProperties;
 
-   /**
-    * Connection Factory used if properties are set
-    */
    private ActiveMQConnectionFactory recoveryConnectionFactory;
 
-   /**
-    * The resource recovery if there is one
-    */
    private XARecoveryConfig resourceRecovery;
 
-   /**
-    * Used to configure whether the connection should be part of the JTA TX. This is when the RA doesn not have access to the Transaction manager to deduct whether this is the case.
-    */
-   private boolean inJtaTransaction;
-
-   /**
-    * Constructor
-    */
    public ActiveMQRAManagedConnectionFactory() {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("constructor()");
-      }
+      logger.trace("constructor()");
 
       ra = null;
       cm = null;
@@ -87,73 +62,48 @@ public final class ActiveMQRAManagedConnectionFactory implements ManagedConnecti
    }
 
    /**
-    * Creates a Connection Factory instance
-    *
-    * @return javax.resource.cci.ConnectionFactory instance
-    * @throws ResourceException Thrown if a connection factory can't be created
+    * {@inheritDoc}
     */
    @Override
    public Object createConnectionFactory() throws ResourceException {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.debug("createConnectionFactory()");
-      }
+      logger.debug("createConnectionFactory()");
 
       return createConnectionFactory(new ActiveMQRAConnectionManager());
    }
 
    /**
-    * Creates a Connection Factory instance
-    *
-    * @param cxManager The connection manager
-    * @return javax.resource.cci.ConnectionFactory instance
-    * @throws ResourceException Thrown if a connection factory can't be created
+    * {@inheritDoc}
     */
    @Override
    public Object createConnectionFactory(final ConnectionManager cxManager) throws ResourceException {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("createConnectionFactory(" + cxManager + ")");
-      }
+      logger.trace("createConnectionFactory({})", cxManager);
 
       cm = cxManager;
 
       ActiveMQRAConnectionFactory cf = new ActiveMQRAConnectionFactoryImpl(this, cm);
 
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("Created connection factory: " + cf +
-                                          ", using connection manager: " +
-                                          cm);
-      }
+      logger.trace("Created connection factory: {}, using connection manager: {}", cf, cm);
+
       return cf;
    }
 
    /**
-    * Creates a new physical connection to the underlying EIS resource manager.
-    *
-    * @param subject       Caller's security information
-    * @param cxRequestInfo Additional resource adapter specific connection request information
-    * @return The managed connection
-    * @throws ResourceException Thrown if a managed connection can't be created
+    * {@inheritDoc}
     */
    @Override
    public ManagedConnection createManagedConnection(final Subject subject,
                                                     final ConnectionRequestInfo cxRequestInfo) throws ResourceException {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("createManagedConnection(" + subject + ", " + cxRequestInfo + ")");
-      }
+      logger.trace("createManagedConnection({}, {})", subject, cxRequestInfo);
 
       ActiveMQRAConnectionRequestInfo cri = getCRI((ActiveMQRAConnectionRequestInfo) cxRequestInfo);
 
       ActiveMQRACredential credential = ActiveMQRACredential.getCredential(this, subject, cri);
 
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("jms credential: " + credential);
-      }
+      logger.trace("jms credential: {}", credential);
 
       ActiveMQRAManagedConnection mc = new ActiveMQRAManagedConnection(this, cri, ra, credential.getUserName(), credential.getPassword());
 
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("created new managed connection: " + mc);
-      }
+      logger.trace("created new managed connection: {}", mc);
 
       registerRecovery();
 
@@ -175,44 +125,28 @@ public final class ActiveMQRAManagedConnectionFactory implements ManagedConnecti
    }
 
    /**
-    * Returns a matched connection from the candidate set of connections.
-    *
-    * @param connectionSet The candidate connection set
-    * @param subject       Caller's security information
-    * @param cxRequestInfo Additional resource adapter specific connection request information
-    * @return The managed connection
-    * @throws ResourceException Thrown if the managed connection can not be found
+    * {@inheritDoc}
     */
    @Override
    public ManagedConnection matchManagedConnections(final Set connectionSet,
                                                     final Subject subject,
                                                     final ConnectionRequestInfo cxRequestInfo) throws ResourceException {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("matchManagedConnections(" + connectionSet +
-                                          ", " +
-                                          subject +
-                                          ", " +
-                                          cxRequestInfo +
-                                          ")");
+      if (logger.isTraceEnabled()) {
+         logger.trace("matchManagedConnections({}, {}, {})", connectionSet, subject, cxRequestInfo);
       }
 
       ActiveMQRAConnectionRequestInfo cri = getCRI((ActiveMQRAConnectionRequestInfo) cxRequestInfo);
       ActiveMQRACredential credential = ActiveMQRACredential.getCredential(this, subject, cri);
 
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("Looking for connection matching credentials: " + credential);
-      }
+      logger.trace("Looking for connection matching credentials: {}", credential);
 
       for (Object obj : connectionSet) {
-         if (obj instanceof ActiveMQRAManagedConnection) {
-            ActiveMQRAManagedConnection mc = (ActiveMQRAManagedConnection) obj;
+         if (obj instanceof ActiveMQRAManagedConnection mc) {
             ManagedConnectionFactory mcf = mc.getManagedConnectionFactory();
 
             if ((mc.getUserName() == null || mc.getUserName() != null && mc.getUserName().equals(credential.getUserName())) && mcf.equals(this)) {
                if (cri.equals(mc.getCRI())) {
-                  if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-                     ActiveMQRALogger.LOGGER.trace("Found matching connection: " + mc);
-                  }
+                  logger.trace("Found matching connection: {}", mc);
 
                   return mc;
                }
@@ -220,51 +154,39 @@ public final class ActiveMQRAManagedConnectionFactory implements ManagedConnecti
          }
       }
 
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("No matching connection was found");
-      }
+      logger.trace("No matching connection was found");
 
       return null;
    }
 
    /**
-    * Set the log writer -- NOT SUPPORTED
-    *
-    * @param out The writer
-    * @throws ResourceException Thrown if the writer can't be set
+    * <b>NOT SUPPORTED</b>
+    * <p>
+    * {@inheritDoc}
     */
    @Override
    public void setLogWriter(final PrintWriter out) throws ResourceException {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("setLogWriter(" + out + ")");
-      }
+      logger.trace("setLogWriter({})", out);
    }
 
    /**
-    * Get the log writer -- NOT SUPPORTED
-    *
-    * @return The writer
-    * @throws ResourceException Thrown if the writer can't be retrieved
+    * <b>NOT SUPPORTED</b>
+    * <p>
+    * {@inheritDoc}
     */
    @Override
    public PrintWriter getLogWriter() throws ResourceException {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("getLogWriter()");
-      }
+      logger.trace("getLogWriter()");
 
       return null;
    }
 
    /**
-    * Get the resource adapter
-    *
-    * @return The resource adapter
+    * {@inheritDoc}
     */
    @Override
    public ResourceAdapter getResourceAdapter() {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("getResourceAdapter()");
-      }
+      logger.trace("getResourceAdapter()");
 
       return ra;
    }
@@ -274,18 +196,11 @@ public final class ActiveMQRAManagedConnectionFactory implements ManagedConnecti
    }
 
    /**
-    * Set the resource adapter
-    * <br>
-    * This should ensure that when the RA is stopped, this MCF will be stopped as well.
-    *
-    * @param ra The resource adapter
-    * @throws ResourceException Thrown if incorrect resource adapter
+    * {@inheritDoc}
     */
    @Override
    public void setResourceAdapter(final ResourceAdapter ra) throws ResourceException {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("setResourceAdapter(" + ra + ")");
-      }
+      logger.trace("setResourceAdapter({})", ra);
 
       if (ra == null || !(ra instanceof ActiveMQResourceAdapter)) {
          throw new ResourceException("Resource adapter is " + ra);
@@ -295,57 +210,29 @@ public final class ActiveMQRAManagedConnectionFactory implements ManagedConnecti
       this.ra.setManagedConnectionFactory(this);
    }
 
-   /**
-    * Indicates whether some other object is "equal to" this one.
-    *
-    * @param obj Object with which to compare
-    * @return True if this object is the same as the obj argument; false otherwise.
-    */
    @Override
    public boolean equals(final Object obj) {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("equals(" + obj + ")");
+      logger.trace("equals({})", obj);
+      if (this == obj) {
+         return true;
       }
 
-      if (obj == null) {
+      if (!(obj instanceof ActiveMQRAManagedConnectionFactory other)) {
          return false;
       }
 
-      if (obj instanceof ActiveMQRAManagedConnectionFactory) {
-         ActiveMQRAManagedConnectionFactory other = (ActiveMQRAManagedConnectionFactory) obj;
-
-         return mcfProperties.equals(other.getProperties()) && ra.equals(other.getResourceAdapter());
-      } else {
-         return false;
-      }
+      return Objects.equals(mcfProperties, other.getProperties()) &&
+             Objects.equals(ra, other.getResourceAdapter());
    }
 
-   /**
-    * Return the hash code for the object
-    *
-    * @return The hash code
-    */
    @Override
    public int hashCode() {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("hashCode()");
-      }
-
-      int hash = mcfProperties.hashCode();
-      hash += 31 * (ra != null ? ra.hashCode() : 0);
-
-      return hash;
+      logger.trace("hashCode()");
+      return Objects.hash(mcfProperties, ra);
    }
 
-   /**
-    * Get the default session type
-    *
-    * @return The value
-    */
    public String getSessionDefaultType() {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("getSessionDefaultType()");
-      }
+      logger.trace("getSessionDefaultType()");
 
       return mcfProperties.getSessionDefaultType();
    }
@@ -353,19 +240,14 @@ public final class ActiveMQRAManagedConnectionFactory implements ManagedConnecti
    /**
     * Set the default session type
     *
-    * @param type either javax.jms.Topic or javax.jms.Queue
+    * @param type either {@literal javax.jms.Topic} or {@literal javax.jms.Queue}
     */
    public void setSessionDefaultType(final String type) {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("setSessionDefaultType(" + type + ")");
-      }
+      logger.trace("setSessionDefaultType({})", type);
 
       mcfProperties.setSessionDefaultType(type);
    }
 
-   /**
-    * @return the connectionParameters
-    */
    public String getConnectionParameters() {
       return mcfProperties.getStrConnectionParameters();
    }
@@ -374,9 +256,6 @@ public final class ActiveMQRAManagedConnectionFactory implements ManagedConnecti
       mcfProperties.setConnectionParameters(configuration);
    }
 
-   /**
-    * @return the transportType
-    */
    public String getConnectorClassName() {
       return mcfProperties.getConnectorClassName();
    }
@@ -718,69 +597,56 @@ public final class ActiveMQRAManagedConnectionFactory implements ManagedConnecti
       mcfProperties.setHA(ha);
    }
 
+   public Boolean isCompressLargeMessage() {
+      return mcfProperties.isCompressLargeMessage();
+   }
+
+   public void setCompressLargeMessage(final Boolean compressLargeMessage) {
+      mcfProperties.setCompressLargeMessage(compressLargeMessage);
+   }
+
+   public Integer getCompressionLevel() {
+      return mcfProperties.getCompressionLevel();
+   }
+
+   public void setCompressionLevel(final Integer compressionLevel) {
+      mcfProperties.setCompressionLevel(compressionLevel);
+   }
+
+   public Integer getInitialConnectAttempts() {
+      return mcfProperties.getInitialConnectAttempts();
+   }
+
+   public void setInitialConnectAttempts(final Integer initialConnectAttempts) {
+      mcfProperties.setInitialConnectAttempts(initialConnectAttempts);
+   }
 
-   /**
-    * Get the useTryLock.
-    *
-    * @return the useTryLock.
-    */
    public Integer getUseTryLock() {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("getUseTryLock()");
-      }
+      logger.trace("getUseTryLock()");
 
       return mcfProperties.getUseTryLock();
    }
 
-   /**
-    * Set the useTryLock.
-    *
-    * @param useTryLock the useTryLock.
-    */
    public void setUseTryLock(final Integer useTryLock) {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("setUseTryLock(" + useTryLock + ")");
-      }
+      logger.trace("setUseTryLock({})", useTryLock);
 
       mcfProperties.setUseTryLock(useTryLock);
    }
 
-   /**
-    * Get the connection metadata
-    *
-    * @return The metadata
-    */
    public ConnectionMetaData getMetaData() {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("getMetadata()");
-      }
+      logger.trace("getMetadata()");
 
       return new ActiveMQRAConnectionMetaData();
    }
 
-   /**
-    * Get the managed connection factory properties
-    *
-    * @return The properties
-    */
    protected ActiveMQRAMCFProperties getProperties() {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("getProperties()");
-      }
+      logger.trace("getProperties()");
 
       return mcfProperties;
    }
 
-   /**
-    * Get a connection request info instance
-    *
-    * @param info The instance that should be updated; may be <code>null</code>
-    * @return The instance
-    */
    private ActiveMQRAConnectionRequestInfo getCRI(final ActiveMQRAConnectionRequestInfo info) {
-      if (ActiveMQRALogger.LOGGER.isTraceEnabled()) {
-         ActiveMQRALogger.LOGGER.trace("getCRI(" + info + ")");
-      }
+      logger.trace("getCRI({})", info);
 
       if (info == null) {
          // Create a default one
