@@ -72,7 +72,9 @@ public final class PageSubscriptionImpl implements PageSubscription {
 
    private boolean empty = true;
 
-   /** for tests */
+   /**
+    * for tests
+    */
    public AtomicInteger getScheduledCleanupCount() {
       return scheduledCleanupCount;
    }
@@ -139,6 +141,11 @@ public final class PageSubscriptionImpl implements PageSubscription {
       return pageStore.isPaging();
    }
 
+   @Override
+   public boolean isStorePaging() {
+      return pageStore.isStorePaging();
+   }
+
    @Override
    public void setQueue(Queue queue) {
       this.queue = queue;
@@ -211,9 +218,8 @@ public final class PageSubscriptionImpl implements PageSubscription {
    /**
     * A page marked as complete will be ignored until it's cleared.
     * <p>
-    * Usually paging is a stream of messages but in certain scenarios (such as a pending prepared
-    * TX) we may have big holes on the page streaming, and we will need to ignore such pages on the
-    * cursor/subscription.
+    * Usually paging is a stream of messages but in certain scenarios (such as a pending prepared TX) we may have big
+    * holes on the page streaming, and we will need to ignore such pages on the cursor/subscription.
     */
    @Override
    public boolean reloadPageCompletion(PagePosition position) throws Exception {
@@ -315,14 +321,12 @@ public final class PageSubscriptionImpl implements PageSubscription {
          }
 
          for (PageCursorInfo infoPG : completedPages) {
-            // HORNETQ-1017: There are a few cases where a pending transaction might set a big hole on the page system
-            //               where we need to ignore these pages in case of a restart.
-            //               for that reason when we delete complete ACKs we store a single record per page file that will
-            //               be removed once the page file is deleted
-            //               notice also that this record is added as part of the same transaction where the information is deleted.
-            //               In case of a TX Failure (a crash on the server) this will be recovered on the next cleanup once the
-            //               server is restarted.
-            // first will mark the page as complete
+            // There are a few cases where a pending transaction might set a big hole on the page system where we need
+            // to ignore these pages in case of a restart. For that reason when we delete complete ACKs we store a
+            // single record per page file that will be removed once the page file is deleted notice also that this
+            // record is added as part of the same transaction where the information is deleted. In case of a TX Failure
+            // (a crash on the server) this will be recovered on the next cleanup once the server is restarted. First
+            // will mark the page as complete
             if (isPersistent()) {
                PagePosition completePage = new PagePositionImpl(infoPG.getPageId(), infoPG.getNumberOfMessages());
                infoPG.setCompleteInfo(completePage);
@@ -688,8 +692,6 @@ public final class PageSubscriptionImpl implements PageSubscription {
 
          Collections.sort(recoveredACK);
 
-         long txDeleteCursorOnReload = -1;
-
          for (PagePosition pos : recoveredACK) {
             logger.trace("reloading pos {}", pos);
             lastAckedPosition = pos;
@@ -697,10 +699,6 @@ public final class PageSubscriptionImpl implements PageSubscription {
             pageInfo.loadACK(pos);
          }
 
-         if (txDeleteCursorOnReload >= 0) {
-            store.commit(txDeleteCursorOnReload);
-         }
-
          recoveredACK.clear();
          recoveredACK = null;
       }
@@ -727,6 +725,37 @@ public final class PageSubscriptionImpl implements PageSubscription {
       }
    }
 
+   @Override
+   public void deleteCursorInfo() {
+      logger.debug("Delete consumed Paged on {} with consumedPages size = {}", pageStore.getAddress(), consumedPages.size());
+      consumedPages.forEach(this::deleteCursorInfo);
+      consumedPages.clear();
+   }
+
+   private void deleteCursorInfo(Long page, PageCursorInfo info) {
+      logger.debug("Deleting cursorInfo for page {} info={}, address={}", page, info, pageStore.getAddress());
+      PagePosition completeInfo = info.getCompleteInfo();
+      if (completeInfo != null) {
+         try {
+            store.deletePageComplete(completeInfo.getRecordID());
+         } catch (Exception e) {
+            ActiveMQServerLogger.LOGGER.errorDeletingPageCompleteRecord(e);
+         }
+         info.setCompleteInfo(null);
+      }
+      if (info.acks != null) {
+         for (PagePosition deleteInfo : info.acks.values()) {
+            if (deleteInfo.getRecordID() >= 0) {
+               try {
+                  store.deleteCursorAcknowledge(deleteInfo.getRecordID());
+               } catch (Exception e) {
+                  ActiveMQServerLogger.LOGGER.errorDeletingPageCompleteRecord(e);
+               }
+            }
+         }
+      }
+   }
+
    @Override
    public void onDeletePage(Page deletedPage) throws Exception {
       logger.debug("removing page {}", deletedPage);
@@ -735,26 +764,7 @@ public final class PageSubscriptionImpl implements PageSubscription {
          info = consumedPages.remove(deletedPage.getPageId());
       }
       if (info != null) {
-         PagePosition completeInfo = info.getCompleteInfo();
-         if (completeInfo != null) {
-            try {
-               store.deletePageComplete(completeInfo.getRecordID());
-            } catch (Exception e) {
-               ActiveMQServerLogger.LOGGER.errorDeletingPageCompleteRecord(e);
-            }
-            info.setCompleteInfo(null);
-         }
-         if (info.acks != null) {
-            for (PagePosition deleteInfo : info.acks.values()) {
-               if (deleteInfo.getRecordID() >= 0) {
-                  try {
-                     store.deleteCursorAcknowledge(deleteInfo.getRecordID());
-                  } catch (Exception e) {
-                     ActiveMQServerLogger.LOGGER.errorDeletingPageCompleteRecord(e);
-                  }
-               }
-            }
-         }
+         deleteCursorInfo(deletedPage.getPageId(), info);
       }
       deletedPage.usageExhaust();
    }
@@ -863,8 +873,6 @@ public final class PageSubscriptionImpl implements PageSubscription {
 
    /**
     * A callback from the PageCursorInfo. It will be called when all the messages on a page have been acked
-    *
-    * @param info
     */
    private void onPageDone(final PageCursorInfo info) {
       if (autoCleanup) {
@@ -875,12 +883,11 @@ public final class PageSubscriptionImpl implements PageSubscription {
       }
    }
 
-
    /**
     * This will hold information about the pending ACKs towards a page.
     * <p>
-    * This instance will be released as soon as the entire page is consumed, releasing the memory at
-    * that point The ref counts are increased also when a message is ignored for any reason.
+    * This instance will be released as soon as the entire page is consumed, releasing the memory at that point The ref
+    * counts are increased also when a message is ignored for any reason.
     */
    public final class PageCursorInfo implements ConsumedPage {
 
@@ -904,7 +911,8 @@ public final class PageSubscriptionImpl implements PageSubscription {
       private boolean pendingDelete;
 
       /**
-       * This is to be set when all the messages are complete on a given page, and we cleanup the records that are marked on it
+       * This is to be set when all the messages are complete on a given page, and we cleanup the records that are
+       * marked on it
        */
       private PagePosition completePage;
 
@@ -944,17 +952,13 @@ public final class PageSubscriptionImpl implements PageSubscription {
                " numberOfMessage = " +
                numberOfMessages +
                ", confirmed = " +
-               confirmed +
-               ", isDone=" +
-               this.isDone();
+               confirmed;
          } catch (Exception e) {
             return "PageCursorInfo::pageNr=" + pageId +
                " numberOfMessage = " +
                numberOfMessages +
                ", confirmed = " +
-               confirmed +
-               ", isDone=" +
-               e.toString();
+               confirmed + ", exception = " + e;
          }
       }
 
@@ -980,9 +984,6 @@ public final class PageSubscriptionImpl implements PageSubscription {
          this.acks = null;
       }
 
-      /**
-       * @param completePage
-       */
       public void setCompleteInfo(final PagePosition completePage) {
          if (logger.isTraceEnabled()) {
             logger.trace("Setting up complete page {} on cursor {} on subscription {}", completePage, this, PageSubscriptionImpl.this);
@@ -1002,6 +1003,10 @@ public final class PageSubscriptionImpl implements PageSubscription {
                PageSubscriptionImpl.this, pageId, completePage != null, getNumberOfMessages(), confirmed.get(), pendingTX.get());
          }
 
+         if (!pageStore.isStorePaging()) {
+            return true;
+         }
+
          // in cases where the file was damaged it is possible to get more confirmed records than we actually had messages
          // for that case we set confirmed.get() >= getNumberOfMessages instead of ==
          return completePage != null || (confirmed.get() >= getNumberOfMessages() && pendingTX.get() == 0);
@@ -1015,9 +1020,6 @@ public final class PageSubscriptionImpl implements PageSubscription {
          pendingDelete = true;
       }
 
-      /**
-       * @return the pageId
-       */
       @Override
       public long getPageId() {
          return pageId;
@@ -1087,19 +1089,21 @@ public final class PageSubscriptionImpl implements PageSubscription {
          }
       }
 
-      /**
-       *
-       */
       protected void checkDone() {
-         if (isDone()) {
-            onPageDone(this);
-         }
+         pageStore.execute(() -> {
+            if (isDone()) {
+               onPageDone(this);
+            }
+         });
       }
 
       private int getNumberOfMessages() {
+         if (!pageStore.isStorePaging()) {
+            return 0;
+         }
          if (numberOfMessages < 0) {
             try {
-               Page page = pageStore.usePage(pageId, false);
+               Page page = pageStore.usePage(pageId, true, false);
 
                if (page == null) {
                   page = pageStore.newPageObject(pageId);
@@ -1214,8 +1218,7 @@ public final class PageSubscriptionImpl implements PageSubscription {
       private final java.util.Queue<PagedReference> redeliveries = new LinkedList<>();
 
       /**
-       * next element taken on hasNext test.
-       * it has to be delivered on next next operation
+       * next element taken on hasNext test. it has to be delivered on next next operation
        */
       private volatile PagedReference cachedNext;
 
@@ -1425,7 +1428,7 @@ public final class PageSubscriptionImpl implements PageSubscription {
             return NextResult.hasElements;
          }
 
-         if (!pageStore.isPaging()) {
+         if (!pageStore.isStorePaging()) {
             return NextResult.noElements;
          }
 
@@ -1439,8 +1442,8 @@ public final class PageSubscriptionImpl implements PageSubscription {
       }
 
       /**
-       * QueueImpl::deliver could be calling hasNext while QueueImpl.depage could be using next and hasNext as well.
-       * It would be a rare race condition but I would prefer avoiding that scenario
+       * QueueImpl::deliver could be calling hasNext while QueueImpl.depage could be using next and hasNext as well. It
+       * would be a rare race condition but I would prefer avoiding that scenario
        */
       @Override
       public synchronized boolean hasNext() {
