@@ -39,14 +39,15 @@ import org.apache.activemq.artemis.core.journal.EncodingSupport;
 import org.apache.activemq.artemis.core.journal.Journal;
 import org.apache.activemq.artemis.core.journal.PreparedTransactionInfo;
 import org.apache.activemq.artemis.core.journal.RecordInfo;
-import org.apache.activemq.artemis.core.journal.TransactionFailureCallback;
 import org.apache.activemq.artemis.core.journal.impl.JournalFile;
 import org.apache.activemq.artemis.core.journal.impl.JournalImpl;
 import org.apache.activemq.artemis.core.journal.impl.JournalReaderCallback;
 import org.apache.activemq.artemis.core.paging.cursor.impl.PageSubscriptionCounterImpl;
 import org.apache.activemq.artemis.core.paging.impl.PageTransactionInfoImpl;
+import org.apache.activemq.artemis.core.persistence.config.PersistedBridgeConfiguration;
 import org.apache.activemq.artemis.core.persistence.config.PersistedDivertConfiguration;
 import org.apache.activemq.artemis.core.persistence.impl.journal.BatchingIDGenerator.IDCounterEncoding;
+import org.apache.activemq.artemis.core.persistence.impl.journal.codec.AckRetry;
 import org.apache.activemq.artemis.core.persistence.impl.journal.codec.CursorAckRecordEncoding;
 import org.apache.activemq.artemis.core.persistence.impl.journal.codec.DeliveryCountUpdateEncoding;
 import org.apache.activemq.artemis.core.persistence.impl.journal.codec.DuplicateIDEncoding;
@@ -66,7 +67,11 @@ import org.apache.activemq.artemis.spi.core.protocol.MessagePersister;
 import org.apache.activemq.artemis.utils.Base64;
 import org.apache.activemq.artemis.utils.XMLUtil;
 import org.apache.activemq.artemis.utils.XidCodecSupport;
-import org.jboss.logging.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
+import java.util.Objects;
+
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
@@ -75,6 +80,7 @@ import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalR
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.ACKNOWLEDGE_REF;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.ADDRESS_BINDING_RECORD;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.ADDRESS_SETTING_RECORD;
+import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.ADDRESS_SETTING_RECORD_JSON;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.ADDRESS_STATUS_RECORD;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.ADD_LARGE_MESSAGE;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.ADD_LARGE_MESSAGE_PENDING;
@@ -85,6 +91,7 @@ import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalR
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.DUPLICATE_ID;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.HEURISTIC_COMPLETION;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.ID_COUNTER_RECORD;
+import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.ACK_RETRY;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.PAGE_CURSOR_COMPLETE;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.PAGE_CURSOR_COUNTER_INC;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.PAGE_CURSOR_COUNTER_VALUE;
@@ -97,6 +104,7 @@ import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalR
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.SET_SCHEDULED_DELIVERY_TIME;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.UPDATE_DELIVERY_COUNT;
 import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.USER_RECORD;
+import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds.BRIDGE_RECORD;
 
 /**
  * Outputs a String description of the Journals contents.
@@ -105,7 +113,7 @@ import static org.apache.activemq.artemis.core.persistence.impl.journal.JournalR
  */
 public final class DescribeJournal {
 
-   private static final Logger logger = Logger.getLogger(DescribeJournal.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
    private final List<RecordInfo> records;
    private final List<PreparedTransactionInfo> preparedTransactions;
@@ -199,11 +207,6 @@ public final class DescribeJournal {
       }
    });
 
-   /**
-    * @param fileFactory
-    * @param journal
-    * @throws Exception
-    */
    private static DescribeJournal describeJournal(SequentialFileFactory fileFactory,
                                                   JournalImpl journal,
                                                   final File path,
@@ -347,7 +350,7 @@ public final class DescribeJournal {
 
       journal.start();
 
-      final StringBuffer bufferFailingTransactions = new StringBuffer();
+      final StringBuilder bufferFailingTransactions = new StringBuilder();
 
       final class Count {
 
@@ -363,13 +366,15 @@ public final class DescribeJournal {
          }
 
          @Override
-         public boolean equals(Object o) {
-            if (this == o)
+         public boolean equals(Object obj) {
+            if (this == obj) {
                return true;
-            if (o == null || getClass() != o.getClass())
+            }
+            if (!(obj instanceof Count other)) {
                return false;
-            Count count = (Count) o;
-            return value == count.value;
+            }
+
+            return value == other.value;
          }
 
          @Override
@@ -383,22 +388,16 @@ public final class DescribeJournal {
       long preparedMessageCount = 0;
       long preparedLargeMessageCount = 0;
       Map<Long, Count> preparedMessageRefCount = new HashMap<>();
-      journal.load(records, preparedTransactions, new TransactionFailureCallback() {
-
-         @Override
-         public void failedTransaction(long transactionID,
-                                       List<RecordInfo> records1,
-                                       List<RecordInfo> recordsToDelete) {
-            bufferFailingTransactions.append("Transaction " + transactionID + " failed with these records:\n");
-            for (RecordInfo info : records1) {
-               bufferFailingTransactions.append("- " + describeRecord(info, safe) + "\n");
-            }
-
-            for (RecordInfo info : recordsToDelete) {
-               bufferFailingTransactions.append("- " + describeRecord(info, safe) + " <marked to delete>\n");
-            }
-
+      journal.load(records, preparedTransactions, (transactionID, records1, recordsToDelete) -> {
+         bufferFailingTransactions.append("Transaction " + transactionID + " failed with these records:\n");
+         for (RecordInfo info : records1) {
+            bufferFailingTransactions.append("- " + describeRecord(info, safe) + "\n");
          }
+
+         for (RecordInfo info : recordsToDelete) {
+            bufferFailingTransactions.append("- " + describeRecord(info, safe) + " <marked to delete>\n");
+         }
+
       }, false);
 
       for (RecordInfo info : records) {
@@ -460,7 +459,7 @@ public final class DescribeJournal {
          }
       }
 
-      if (counters.size() > 0) {
+      if (!counters.isEmpty()) {
          out.println("### Page Counters");
          printCounters(out, counters);
       }
@@ -496,7 +495,7 @@ public final class DescribeJournal {
 
       String missingTX = bufferFailingTransactions.toString();
 
-      if (missingTX.length() > 0) {
+      if (!missingTX.isEmpty()) {
          out.println();
          out.println("### Failed Transactions (Missing commit/prepare/rollback record) ###");
       }
@@ -533,7 +532,7 @@ public final class DescribeJournal {
       PageSubscriptionCounterImpl subsCounter;
       subsCounter = counters.get(queueIDForCounter);
       if (subsCounter == null) {
-         subsCounter = new PageSubscriptionCounterImpl(null, null, null, false, -1);
+         subsCounter = new PageSubscriptionCounterImpl(null, -1);
          counters.put(queueIDForCounter, subsCounter);
       }
       return subsCounter;
@@ -551,13 +550,12 @@ public final class DescribeJournal {
          return "** null **";
       }
       if (safe && !isSafe(obj)) {
-         if (obj instanceof MessageDescribe) {
-            MessageDescribe describe = (MessageDescribe)obj;
+         if (obj instanceof MessageDescribe messageDescribe) {
             try {
-               return describe.getMsg().getClass().getSimpleName() + "(safe data, size=" + describe.getMsg().getPersistentSize() + ")";
+               return messageDescribe.getMsg().getClass().getSimpleName() + "(safe data, size=" + messageDescribe.getMsg().getPersistentSize() + ")";
             } catch (Throwable e) {
                e.printStackTrace();
-               return describe.getMsg().getClass().getSimpleName() + "(safe data)";
+               return messageDescribe.getMsg().getClass().getSimpleName() + "(safe data)";
             }
          } else {
             return obj.getClass().getSimpleName() + "(safe data)";
@@ -576,7 +574,7 @@ public final class DescribeJournal {
    }
 
    private static String encode(final byte[] data) {
-      return Base64.encodeBytes(data, 0, data.length, Base64.DONT_BREAK_LINES | Base64.URL_SAFE);
+      return Base64.encodeBytes(data, true);
    }
 
    private static Xid toXid(final byte[] data) {
@@ -602,6 +600,12 @@ public final class DescribeJournal {
             persistedDivertConfiguration.decode(buffer);
             return persistedDivertConfiguration;
 
+         case BRIDGE_RECORD: {
+            PersistedBridgeConfiguration persistedBridgeConfiguration = new PersistedBridgeConfiguration();
+            persistedBridgeConfiguration.decode(buffer);
+            return persistedBridgeConfiguration;
+         }
+
          case ADD_LARGE_MESSAGE_PENDING: {
             PendingLargeMessageEncoding lmEncoding = new PendingLargeMessageEncoding();
             lmEncoding.decode(buffer);
@@ -736,6 +740,9 @@ public final class DescribeJournal {
          case ADDRESS_SETTING_RECORD:
             return AbstractJournalStorageManager.newAddressEncoding(id, buffer);
 
+         case ADDRESS_SETTING_RECORD_JSON:
+            return AbstractJournalStorageManager.newAddressJSONEncoding(id, buffer);
+
          case SECURITY_SETTING_RECORD:
             return AbstractJournalStorageManager.newSecurityRecord(id, buffer);
 
@@ -751,6 +758,9 @@ public final class DescribeJournal {
          case ROLE_RECORD:
             return AbstractJournalStorageManager.newRoleEncoding(id, buffer);
 
+         case ACK_RETRY:
+            return AckRetry.getPersister().decode(buffer, null, null);
+
          default:
             return null;
       }
@@ -774,16 +784,16 @@ public final class DescribeJournal {
 
       @Override
       public String toString() {
-         StringBuffer buffer = new StringBuffer();
-         buffer.append(msg.isLargeMessage() ? "LargeMessage(" : "Message(");
-         buffer.append("messageID=" + msg.getMessageID());
+         StringBuilder sb = new StringBuilder();
+         sb.append(msg.isLargeMessage() ? "LargeMessage(" : "Message(");
+         sb.append("messageID=" + msg.getMessageID());
          if (msg.getUserID() != null) {
-            buffer.append(";userMessageID=" + msg.getUserID().toString());
+            sb.append(";userMessageID=" + msg.getUserID().toString());
          }
 
-         buffer.append(";msg=" + msg.toString());
+         sb.append(";msg=" + msg.toString());
 
-         return buffer.toString();
+         return sb.toString();
       }
 
       public Message getMsg() {
@@ -807,27 +817,22 @@ public final class DescribeJournal {
 
       @Override
       public int hashCode() {
-         final int prime = 31;
-         int result = 1;
-         result = prime * result + ((refEncoding == null) ? 0 : refEncoding.hashCode());
-         return result;
+         return Objects.hashCode(refEncoding);
       }
 
       @Override
       public boolean equals(Object obj) {
-         if (this == obj)
+         if (this == obj) {
             return true;
-         if (obj == null)
+         }
+         if (obj == null) {
             return false;
-         if (!(obj instanceof ReferenceDescribe))
+         }
+         if (!(obj instanceof ReferenceDescribe other)) {
             return false;
-         ReferenceDescribe other = (ReferenceDescribe) obj;
-         if (refEncoding == null) {
-            if (other.refEncoding != null)
-               return false;
-         } else if (!refEncoding.equals(other.refEncoding))
-            return false;
-         return true;
+         }
+
+         return Objects.equals(refEncoding, other.refEncoding);
       }
    }
 
