@@ -122,6 +122,15 @@ public interface ServerSession extends SecurityAuth {
                                  boolean supportLargeMessage,
                                  Integer credits) throws Exception;
 
+   ServerConsumer createConsumer(long consumerID,
+                                 SimpleString queueName,
+                                 SimpleString filterString,
+                                 int priority,
+                                 boolean browseOnly,
+                                 boolean supportLargeMessage,
+                                 Integer credits,
+                                 boolean enforceSecurity) throws Exception;
+
    /**
     * To be used by protocol heads that needs to control the transaction outside the session context.
     */
@@ -339,6 +348,14 @@ public interface ServerSession extends SecurityAuth {
                       boolean noAutoCreateQueue,
                       RoutingContext routingContext) throws Exception;
 
+   RoutingStatus send(Transaction tx,
+                      SimpleString address,
+                      RoutingType routingType,
+                      Message message,
+                      boolean direct,
+                      String senderName,
+                      boolean noAutoCreateQueue,
+                      RoutingContext routingContext) throws Exception;
 
    RoutingStatus doSend(Transaction tx,
                         Message msg,
@@ -355,6 +372,15 @@ public interface ServerSession extends SecurityAuth {
                         boolean noAutoCreateQueue,
                         RoutingContext routingContext) throws Exception;
 
+   RoutingStatus doSend(Transaction tx,
+                        RoutingType routingType,
+                        Message msg,
+                        SimpleString originalAddress,
+                        boolean direct,
+                        String senderName,
+                        boolean noAutoCreateQueue,
+                        RoutingContext routingContext) throws Exception;
+
    RoutingStatus send(Message message, boolean direct, String senderName, boolean noAutoCreateQueue) throws Exception;
 
    RoutingStatus send(Message message, boolean direct, String senderName) throws Exception;
