@@ -16,23 +16,31 @@
  */
 package org.apache.activemq.artemis.core.list;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
+import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
 import java.util.Objects;
+import java.util.Set;
 
 import io.netty.util.collection.LongObjectHashMap;
-import org.apache.activemq.artemis.utils.collections.NodeStore;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.utils.collections.LinkedListImpl;
 import org.apache.activemq.artemis.utils.collections.LinkedListIterator;
+import org.apache.activemq.artemis.utils.collections.NodeStore;
 import org.apache.activemq.artemis.utils.collections.PriorityLinkedListImpl;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 public final class PriorityLinkedListTest {
 
    protected Wibble a;
@@ -89,8 +97,18 @@ public final class PriorityLinkedListTest {
 
    private PriorityLinkedListImpl<Wibble> list;
 
-   protected PriorityLinkedListImpl<Wibble> getList() {
-      return new PriorityLinkedListImpl<>(10);
+   int lastRemovedLevel;
+   Wibble lastRemovedWibble;
+
+   private PriorityLinkedListImpl<Wibble> getList() {
+      return new PriorityLinkedListImpl<>(10) {
+         @Override
+         protected void removed(int level, Wibble element) {
+            super.removed(level, element);
+            lastRemovedWibble = element;
+            lastRemovedLevel = level;
+         }
+      };
    }
 
    @BeforeEach
@@ -916,36 +934,7 @@ public final class PriorityLinkedListTest {
          list.addHead(new Wibble("" + i, i), i % 10);
       }
 
-      class WibbleNodeStore implements NodeStore<Wibble> {
-         LongObjectHashMap<LinkedListImpl.Node<Wibble>> list = new LongObjectHashMap<>();
-
-         @Override
-         public void storeNode(Wibble element, LinkedListImpl.Node<Wibble> node) {
-            list.put(element.id, node);
-         }
-
-         @Override
-         public LinkedListImpl.Node<Wibble> getNode(String listID, long id) {
-            return list.get(id);
-         }
-
-         @Override
-         public void removeNode(Wibble element, LinkedListImpl.Node<Wibble> node) {
-            list.remove(element.id);
-         }
-
-         @Override
-         public void clear() {
-            list.clear();
-         }
-
-         @Override
-         public int size() {
-            return list.size();
-         }
-      }
-
-      list.setNodeStore(new WibbleNodeStore());
+      list.setNodeStore(WibbleNodeStore::new);
 
       // remove every 3rd
       for (int i = 3; i <= 3000; i += 3) {
@@ -956,7 +945,7 @@ public final class PriorityLinkedListTest {
 
       Iterator<Wibble> iterator = list.iterator();
 
-      HashSet<String> values = new HashSet<>();
+      Set<String> values = new HashSet<>();
       while (iterator.hasNext()) {
          values.add(iterator.next().s1);
       }
@@ -975,35 +964,115 @@ public final class PriorityLinkedListTest {
 
    }
 
+   @Test
+   public void testRemoveWithRandomOrderID() {
+
+      list.setNodeStore(WibbleNodeStore::new);
+
+      List<Integer> usedIds = new ArrayList<>();
+
+      int elements = 50;
+
+      for (int i = 1; i <= elements; i++) {
+         int level = RandomUtil.randomInterval(0, 2);
+         list.addTail(new Wibble("" + i, i, level), level);
+         usedIds.add(i);
+      }
+
+      Map<Integer, Wibble> hashMapOutput = new HashMap<>(elements);
+
+      while (!usedIds.isEmpty()) {
+         Integer idToRemove = usedIds.remove(RandomUtil.randomInterval(0, usedIds.size() - 1));
+         Wibble wibble = list.removeWithID("", idToRemove);
+         assertNotNull(wibble);
+         assertEquals(idToRemove.intValue(), wibble.id);
+         assertSame(wibble, lastRemovedWibble);
+         // removing from the wrong could create a mess in the linked list nodes
+         assertEquals(wibble.level, lastRemovedLevel);
+         hashMapOutput.put(idToRemove, wibble);
+      }
+
+      assertEquals(elements, hashMapOutput.size());
+
+      for (int i = 1; i <= elements; i++) {
+         Wibble wibble = hashMapOutput.remove(i);
+         assertNotNull(wibble);
+         assertEquals(i, wibble.id);
+      }
+
+      assertEquals(0, hashMapOutput.size());
+   }
+
    static class Wibble {
 
       String s1;
       long id;
 
+      int level;
+
       Wibble(final String s, long id) {
+         this(s, id, 4);
+      }
+
+      Wibble(final String s, long id, int level) {
          this.s1 = s;
          this.id = id;
+         this.level = level;
       }
 
       @Override
       public String toString() {
-         return s1;
+         return "s = " + s1 + ", id = " + id + ", level = " + level;
       }
 
       @Override
-      public boolean equals(Object o) {
-         if (this == o)
+      public boolean equals(Object obj) {
+         if (this == obj) {
             return true;
-         if (o == null || getClass() != o.getClass())
+         }
+         if (!(obj instanceof Wibble other)) {
             return false;
-         Wibble wibble = (Wibble) o;
-         return Objects.equals(s1, wibble.s1);
+         }
+
+         return Objects.equals(s1, other.s1) &&
+                Objects.equals(id, other.id) &&
+                Objects.equals(level, other.level);
       }
 
       @Override
       public int hashCode() {
-         return Objects.hash(s1);
+         return Objects.hashCode(s1);
       }
    }
 
+   class WibbleNodeStore implements NodeStore<Wibble> {
+      LongObjectHashMap<LinkedListImpl.Node<Wibble>> list = new LongObjectHashMap<>();
+
+      @Override
+      public void storeNode(Wibble element, LinkedListImpl.Node<Wibble> node) {
+         list.put(element.id, node);
+      }
+
+      @Override
+      public LinkedListImpl.Node<Wibble> getNode(String listID, long id) {
+         return list.get(id);
+      }
+
+      @Override
+      public void removeNode(Wibble element, LinkedListImpl.Node<Wibble> node) {
+         list.remove(element.id);
+      }
+
+      @Override
+      public void clear() {
+         list.clear();
+      }
+
+      @Override
+      public int size() {
+         return list.size();
+      }
+   }
+
+
 }
