@@ -16,6 +16,10 @@
  */
 package org.apache.activemq.artemis.core.server.files;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileInputStream;
@@ -26,6 +30,7 @@ import java.io.InputStreamReader;
 import java.io.PrintWriter;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
+import java.util.concurrent.ScheduledExecutorService;
 
 import org.apache.activemq.artemis.api.config.ActiveMQDefaultConfiguration;
 import org.apache.activemq.artemis.api.core.SimpleString;
@@ -39,38 +44,31 @@ import org.apache.activemq.artemis.core.settings.impl.AddressFullMessagePolicy;
 import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.core.settings.impl.HierarchicalObjectRepository;
 import org.apache.activemq.artemis.logs.AssertionLoggerHandler;
+import org.apache.activemq.artemis.tests.extensions.TargetTempDirFactory;
+import org.apache.activemq.artemis.tests.util.ArtemisTestCase;
 import org.apache.activemq.artemis.utils.actors.OrderedExecutorFactory;
-import org.apache.activemq.artemis.utils.ThreadLeakCheckRule;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.apache.activemq.artemis.utils.FileUtil;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
+import org.mockito.Mockito;
 
-public class FileMoveManagerTest {
+public class FileMoveManagerTest extends ArtemisTestCase {
 
-   @Rule
-   public TemporaryFolder temporaryFolder;
-
-   @Rule
-   public ThreadLeakCheckRule leakCheckRule = new ThreadLeakCheckRule();
+   // Temp folder at ./target/tmp/<TestClassName>/<generated>
+   @TempDir(factory = TargetTempDirFactory.class)
+   public File temporaryFolder;
 
    private File dataLocation;
    private FileMoveManager manager;
 
-   @Before
+   @BeforeEach
    public void setUp() {
-      dataLocation = new File(temporaryFolder.getRoot(), "data");
+      dataLocation = new File(temporaryFolder, "data");
       dataLocation.mkdirs();
       manager = new FileMoveManager(dataLocation, 10);
    }
 
-   public FileMoveManagerTest() {
-      File parent = new File("./target/tmp");
-      parent.mkdirs();
-      temporaryFolder = new TemporaryFolder(parent);
-   }
-
    @Test
    public void testBackupFiles() {
       int[] originalFiles = new int[12];
@@ -83,8 +81,8 @@ public class FileMoveManagerTest {
          bkp.mkdirs();
       }
 
-      Assert.assertEquals(12, manager.getFolders().length);
-      Assert.assertEquals(12, manager.getNumberOfFolders());
+      assertEquals(12, manager.getFolders().length);
+      assertEquals(12, manager.getNumberOfFolders());
 
       assertIDs(originalFiles, manager.getIDlist());
    }
@@ -110,21 +108,21 @@ public class FileMoveManagerTest {
          bkp.mkdirs();
       }
 
-      Assert.assertEquals(12, manager.getFolders().length);
-      Assert.assertEquals(12, manager.getNumberOfFolders());
+      assertEquals(12, manager.getFolders().length);
+      assertEquals(12, manager.getNumberOfFolders());
 
       int[] ids = manager.getIDlist();
 
       assertIDs(originalFiles, ids);
 
-      Assert.assertEquals(0, manager.getMinID());
-      Assert.assertEquals(13, manager.getMaxID());
+      assertEquals(0, manager.getMinID());
+      assertEquals(13, manager.getMaxID());
 
       manager.setMaxFolders(3).checkOldFolders();
 
-      Assert.assertEquals(3, manager.getNumberOfFolders());
-      Assert.assertEquals(13, manager.getMaxID());
-      Assert.assertEquals(11, manager.getMinID());
+      assertEquals(3, manager.getNumberOfFolders());
+      assertEquals(13, manager.getMaxID());
+      assertEquals(11, manager.getMinID());
 
    }
 
@@ -152,13 +150,13 @@ public class FileMoveManagerTest {
 
    @Test
    public void testNoFolders() {
-      Assert.assertEquals(0, manager.getFolders().length);
-      Assert.assertEquals(0, manager.getNumberOfFolders());
+      assertEquals(0, manager.getFolders().length);
+      assertEquals(0, manager.getNumberOfFolders());
 
-      Assert.assertTrue(dataLocation.delete());
+      assertTrue(dataLocation.delete());
 
-      Assert.assertEquals(0, manager.getFolders().length);
-      Assert.assertEquals(0, manager.getNumberOfFolders());
+      assertEquals(0, manager.getFolders().length);
+      assertEquals(0, manager.getNumberOfFolders());
    }
 
    @Test
@@ -166,7 +164,7 @@ public class FileMoveManagerTest {
       // nothing to be moved, so why to do a backup
       manager.doMove();
 
-      Assert.assertEquals(0, manager.getNumberOfFolders());
+      assertEquals(0, manager.getNumberOfFolders());
    }
 
    @Test
@@ -181,7 +179,7 @@ public class FileMoveManagerTest {
          manager.doMove();
 
          // We will always have maximum of 3 folders
-         Assert.assertEquals(Math.min(bkp, manager.getMaxFolders()), manager.getNumberOfFolders());
+         assertEquals(Math.min(bkp, manager.getMaxFolders()), manager.getNumberOfFolders());
 
          File bkpFolder = manager.getFolder(bkp);
 
@@ -193,17 +191,17 @@ public class FileMoveManagerTest {
          }
       }
 
-      Assert.assertEquals(manager.getMaxFolders(), manager.getNumberOfFolders());
+      assertEquals(manager.getMaxFolders(), manager.getNumberOfFolders());
 
       manager.setMaxFolders(-1).checkOldFolders();
 
-      Assert.assertEquals(3, manager.getNumberOfFolders());
+      assertEquals(3, manager.getNumberOfFolders());
 
       manager.setMaxFolders(1).checkOldFolders();
-      Assert.assertEquals(1, manager.getNumberOfFolders());
+      assertEquals(1, manager.getNumberOfFolders());
 
-      Assert.assertEquals(10, manager.getMaxID());
-      Assert.assertEquals(10, manager.getMinID());
+      assertEquals(10, manager.getMaxID());
+      assertEquals(10, manager.getMinID());
    }
 
    @Test
@@ -228,7 +226,7 @@ public class FileMoveManagerTest {
          manager.doMove();
 
          // We will always have maximum of 3 folders
-         Assert.assertEquals(Math.min(bkp, manager.getMaxFolders()), manager.getNumberOfFolders());
+         assertEquals(Math.min(bkp, manager.getMaxFolders()), manager.getNumberOfFolders());
 
          File bkpFolder = manager.getFolder(bkp);
 
@@ -237,7 +235,7 @@ public class FileMoveManagerTest {
 
             String[] filesOnFolder = fileTmp.list();
 
-            Assert.assertEquals(FILES_PER_FOLDER + f, filesOnFolder.length);
+            assertEquals(FILES_PER_FOLDER + f, filesOnFolder.length);
 
             for (String file : filesOnFolder) {
                checkFile(fileTmp, file);
@@ -246,17 +244,17 @@ public class FileMoveManagerTest {
 
       }
 
-      Assert.assertEquals(manager.getMaxFolders(), manager.getNumberOfFolders());
+      assertEquals(manager.getMaxFolders(), manager.getNumberOfFolders());
 
       manager.setMaxFolders(-1).checkOldFolders();
 
-      Assert.assertEquals(3, manager.getNumberOfFolders());
+      assertEquals(3, manager.getNumberOfFolders());
 
       manager.setMaxFolders(1).checkOldFolders();
-      Assert.assertEquals(1, manager.getNumberOfFolders());
+      assertEquals(1, manager.getNumberOfFolders());
 
-      Assert.assertEquals(10, manager.getMaxID());
-      Assert.assertEquals(10, manager.getMinID());
+      assertEquals(10, manager.getMaxID());
+      assertEquals(10, manager.getMinID());
    }
 
    @Test
@@ -284,19 +282,19 @@ public class FileMoveManagerTest {
 
          manager.doMove();
 
-         Assert.assertEquals(0, manager.getNumberOfFolders());
-         Assert.assertEquals(0, manager.getFiles().length);
+         assertEquals(0, manager.getNumberOfFolders());
+         assertEquals(0, manager.getFiles().length);
       }
 
-      Assert.assertEquals(0, manager.getMaxID());
+      assertEquals(0, manager.getMaxID());
    }
 
    @Test
    public void testMoveOverPaging() throws Exception {
-      AssertionLoggerHandler.startCapture();
 
       ExecutorService threadPool = Executors.newCachedThreadPool();
-      try {
+      runAfter(threadPool::shutdownNow);
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
          manager.setMaxFolders(3);
          for (int i = 1; i <= 10; i++) {
             HierarchicalRepository<AddressSettings> addressSettings = new HierarchicalObjectRepository<>();
@@ -306,13 +304,13 @@ public class FileMoveManagerTest {
 
             final StorageManager storageManager = new NullStorageManager();
 
-            PagingStoreFactoryNIO storeFactory = new PagingStoreFactoryNIO(storageManager, dataLocation, 100, null, new OrderedExecutorFactory(threadPool),  new OrderedExecutorFactory(threadPool), true, null);
+            PagingStoreFactoryNIO storeFactory = new PagingStoreFactoryNIO(storageManager, dataLocation, 100, Mockito.mock(ScheduledExecutorService.class), new OrderedExecutorFactory(threadPool), true, null);
 
-            PagingManagerImpl managerImpl = new PagingManagerImpl(storeFactory, addressSettings, -1, -1, ActiveMQDefaultConfiguration.getDefaultManagementAddress());
+            PagingManagerImpl managerImpl = new PagingManagerImpl(storeFactory, addressSettings, -1, -1, ActiveMQDefaultConfiguration.getDefaultManagementAddress(), null);
 
             managerImpl.start();
 
-            PagingStore store = managerImpl.getPageStore(new SimpleString("simple-test"));
+            PagingStore store = managerImpl.getPageStore(SimpleString.of("simple-test"));
 
             store.startPaging();
 
@@ -322,28 +320,25 @@ public class FileMoveManagerTest {
 
             manager.doMove();
 
-            Assert.assertEquals(Math.min(i, manager.getMaxFolders()), manager.getNumberOfFolders());
+            assertEquals(Math.min(i, manager.getMaxFolders()), manager.getNumberOfFolders());
          }
 
-         Assert.assertFalse("The loggers are complaining about address.txt", AssertionLoggerHandler.findText("address.txt"));
-      } finally {
-         AssertionLoggerHandler.stopCapture();
-         threadPool.shutdown();
+         assertFalse(loggerHandler.findText("address.txt"), "The loggers are complaining about address.txt");
       }
 
    }
 
    private void assertIDs(int[] originalFiles, int[] ids) {
-      Assert.assertEquals(originalFiles.length, ids.length);
+      assertEquals(originalFiles.length, ids.length);
       for (int i = 0; i < ids.length; i++) {
-         Assert.assertEquals(originalFiles[i], ids[i]);
+         assertEquals(originalFiles[i], ids[i]);
       }
    }
 
    private void resetTmp() {
-      temporaryFolder.delete();
-      temporaryFolder.getRoot().mkdirs();
-      Assert.assertEquals(0, manager.getNumberOfFolders());
+      FileUtil.deleteDirectory(temporaryFolder);
+      temporaryFolder.mkdirs();
+      assertEquals(0, manager.getNumberOfFolders());
    }
 
    private void createFile(File folder, int i) throws FileNotFoundException {
@@ -359,7 +354,7 @@ public class FileMoveManagerTest {
          BufferedReader reader = new BufferedReader(stream);
          String valueRead = reader.readLine();
          int id = Integer.parseInt(file.substring(0, file.indexOf('.')));
-         Assert.assertEquals("content of the file wasn't the expected", id, Integer.parseInt(valueRead));
+         assertEquals(id, Integer.parseInt(valueRead), "content of the file wasn't the expected");
       }
    }
 
