@@ -1,22 +1,24 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with
+ * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * <p>
- * http://www.apache.org/licenses/LICENSE-2.0
- * <p>
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.activemq.artemis.core.server.impl;
 
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import java.util.Collection;
 import java.util.List;
 import java.util.Map;
@@ -42,11 +44,10 @@ import org.apache.activemq.artemis.core.transaction.Transaction;
 import org.apache.activemq.artemis.core.transaction.impl.TransactionImpl;
 import org.apache.activemq.artemis.utils.ReferenceCounter;
 import org.apache.activemq.artemis.utils.collections.LinkedListIterator;
-import org.apache.activemq.artemis.utils.collections.NodeStore;
+import org.apache.activemq.artemis.utils.collections.NodeStoreFactory;
 import org.apache.activemq.artemis.utils.critical.CriticalAnalyzer;
 import org.apache.activemq.artemis.utils.critical.CriticalCloseable;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class RoutingContextTest {
 
@@ -89,7 +90,7 @@ public class RoutingContextTest {
 
       @Override
       public SimpleString getName() {
-         return SimpleString.toSimpleString(name);
+         return SimpleString.of(name);
       }
 
       @Override
@@ -158,7 +159,7 @@ public class RoutingContextTest {
       }
 
       @Override
-      public MessageReference removeWithSuppliedID(String serverID, long id, NodeStore<MessageReference> nodeStore) {
+      public MessageReference removeWithSuppliedID(String serverID, long id, NodeStoreFactory<MessageReference> nodeStore) {
          return null;
       }
 
@@ -377,6 +378,11 @@ public class RoutingContextTest {
          return 0;
       }
 
+      @Override
+      public int getInitialQueueBufferSize() {
+         return 0;
+      }
+
       @Override
       public ReferenceCounter getConsumersRefCount() {
          return null;
@@ -392,6 +398,10 @@ public class RoutingContextTest {
 
       }
 
+      @Override
+      public void reloadSequence(MessageReference ref) {
+      }
+
       @Override
       public void addTail(MessageReference ref) {
 
@@ -441,7 +451,8 @@ public class RoutingContextTest {
       public void acknowledge(Transaction tx,
                               MessageReference ref,
                               AckReason reason,
-                              ServerConsumer consumer) throws Exception {
+                              ServerConsumer consumer,
+                              boolean delivering) throws Exception {
 
       }
 
@@ -610,11 +621,6 @@ public class RoutingContextTest {
          return null;
       }
 
-      @Override
-      public MessageReference getReference(long id) throws ActiveMQException {
-         return null;
-      }
-
       @Override
       public int deleteAllReferences() throws Exception {
          return 0;
@@ -661,7 +667,7 @@ public class RoutingContextTest {
       }
 
       @Override
-      public void expire(MessageReference ref, ServerConsumer consumer) throws Exception {
+      public void expire(MessageReference ref, ServerConsumer consumer, boolean delivering) throws Exception {
 
       }
 
@@ -722,6 +728,11 @@ public class RoutingContextTest {
          return 0;
       }
 
+      @Override
+      public boolean copyReference(long messageID, SimpleString address, Binding binding) throws Exception {
+         return false;
+      }
+
       @Override
       public int retryMessages(Filter filter) throws Exception {
          return 0;
@@ -742,6 +753,11 @@ public class RoutingContextTest {
          return false;
       }
 
+      @Override
+      public long getPendingMessageCount() {
+         return 0;
+      }
+
       @Override
       public Collection<Consumer> getConsumers() {
          return null;
@@ -851,7 +867,7 @@ public class RoutingContextTest {
 
       @Override
       public SimpleString getAddress() {
-         return SimpleString.toSimpleString(name);
+         return SimpleString.of(name);
       }
 
       @Override
@@ -894,11 +910,26 @@ public class RoutingContextTest {
 
       }
 
+      @Override
+      public void deliverScheduledMessages(String filter) throws ActiveMQException {
+
+      }
+
+      @Override
+      public void deliverScheduledMessage(long messageId) throws ActiveMQException {
+
+      }
+
       @Override
       public void postAcknowledge(MessageReference ref, AckReason reason) {
 
       }
 
+      @Override
+      public void postAcknowledge(MessageReference ref, AckReason reason, boolean delivering) {
+
+      }
+
       @Override
       public SimpleString getUser() {
          return null;
@@ -918,28 +949,28 @@ public class RoutingContextTest {
    @Test
    public void testValidateInternal() {
       RoutingContext context = new RoutingContextImpl(new TransactionImpl(new NullStorageManager()));
-      Assert.assertFalse(context.isInternal());
+      assertFalse(context.isInternal());
 
-      context.addQueue(SimpleString.toSimpleString("t1"), new FakeQueueForRoutingContextTest("t1", true, true));
-      Assert.assertTrue(context.isInternal());
+      context.addQueue(SimpleString.of("t1"), new FakeQueueForRoutingContextTest("t1", true, true));
+      assertTrue(context.isInternal());
 
-      context.addQueue(SimpleString.toSimpleString("t2"), new FakeQueueForRoutingContextTest("t2", false, true));
-      Assert.assertFalse(context.isInternal());
+      context.addQueue(SimpleString.of("t2"), new FakeQueueForRoutingContextTest("t2", false, true));
+      assertFalse(context.isInternal());
 
-      context.addQueue(SimpleString.toSimpleString("t3"), new FakeQueueForRoutingContextTest("t3", true, true));
-      Assert.assertFalse(context.isInternal());
+      context.addQueue(SimpleString.of("t3"), new FakeQueueForRoutingContextTest("t3", true, true));
+      assertFalse(context.isInternal());
 
       context.clear();
-      Assert.assertFalse(context.isInternal());
+      assertFalse(context.isInternal());
 
-      context.addQueue(SimpleString.toSimpleString("t1"), new FakeQueueForRoutingContextTest("t1", true, true));
-      Assert.assertTrue(context.isInternal());
+      context.addQueue(SimpleString.of("t1"), new FakeQueueForRoutingContextTest("t1", true, true));
+      assertTrue(context.isInternal());
 
-      context.addQueue(SimpleString.toSimpleString("t2"), new FakeQueueForRoutingContextTest("t2", true, true));
-      Assert.assertTrue(context.isInternal());
+      context.addQueue(SimpleString.of("t2"), new FakeQueueForRoutingContextTest("t2", true, true));
+      assertTrue(context.isInternal());
 
-      context.addQueue(SimpleString.toSimpleString("t3"), new FakeQueueForRoutingContextTest("t3", true, true));
-      Assert.assertTrue(context.isInternal());
+      context.addQueue(SimpleString.of("t3"), new FakeQueueForRoutingContextTest("t3", true, true));
+      assertTrue(context.isInternal());
    }
 
 }
