@@ -25,6 +25,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import org.apache.activemq.artemis.core.config.WildcardConfiguration;
@@ -37,7 +38,7 @@ import org.junit.jupiter.api.Test;
 
 public class RepositoryTest extends ServerTestBase {
 
-   HierarchicalRepository<HashSet<Role>> securityRepository;
+   HierarchicalRepository<Set<Role>> securityRepository;
 
    @Override
    @BeforeEach
@@ -50,9 +51,9 @@ public class RepositoryTest extends ServerTestBase {
    @Test
    public void testDefault() {
       securityRepository.setDefault(new HashSet<>());
-      HashSet<Role> roles = securityRepository.getMatch("queues.something");
+      Set<Role> roles = securityRepository.getMatch("queues.something");
 
-      assertEquals(roles.size(), 0);
+      assertEquals(0, roles.size());
    }
 
    @Test
@@ -72,8 +73,9 @@ public class RepositoryTest extends ServerTestBase {
       assertEquals("abd#", repo.getMatch("a.b.d"));
    }
 
-   /*
-    * A "literal" match is one which uses wild-cards but should not be applied to other matches "below" it in the hierarchy.
+   /**
+    * A "literal" match is one which uses wild-cards but should not be applied to other matches "below" it in the
+    * hierarchy.
     */
    @Test
    public void testLiteral() {
@@ -176,36 +178,36 @@ public class RepositoryTest extends ServerTestBase {
    @Test
    public void testSingleMatch() {
       securityRepository.addMatch("queues.*", new HashSet<>());
-      HashSet<Role> hashSet = securityRepository.getMatch("queues.something");
-      assertEquals(hashSet.size(), 0);
+      Set<Role> hashSet = securityRepository.getMatch("queues.something");
+      assertEquals(0, hashSet.size());
    }
 
    @Test
    public void testSingletwo() {
       securityRepository.addMatch("queues.another.aq.*", new HashSet<>());
-      HashSet<Role> roles = new HashSet<>(2);
+      Set<Role> roles = new HashSet<>(2);
       roles.add(new Role("test1", true, true, true, true, true, true, true, true, true, true, false, false));
       roles.add(new Role("test2", true, true, true, true, true, true, true, true, true, true, false, false));
       securityRepository.addMatch("queues.aq", roles);
-      HashSet<Role> roles2 = new HashSet<>(2);
+      Set<Role> roles2 = new HashSet<>(2);
       roles2.add(new Role("test1", true, true, true, true, true, true, true, true, true, true, false, false));
       roles2.add(new Role("test2", true, true, true, true, true, true, true, true, true, true, false, false));
       roles2.add(new Role("test3", true, true, true, true, true, true, true, true, true, true, false, false));
       securityRepository.addMatch("queues.another.andanother", roles2);
 
-      HashSet<Role> hashSet = securityRepository.getMatch("queues.another.andanother");
-      assertEquals(hashSet.size(), 3);
+      Set<Role> hashSet = securityRepository.getMatch("queues.another.andanother");
+      assertEquals(3, hashSet.size());
    }
 
    @Test
    public void testWithoutWildcard() {
       securityRepository.addMatch("queues.1.*", new HashSet<>());
-      HashSet<Role> roles = new HashSet<>(2);
+      Set<Role> roles = new HashSet<>(2);
       roles.add(new Role("test1", true, true, true, true, true, true, true, true, true, true, false, false));
       roles.add(new Role("test2", true, true, true, true, true, true, true, true, true, true, false, false));
       securityRepository.addMatch("queues.2.aq", roles);
-      HashSet<Role> hashSet = securityRepository.getMatch("queues.2.aq");
-      assertEquals(hashSet.size(), 2);
+      Set<Role> hashSet = securityRepository.getMatch("queues.2.aq");
+      assertEquals(2, hashSet.size());
    }
 
    @Test
@@ -417,7 +419,7 @@ public class RepositoryTest extends ServerTestBase {
 
    static class DummyMergeable implements Mergeable<DummyMergeable> {
       private final int id;
-      private final Map<String,String> settings;
+      private final Map<String, String> settings;
       private final List<DummyMergeable> mergedItems;
 
       public int getId() {
@@ -438,7 +440,7 @@ public class RepositoryTest extends ServerTestBase {
          this.mergedItems = new ArrayList<>();
       }
 
-      DummyMergeable(final int id, final Map<String,String> settings) {
+      DummyMergeable(final int id, final Map<String, String> settings) {
          this.id = id;
          this.settings = settings;
          this.mergedItems = new ArrayList<>();
