@@ -58,16 +58,18 @@ public class KubernetesClientImplTest {
    private static final String host = "localhost";
    private static String port;
 
-   private static final String BOB_REQUEST = "{\"apiVersion\": \"authentication.k8s.io/v1\"," +
-         "\"kind\": \"TokenReview\", \"spec\": {\"token\": \"bob_token\"}}";
+   private static final String BOB_REQUEST = """
+         {"apiVersion": "authentication.k8s.io/v1",\
+         "kind": "TokenReview", "spec": {"token": "bob_token"}}""";
 
-   private static final String KERMIT_REQUEST = "{\"apiVersion\": \"authentication.k8s.io/v1\"," +
-         "\"kind\": \"TokenReview\", \"spec\": {\"token\": \"kermit_token\"}}";
+   private static final String KERMIT_REQUEST = """
+         {"apiVersion": "authentication.k8s.io/v1",\
+         "kind": "TokenReview", "spec": {"token": "kermit_token"}}""";
 
    @BeforeAll
    public static void startServer() {
-      ConfigurationProperties.dynamicallyCreateCertificateAuthorityCertificate(true);
-      ConfigurationProperties.directoryToSaveDynamicSSLCertificate("target/test-classes");
+      ConfigurationProperties.certificateAuthorityPrivateKey(KubernetesClientImplTest.class.getClassLoader().getResource("server-ca.pem").getPath());
+      ConfigurationProperties.certificateAuthorityCertificate(KubernetesClientImplTest.class.getClassLoader().getResource("server-ca-cert.pem").getPath());
       ConfigurationProperties.preventCertificateDynamicUpdate(false);
       ConfigurationProperties.proactivelyInitialiseTLS(true);
 
@@ -84,7 +86,8 @@ public class KubernetesClientImplTest {
             KubernetesClientImplTest.class.getClassLoader().getResource("client_token").getPath());
 
       URL caPath = KubernetesClientImplTest.class.getClassLoader()
-         .getResource("CertificateAuthorityCertificate.pem");
+         .getResource("client-and-server-ca-certs.pem");
+
       assertNotNull(caPath);
       logger.info("Setting KUBERNETES_CA_PATH {}", caPath.getPath());
       System.setProperty("KUBERNETES_CA_PATH", caPath.getPath());
@@ -101,6 +104,7 @@ public class KubernetesClientImplTest {
 
    @BeforeEach
    public void reset() {
+      KubernetesClientImpl.clearHttpClient();
       mockServer.reset();
    }
 
@@ -166,12 +170,12 @@ public class KubernetesClientImplTest {
          if (System.getProperty(envKv.getKey()) == null) {
 
             KubernetesClientImpl clientImpl = new KubernetesClientImpl();
-            assertEquals(envKv.getValue(), clientImpl.getParam(envKv.getKey(), null));
+            assertEquals(envKv.getValue(), KubernetesClientImpl.getParam(envKv.getKey(), null));
 
             final String valFromProp = "bla";
             try {
                System.setProperty(envKv.getKey(), valFromProp);
-               assertEquals(valFromProp, clientImpl.getParam(envKv.getKey(), null));
+               assertEquals(valFromProp, KubernetesClientImpl.getParam(envKv.getKey(), null));
             } finally {
                System.clearProperty(envKv.getKey());
             }
@@ -180,7 +184,7 @@ public class KubernetesClientImplTest {
             String candidate = valFromProp;
             for (int i = 0; i < 10; i++) {
                if (System.getenv(candidate) == null && System.getProperty(candidate) == null) {
-                  assertEquals(candidate, clientImpl.getParam(candidate, candidate));
+                  assertEquals(candidate, KubernetesClientImpl.getParam(candidate, candidate));
                   break;
                }
                candidate += i;
@@ -192,4 +196,10 @@ public class KubernetesClientImplTest {
       }
    }
 
+   @Test
+   public void testSingeltonHttpClient() throws Exception {
+      KubernetesClientImpl clientImplFirst = new KubernetesClientImpl();
+      KubernetesClientImpl clientImplSecond = new KubernetesClientImpl();
+      assertEquals(clientImplFirst.getHttpClient(), clientImplSecond.getHttpClient());
+   }
 }
