@@ -17,11 +17,13 @@
 
 package org.apache.activemq.artemis.service.extensions.xa.recovery;
 
-public interface ActiveMQRegistry {
+import java.io.Serializable;
 
-   void register(final XARecoveryConfig resourceConfig);
+public interface ActiveMQRegistry extends Serializable {
 
-   void unRegister(final XARecoveryConfig resourceConfig);
+   void register(XARecoveryConfig resourceConfig);
+
+   void unRegister(XARecoveryConfig resourceConfig);
 
    void stop();
 
