@@ -17,21 +17,21 @@
 package org.apache.activemq.artemis.component;
 
 import javax.security.auth.Subject;
-import javax.servlet.Filter;
-import javax.servlet.FilterChain;
-import javax.servlet.FilterConfig;
-import javax.servlet.ServletException;
-import javax.servlet.ServletRequest;
-import javax.servlet.ServletResponse;
+import jakarta.servlet.Filter;
+import jakarta.servlet.FilterChain;
+import jakarta.servlet.FilterConfig;
+import jakarta.servlet.ServletException;
+import jakarta.servlet.ServletRequest;
+import jakarta.servlet.ServletResponse;
 import java.io.IOException;
 
 import org.apache.activemq.artemis.logs.AuditLogger;
 import org.eclipse.jetty.server.Request;
 import org.eclipse.jetty.server.Session;
 
-/*
-* This intercepts all calls made via jolokia
-* */
+/**
+ * This intercepts all calls made via jolokia
+ */
 public class JolokiaFilter implements Filter {
    @Override
    public void init(FilterConfig filterConfig) {
@@ -40,18 +40,18 @@ public class JolokiaFilter implements Filter {
    @Override
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
       /*
-      * this is the only place we can catch the remote address of the calling console client thru Jolokia.
-      * We set the address on the calling thread which will end up in JMX audit logging
-      * */
+       * This is the only place we can catch the remote address of the calling console client thru Jolokia. We set the
+       * address on the calling thread which will end up in JMX audit logging.
+       */
       if (AuditLogger.isAnyLoggingEnabled() && servletRequest != null) {
          String remoteHost = servletRequest.getRemoteHost();
          AuditLogger.setRemoteAddress(remoteHost + ":" + servletRequest.getRemotePort());
       }
       filterChain.doFilter(servletRequest, servletResponse);
       /*
-      * This is the only place we can get access to the authenticated subject on invocations after the login has happened.
-      * we set the subject for audit logging
-      * */
+       * This is the only place we can get access to the authenticated subject on invocations after the login has
+       * happened. We set the subject for audit logging.
+       */
       if (AuditLogger.isAnyLoggingEnabled()) {
          try {
             Session session = ((Request) servletRequest).getSession(true);
