@@ -46,7 +46,6 @@ import org.apache.activemq.artemis.core.server.ActiveMQServer;
 import org.apache.activemq.artemis.jms.client.ActiveMQBytesMessage;
 import org.apache.activemq.artemis.jms.client.ActiveMQTextMessage;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
-import org.apache.activemq.artemis.utils.RandomUtil;
 import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -229,7 +228,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       }, NUM_THREADS, false);
    }
 
-   // Added do replicate HORNETQ-264
    @Test
    public void testO() throws Exception {
       runTestMultipleThreads(new RunnableT() {
@@ -242,15 +240,11 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
 
    protected ClientSession createAutoCommitSession(final ClientSessionFactory sf) throws Exception {
       ClientSession session = sf.createSession(false, true, true);
-      session.addMetaData("someData", RandomUtil.randomString());
-      session.addMetaData("someData2", RandomUtil.randomString());
       return session;
    }
 
    protected ClientSession createTransactionalSession(final ClientSessionFactory sf) throws Exception {
       ClientSession session = sf.createSession(false, false, false);
-      session.addMetaData("someData", RandomUtil.randomString());
-      session.addMetaData("someData2", RandomUtil.randomString());
 
       return session;
    }
@@ -404,7 +398,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       }
 
       ClientSession sessSend = sf.createSession(false, true, true);
-      sessSend.addMetaData("some-data", RandomUtil.randomString());
 
       ClientProducer producer = sessSend.createProducer(ADDRESS);
 
@@ -462,7 +455,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       long start = System.currentTimeMillis();
 
       ClientSession s = sf.createSession(false, false, false);
-      s.addMetaData("some-data", RandomUtil.randomString());
 
       final int numMessages = 100;
 
@@ -488,7 +480,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       }
 
       ClientSession sessSend = sf.createSession(false, false, false);
-      sessSend.addMetaData("some-data", RandomUtil.randomString());
 
       ClientProducer producer = sessSend.createProducer(ADDRESS);
 
@@ -562,7 +553,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       long start = System.currentTimeMillis();
 
       ClientSession s = sf.createSession(false, false, false);
-      s.addMetaData("some-data", RandomUtil.randomString());
 
       final int numMessages = 100;
 
@@ -575,7 +565,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
          SimpleString subName = SimpleString.of(threadNum + " sub" + i);
 
          ClientSession sessConsume = sf.createSession(false, false, false);
-         sessConsume.addMetaData("data", RandomUtil.randomString());
 
          sessConsume.createQueue(QueueConfiguration.of(subName).setAddress(ADDRESS).setDurable(false));
 
@@ -587,7 +576,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       }
 
       ClientSession sessSend = sf.createSession(false, false, false);
-      sessSend.addMetaData("some-data", RandomUtil.randomString());
 
       ClientProducer producer = sessSend.createProducer(ADDRESS);
 
@@ -689,7 +677,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       long start = System.currentTimeMillis();
 
       ClientSession s = sf.createSession(false, false, false);
-      s.addMetaData("some-data", RandomUtil.randomString());
 
       final int numMessages = 100;
 
@@ -702,7 +689,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
          SimpleString subName = SimpleString.of(threadNum + "sub" + i);
 
          ClientSession sessConsume = sf.createSession(false, true, true);
-         sessConsume.addMetaData("some-data", RandomUtil.randomString());
 
          sessConsume.start();
 
@@ -716,7 +702,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       }
 
       ClientSession sessSend = sf.createSession(false, true, true);
-      sessSend.addMetaData("some-data", RandomUtil.randomString());
 
       ClientProducer producer = sessSend.createProducer(ADDRESS);
 
@@ -746,7 +731,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       long start = System.currentTimeMillis();
 
       ClientSession s = sf.createSession(false, false, false);
-      s.addMetaData("data", RandomUtil.randomString());
 
       final int numMessages = 100;
 
@@ -759,7 +743,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
          SimpleString subName = SimpleString.of(threadNum + "sub" + i);
 
          ClientSession sessConsume = sf.createSession(false, true, true);
-         sessConsume.addMetaData("data", RandomUtil.randomString());
 
          sessConsume.createQueue(QueueConfiguration.of(subName).setAddress(ADDRESS).setDurable(false));
 
@@ -771,7 +754,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       }
 
       ClientSession sessSend = sf.createSession(false, true, true);
-      sessSend.addMetaData("data", RandomUtil.randomString());
 
       ClientProducer producer = sessSend.createProducer(ADDRESS);
 
@@ -805,7 +787,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       long start = System.currentTimeMillis();
 
       ClientSession s = sf.createSession(false, false, false);
-      s.addMetaData("data", RandomUtil.randomString());
 
       final int numMessages = 100;
 
@@ -818,7 +799,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
          SimpleString subName = SimpleString.of(threadNum + "sub" + i);
 
          ClientSession sessConsume = sf.createSession(false, false, false);
-         sessConsume.addMetaData("data", RandomUtil.randomString());
 
          sessConsume.start();
 
@@ -832,7 +812,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       }
 
       ClientSession sessSend = sf.createSession(false, false, false);
-      sessSend.addMetaData("data", RandomUtil.randomString());
 
       ClientProducer producer = sessSend.createProducer(ADDRESS);
 
@@ -878,7 +857,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       long start = System.currentTimeMillis();
 
       ClientSession s = sf.createSession(false, false, false);
-      s.addMetaData("data", RandomUtil.randomString());
 
       final int numMessages = 100;
 
@@ -891,7 +869,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
          SimpleString subName = SimpleString.of(threadNum + "sub" + i);
 
          ClientSession sessConsume = sf.createSession(false, false, false);
-         sessConsume.addMetaData("data", RandomUtil.randomString());
 
          sessConsume.createQueue(QueueConfiguration.of(subName).setAddress(ADDRESS).setDurable(false));
 
@@ -903,7 +880,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       }
 
       ClientSession sessSend = sf.createSession(false, false, false);
-      sessSend.addMetaData("data", RandomUtil.randomString());
 
       ClientProducer producer = sessSend.createProducer(ADDRESS);
 
@@ -951,12 +927,10 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
 
    protected void doTestI(final ClientSessionFactory sf, final int threadNum) throws Exception {
       ClientSession sessCreate = sf.createSession(false, true, true);
-      sessCreate.addMetaData("data", RandomUtil.randomString());
 
       sessCreate.createQueue(QueueConfiguration.of(SimpleString.of(threadNum + ADDRESS.toString())).setAddress(ADDRESS).setDurable(false));
 
       ClientSession sess = sf.createSession(false, true, true);
-      sess.addMetaData("data", RandomUtil.randomString());
 
       sess.start();
 
@@ -982,12 +956,10 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
 
    protected void doTestJ(final ClientSessionFactory sf, final int threadNum) throws Exception {
       ClientSession sessCreate = sf.createSession(false, true, true);
-      sessCreate.addMetaData("data", RandomUtil.randomString());
 
       sessCreate.createQueue(QueueConfiguration.of(SimpleString.of(threadNum + ADDRESS.toString())).setAddress(ADDRESS).setDurable(false));
 
       ClientSession sess = sf.createSession(false, true, true);
-      sess.addMetaData("data", RandomUtil.randomString());
 
       sess.start();
 
@@ -1013,7 +985,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
 
    protected void doTestK(final ClientSessionFactory sf, final int threadNum) throws Exception {
       ClientSession s = sf.createSession(false, false, false);
-      s.addMetaData("data", RandomUtil.randomString());
 
       s.createQueue(QueueConfiguration.of(SimpleString.of(threadNum + ADDRESS.toString())).setAddress(ADDRESS).setDurable(false));
 
@@ -1030,16 +1001,13 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       s.close();
    }
 
-   /*
-    * This test tests failure during create connection
-    */
+   // This test tests failure during create connection
    protected void doTestL(final ClientSessionFactory sf) throws Exception {
       final int numSessions = 100;
 
       for (int i = 0; i < numSessions; i++) {
          ClientSession session = sf.createSession(false, false, false);
 
-         session.addMetaData("data", RandomUtil.randomString());
 
          session.close();
       }
@@ -1051,7 +1019,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       sessCreate.createQueue(QueueConfiguration.of(SimpleString.of(threadNum + ADDRESS.toString())).setAddress(ADDRESS).setDurable(false));
 
       ClientSession sess = sf.createSession(false, true, true);
-      sess.addMetaData("data", RandomUtil.randomString());
 
       sess.stop();
 
@@ -1119,7 +1086,7 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
    private void runTestMultipleThreads(final RunnableT runnable,
                                        final int numThreads,
                                        final boolean failOnCreateConnection) throws Exception {
-      runTestMultipleThreads(runnable, numThreads, failOnCreateConnection, 1000);
+      runTestMultipleThreads(runnable, numThreads, failOnCreateConnection, 250);
    }
 
    private void runTestMultipleThreads(final RunnableT runnable,
@@ -1130,9 +1097,6 @@ public abstract class MultiThreadRandomReattachTestBase extends MultiThreadReatt
       runMultipleThreadsFailoverTest(runnable, numThreads, getNumIterations(), failOnCreateConnection, failDelay);
    }
 
-   /**
-    * @return
-    */
    @Override
    protected ServerLocator createLocator() throws Exception {
       ServerLocator locator = createInVMNonHALocator().setReconnectAttempts(15).setConfirmationWindowSize(1024 * 1024);
