@@ -17,30 +17,31 @@
 
 package org.apache.activemq.artemis.tests.compatibility;
 
+import static org.apache.activemq.artemis.tests.compatibility.GroovyRun.ONE_FOUR;
+import static org.apache.activemq.artemis.tests.compatibility.GroovyRun.SNAPSHOT;
+import static org.junit.jupiter.api.Assumptions.assumeFalse;
+
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 
 import org.apache.activemq.artemis.tests.compatibility.base.VersionedBase;
+import org.apache.activemq.artemis.tests.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.activemq.artemis.tests.extensions.parameterized.Parameters;
 import org.apache.activemq.artemis.utils.FileUtil;
-import org.junit.After;
-import org.junit.Assume;
-import org.junit.Before;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-import static org.apache.activemq.artemis.tests.compatibility.GroovyRun.ONE_FIVE;
-import static org.apache.activemq.artemis.tests.compatibility.GroovyRun.SNAPSHOT;
-
-@RunWith(Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class ExportImportTest extends VersionedBase {
    private String serverScriptToUse;
    private boolean skipTearDownCleanup = false;
 
    // this will ensure that all tests in this class are run twice,
    // once with "true" passed to the class' constructor and once with "false"
-   @Parameterized.Parameters(name = "server={0}, sender={1}, consumer={2}")
+   @Parameters(name = "server={0}, sender={1}, consumer={2}")
    public static Collection getParameters() {
       // we don't need every single version ever released..
       // if we keep testing current one against 2.4 and 1.4.. we are sure the wire and API won't change over time
@@ -53,7 +54,7 @@ public class ExportImportTest extends VersionedBase {
       //      combinations.add(new Object[]{SNAPSHOT, ONE_FIVE, ONE_FIVE});
       //      combinations.add(new Object[]{ONE_FIVE, ONE_FIVE, ONE_FIVE});
 
-      combinations.add(new Object[]{null, ONE_FIVE, SNAPSHOT});
+      combinations.add(new Object[]{null, ONE_FOUR, SNAPSHOT});
       combinations.add(new Object[]{null, SNAPSHOT, SNAPSHOT});
       return combinations;
    }
@@ -62,13 +63,13 @@ public class ExportImportTest extends VersionedBase {
       super(server, sender, receiver);
    }
 
-   @Before
+   @BeforeEach
    public void removeFolder() throws Throwable {
-      FileUtil.deleteDirectory(serverFolder.getRoot());
-      serverFolder.getRoot().mkdirs();
+      FileUtil.deleteDirectory(serverFolder);
+      serverFolder.mkdirs();
    }
 
-   @After
+   @AfterEach
    public void tearDown() {
       if (skipTearDownCleanup) {
          // Skip server teardown when test is no-op, avoids a chunk of stacktrace
@@ -87,17 +88,17 @@ public class ExportImportTest extends VersionedBase {
       }
    }
 
-   @Test
+   @TestTemplate
    public void testSendReceive() throws Throwable {
       internalSendReceive(false);
    }
 
-   @Test
+   @TestTemplate
    public void testSendReceivelegacy() throws Throwable {
       // makes no sense on snapshot
       boolean isSenderSnapshot = SNAPSHOT.equals(sender);
       skipTearDownCleanup = isSenderSnapshot;
-      Assume.assumeFalse("This test only applies to old version senders", isSenderSnapshot);
+      assumeFalse(isSenderSnapshot, "This test only applies to old version senders");
 
       internalSendReceive(true);
    }
@@ -108,24 +109,24 @@ public class ExportImportTest extends VersionedBase {
       if (legacyPrefixes) {
          serverScriptToUse = "exportimport/artemisServer.groovy";
       }
-      startServer(serverFolder.getRoot(), senderClassloader, "sender");
+      startServer(serverFolder, senderClassloader, "sender");
       evaluate(senderClassloader, "meshTest/sendMessages.groovy", server, sender, "sendAckMessages");
       stopServer(senderClassloader);
 
       if (sender.startsWith("ARTEMIS-1")) {
-         evaluate(senderClassloader, "exportimport/export1X.groovy", serverFolder.getRoot().getAbsolutePath());
+         evaluate(senderClassloader, "exportimport/export1X.groovy", serverFolder.getAbsolutePath());
       } else {
-         evaluate(senderClassloader, "exportimport/export.groovy", serverFolder.getRoot().getAbsolutePath());
+         evaluate(senderClassloader, "exportimport/export.groovy", serverFolder.getAbsolutePath());
       }
 
       setVariable(receiverClassloader, "legacy", legacyPrefixes);
       try {
          setVariable(receiverClassloader, "persistent", true);
-         startServer(serverFolder.getRoot(), receiverClassloader, "receiver");
+         startServer(serverFolder, receiverClassloader, "receiver");
 
          setVariable(receiverClassloader, "sort", sender.startsWith("ARTEMIS-1"));
 
-         evaluate(receiverClassloader, "exportimport/import.groovy", serverFolder.getRoot().getAbsolutePath());
+         evaluate(receiverClassloader, "exportimport/import.groovy", serverFolder.getAbsolutePath());
 
          setVariable(receiverClassloader, "latch", null);
          evaluate(receiverClassloader, "meshTest/sendMessages.groovy", server, receiver, "receiveMessages");
