@@ -19,6 +19,7 @@ package org.apache.activemq.artemis.tests.integration.amqp.connect;
 import static org.apache.activemq.artemis.protocol.amqp.connect.bridge.AMQPBridgeConstants.PREFER_SHARED_DURABLE_SUBSCRIPTIONS;
 import static org.apache.activemq.artemis.protocol.amqp.connect.bridge.AMQPBridgeConstants.PULL_RECEIVER_BATCH_SIZE;
 import static org.apache.activemq.artemis.protocol.amqp.connect.bridge.AMQPBridgeConstants.RECEIVER_CREDITS;
+import static org.apache.activemq.artemis.protocol.amqp.connect.bridge.AMQPBridgeConstants.DISABLE_RECEIVER_DEMAND_TRACKING;
 import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertInstanceOf;
@@ -31,6 +32,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Map;
+import java.util.concurrent.TimeUnit;
 
 import javax.jms.BytesMessage;
 import javax.jms.Connection;
@@ -60,6 +62,11 @@ import org.apache.activemq.artemis.protocol.amqp.proton.AmqpSupport;
 import org.apache.activemq.artemis.tests.integration.amqp.AmqpClientTestSupport;
 import org.apache.activemq.artemis.tests.util.CFUtil;
 import org.apache.activemq.artemis.utils.Wait;
+import org.apache.activemq.transport.amqp.client.AmqpClient;
+import org.apache.activemq.transport.amqp.client.AmqpConnection;
+import org.apache.activemq.transport.amqp.client.AmqpMessage;
+import org.apache.activemq.transport.amqp.client.AmqpReceiver;
+import org.apache.activemq.transport.amqp.client.AmqpSession;
 import org.apache.qpid.jms.JmsConnectionFactory;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.RepeatedTest;
@@ -1606,4 +1613,120 @@ class AMQPBridgeServerToServerTest extends AmqpClientTestSupport {
          }
       }
    }
+
+   @Test
+   @Timeout(20)
+   public void testBridgeToRemoteDLQThatHasMessagesSentToMulticastAddressOriginially() throws Exception {
+      logger.info("Test started: {}", getTestName());
+
+      final AMQPBridgeQueuePolicyElement bridgePolicy = new AMQPBridgeQueuePolicyElement();
+      bridgePolicy.setName("drain-remote-dlq-policy");
+      bridgePolicy.addToIncludes(getDeadLetterAddress(), getDeadLetterAddress());
+      bridgePolicy.setRemoteAddress(getDeadLetterAddress() + "::" + getDeadLetterAddress()); // Direct target the desired FQQN
+
+      final AMQPBridgeBrokerConnectionElement element = new AMQPBridgeBrokerConnectionElement();
+      element.setName(getTestName());
+      element.addBridgeToQueuePolicy(bridgePolicy);
+
+      final AMQPBrokerConnectConfiguration amqpConnection =
+         new AMQPBrokerConnectConfiguration(getTestName(), "tcp://localhost:" + SERVER_PORT_REMOTE);
+      amqpConnection.setReconnectAttempts(10); // Limit reconnects
+      amqpConnection.setRetryInterval(50);
+      amqpConnection.addElement(element);
+
+      remoteServer.start();
+      server.getConfiguration().addAMQPConnection(amqpConnection);
+      server.start();
+
+      // Configure defaults
+      createAddressAndQueues(remoteServer);
+      createAddressAndQueues(server);
+
+      final AmqpClient client = createAmqpClient();
+      final AmqpConnection clientConnection = addConnection(client.connect());
+      final AmqpSession clientSession = clientConnection.createSession();
+      final AmqpReceiver receiver = clientSession.createReceiver(getTopicName());
+
+      receiver.flow(1);
+
+      final ConnectionFactory factoryLocal = CFUtil.createConnectionFactory("AMQP", "tcp://localhost:" + SERVER_PORT);
+
+      try (Connection connection = factoryLocal.createConnection()) {
+         connection.setClientID("test-brigdes");
+         connection.start();
+
+         final Session session = connection.createSession(Session.AUTO_ACKNOWLEDGE);
+         final Topic topic = session.createTopic(getTopicName());
+         final MessageProducer producer = session.createProducer(topic);
+
+         // Sends a Topic message with Qpid JMS so that source message has the AMQP JMS mapping headers.
+         producer.send(session.createTextMessage("Message:"));
+      }
+
+      final AmqpMessage received = receiver.receive(5, TimeUnit.SECONDS);
+      assertNotNull(received);
+      received.reject(); // Terminal outcome should be DLQ'd
+
+      Wait.assertTrue(() -> server.queueQuery(SimpleString.of(getDeadLetterAddress())).isExists(), 1_000);
+      Wait.assertTrue(() -> remoteServer.queueQuery(SimpleString.of(getDeadLetterAddress())).isExists(), 1_000);
+      Wait.assertEquals(1L, () -> remoteServer.queueQuery(SimpleString.of(getDeadLetterAddress())).getMessageCount(), 5_000, 10);
+   }
+
+   @Test
+   @Timeout(20)
+   public void testBridgeFromRemoteDLQThatHasMessagesSentToMulticastAddressOriginially() throws Exception {
+      logger.info("Test started: {}", getTestName());
+
+      final AMQPBridgeQueuePolicyElement bridgePolicy = new AMQPBridgeQueuePolicyElement();
+      bridgePolicy.setName("drain-remote-dlq-policy");
+      bridgePolicy.addToIncludes(getDeadLetterAddress(), getDeadLetterAddress());
+      bridgePolicy.addProperty(DISABLE_RECEIVER_DEMAND_TRACKING, "true");
+
+      final AMQPBridgeBrokerConnectionElement element = new AMQPBridgeBrokerConnectionElement();
+      element.setName("From-Server1-DLQ");
+      element.addBridgeFromQueuePolicy(bridgePolicy);
+
+      final AMQPBrokerConnectConfiguration amqpConnection =
+         new AMQPBrokerConnectConfiguration(getTestName(), "tcp://localhost:" + SERVER_PORT);
+      amqpConnection.setReconnectAttempts(10); // Limit reconnects
+      amqpConnection.setRetryInterval(50);
+      amqpConnection.addElement(element);
+
+      remoteServer.getConfiguration().addAMQPConnection(amqpConnection);
+      remoteServer.start();
+      server.start();
+
+      // Configure defaults
+      createAddressAndQueues(remoteServer);
+      createAddressAndQueues(server);
+
+      final AmqpClient client = createAmqpClient();
+      final AmqpConnection clientConnection = addConnection(client.connect());
+      final AmqpSession clientSession = clientConnection.createSession();
+      final AmqpReceiver receiver = clientSession.createReceiver(getTopicName());
+
+      receiver.flow(1);
+
+      final ConnectionFactory factoryLocal = CFUtil.createConnectionFactory("AMQP", "tcp://localhost:" + SERVER_PORT);
+
+      try (Connection connection = factoryLocal.createConnection()) {
+         connection.setClientID("test-brigdes");
+         connection.start();
+
+         final Session session = connection.createSession(Session.AUTO_ACKNOWLEDGE);
+         final Topic topic = session.createTopic(getTopicName());
+         final MessageProducer producer = session.createProducer(topic);
+
+         // Sends a Topic message with Qpid JMS so that source message has the AMQP JMS mapping headers.
+         producer.send(session.createTextMessage("Message:"));
+      }
+
+      final AmqpMessage received = receiver.receive(5, TimeUnit.SECONDS);
+      assertNotNull(received);
+      received.reject(); // Terminal outcome should be DLQ'd
+
+      Wait.assertTrue(() -> server.queueQuery(SimpleString.of(getDeadLetterAddress())).isExists(), 1_000);
+      Wait.assertTrue(() -> remoteServer.queueQuery(SimpleString.of(getDeadLetterAddress())).isExists(), 1_000);
+      Wait.assertEquals(1L, () -> remoteServer.queueQuery(SimpleString.of(getDeadLetterAddress())).getMessageCount(), 5_000, 10);
+   }
 }
