@@ -20,6 +20,7 @@ import static org.apache.activemq.artemis.api.core.management.ResourceNames.ADDR
 import static org.apache.activemq.artemis.api.core.management.ResourceNames.QUEUE;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -60,7 +61,7 @@ import org.apache.activemq.artemis.jms.client.ActiveMQTemporaryTopic;
 import org.apache.activemq.artemis.jms.client.ActiveMQTopic;
 import org.apache.activemq.artemis.spi.core.security.ActiveMQJAASSecurityManager;
 import org.apache.activemq.artemis.tests.util.JMSTestBase;
-import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.tests.util.Wait;
 import org.apache.activemq.artemis.utils.CompositeAddress;
 import org.apache.activemq.artemis.utils.UUIDGenerator;
@@ -117,8 +118,8 @@ public class AutoCreateJmsDestinationTest extends JMSTestBase {
    public void testAutoCreateOnSendToFQQN() throws Exception {
       Connection connection = cf.createConnection();
       Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-      String queueName = RandomUtil.randomString();
-      String addressName = RandomUtil.randomString();
+      String queueName = RandomUtil.randomUUIDString();
+      String addressName = RandomUtil.randomUUIDString();
 
       javax.jms.Queue queue = ActiveMQJMSClient.createQueue(CompositeAddress.toFullyQualified(addressName, queueName));
 
@@ -181,8 +182,8 @@ public class AutoCreateJmsDestinationTest extends JMSTestBase {
    public void testAutoCreateOnSendToFQQNAnonymousProducer() throws Exception {
       Connection connection = cf.createConnection();
       Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-      String queueName = RandomUtil.randomString();
-      String addressName = RandomUtil.randomString();
+      String queueName = RandomUtil.randomUUIDString();
+      String addressName = RandomUtil.randomUUIDString();
 
       javax.jms.Queue queue = ActiveMQJMSClient.createQueue(CompositeAddress.toFullyQualified(addressName, queueName));
 
@@ -226,7 +227,7 @@ public class AutoCreateJmsDestinationTest extends JMSTestBase {
          session.createProducer(queue);
          fail("Sending a message here should throw a JMSSecurityException");
       } catch (Exception e) {
-         assertTrue(e instanceof JMSSecurityException);
+         assertInstanceOf(JMSSecurityException.class, e);
       }
 
       connection.close();
@@ -272,8 +273,8 @@ public class AutoCreateJmsDestinationTest extends JMSTestBase {
       Connection connection = null;
       connection = cf.createConnection();
       Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-      String queueName = RandomUtil.randomString();
-      String addressName = RandomUtil.randomString();
+      String queueName = RandomUtil.randomUUIDString();
+      String addressName = RandomUtil.randomUUIDString();
 
       javax.jms.Queue queue = ActiveMQJMSClient.createQueue(CompositeAddress.toFullyQualified(addressName, queueName));
 
