@@ -16,6 +16,10 @@
  */
 package org.apache.activemq.artemis.tests.integration.cluster.bridge;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -23,6 +27,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.apache.activemq.artemis.api.core.QueueConfiguration;
 import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.artemis.api.core.TransportConfiguration;
 import org.apache.activemq.artemis.api.core.client.ActiveMQClient;
@@ -33,21 +38,19 @@ import org.apache.activemq.artemis.api.core.client.ClientSession;
 import org.apache.activemq.artemis.api.core.client.ClientSessionFactory;
 import org.apache.activemq.artemis.api.core.client.ServerLocator;
 import org.apache.activemq.artemis.core.config.BridgeConfiguration;
-import org.apache.activemq.artemis.core.config.CoreQueueConfiguration;
 import org.apache.activemq.artemis.core.remoting.impl.invm.TransportConstants;
 import org.apache.activemq.artemis.core.server.ActiveMQServer;
 import org.apache.activemq.artemis.core.server.cluster.Bridge;
-import org.apache.activemq.artemis.tests.integration.IntegrationTestLogger;
+import org.apache.activemq.artemis.tests.extensions.parameterized.ParameterizedTestExtension;
+import org.apache.activemq.artemis.tests.extensions.parameterized.Parameters;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
-import org.junit.Assert;
-import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.Parameterized;
+import org.junit.jupiter.api.TestTemplate;
+import org.junit.jupiter.api.extension.ExtendWith;
 
-@RunWith(value = Parameterized.class)
+@ExtendWith(ParameterizedTestExtension.class)
 public class BridgeStartTest extends ActiveMQTestBase {
 
-   @Parameterized.Parameters(name = "isNetty={0}")
+   @Parameters(name = "isNetty={0}")
    public static Collection getParameters() {
       return Arrays.asList(new Object[][]{{true}, {false}});
    }
@@ -58,8 +61,6 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
    private final boolean netty;
 
-   private static final IntegrationTestLogger log = IntegrationTestLogger.LOGGER;
-
    protected boolean isNetty() {
       return netty;
    }
@@ -71,7 +72,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
       return INVM_CONNECTOR_FACTORY;
    }
 
-   @Test
+   @TestTemplate
    public void testStartStop() throws Exception {
       Map<String, Object> server0Params = new HashMap<>();
       ActiveMQServer server0 = createClusteredServerWithParams(isNetty(), 0, true, server0Params);
@@ -97,7 +98,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
          server0.getConfiguration().setConnectorConfigurations(connectors);
 
-         ArrayList<String> staticConnectors = new ArrayList<>();
+         List<String> staticConnectors = new ArrayList<>();
          staticConnectors.add(server1tc.getName());
 
          final String bridgeName = "bridge1";
@@ -108,15 +109,15 @@ public class BridgeStartTest extends ActiveMQTestBase {
          bridgeConfigs.add(bridgeConfiguration);
          server0.getConfiguration().setBridgeConfigurations(bridgeConfigs);
 
-         CoreQueueConfiguration queueConfig0 = new CoreQueueConfiguration().setAddress(testAddress).setName(queueName0);
-         List<CoreQueueConfiguration> queueConfigs0 = new ArrayList<>();
+         QueueConfiguration queueConfig0 = QueueConfiguration.of(queueName0).setAddress(testAddress);
+         List<QueueConfiguration> queueConfigs0 = new ArrayList<>();
          queueConfigs0.add(queueConfig0);
-         server0.getConfiguration().setQueueConfigurations(queueConfigs0);
+         server0.getConfiguration().setQueueConfigs(queueConfigs0);
 
-         CoreQueueConfiguration queueConfig1 = new CoreQueueConfiguration().setAddress(forwardAddress).setName(queueName1);
-         List<CoreQueueConfiguration> queueConfigs1 = new ArrayList<>();
+         QueueConfiguration queueConfig1 = QueueConfiguration.of(queueName1).setAddress(forwardAddress);
+         List<QueueConfiguration> queueConfigs1 = new ArrayList<>();
          queueConfigs1.add(queueConfig1);
-         server1.getConfiguration().setQueueConfigurations(queueConfigs1);
+         server1.getConfiguration().setQueueConfigs(queueConfigs1);
 
          server1.start();
          waitForServerToStart(server1);
@@ -133,7 +134,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
          ClientSession session1 = sf1.createSession(false, true, true);
 
-         ClientProducer producer0 = session0.createProducer(new SimpleString(testAddress));
+         ClientProducer producer0 = session0.createProducer(SimpleString.of(testAddress));
 
          ClientConsumer consumer1 = session1.createConsumer(queueName1);
 
@@ -141,7 +142,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
          final int numMessages = 10;
 
-         final SimpleString propKey = new SimpleString("testkey");
+         final SimpleString propKey = SimpleString.of("testkey");
 
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = session0.createMessage(false);
@@ -154,14 +155,14 @@ public class BridgeStartTest extends ActiveMQTestBase {
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = consumer1.receive(200);
 
-            Assert.assertNotNull(message);
+            assertNotNull(message);
 
-            Assert.assertEquals(i, message.getObjectProperty(propKey));
+            assertEquals(i, message.getObjectProperty(propKey));
 
             message.acknowledge();
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          Bridge bridge = server0.getClusterManager().getBridges().get(bridgeName);
 
@@ -177,21 +178,21 @@ public class BridgeStartTest extends ActiveMQTestBase {
             producer0.send(message);
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          bridge.start();
 
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = consumer1.receive(1000);
 
-            Assert.assertNotNull(message);
+            assertNotNull(message);
 
-            Assert.assertEquals(i, message.getObjectProperty(propKey));
+            assertEquals(i, message.getObjectProperty(propKey));
 
             message.acknowledge();
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          session0.close();
 
@@ -212,7 +213,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
    }
 
-   @Test
+   @TestTemplate
    public void testTargetServerUpAndDown() throws Exception {
       // This test needs to use real files, since it requires duplicate detection, since when the target server is
       // shutdown, messages will get resent when it is started, so the dup id cache needs
@@ -241,7 +242,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
       server0.getConfiguration().setConnectorConfigurations(connectors);
 
-      ArrayList<String> staticConnectors = new ArrayList<>();
+      List<String> staticConnectors = new ArrayList<>();
       staticConnectors.add(server1tc.getName());
 
       final String bridgeName = "bridge1";
@@ -252,15 +253,15 @@ public class BridgeStartTest extends ActiveMQTestBase {
       bridgeConfigs.add(bridgeConfiguration);
       server0.getConfiguration().setBridgeConfigurations(bridgeConfigs);
 
-      CoreQueueConfiguration queueConfig0 = new CoreQueueConfiguration().setAddress(testAddress).setName(queueName0);
-      List<CoreQueueConfiguration> queueConfigs0 = new ArrayList<>();
+      QueueConfiguration queueConfig0 = QueueConfiguration.of(queueName0).setAddress(testAddress);
+      List<QueueConfiguration> queueConfigs0 = new ArrayList<>();
       queueConfigs0.add(queueConfig0);
-      server0.getConfiguration().setQueueConfigurations(queueConfigs0);
+      server0.getConfiguration().setQueueConfigs(queueConfigs0);
 
-      CoreQueueConfiguration queueConfig1 = new CoreQueueConfiguration().setAddress(forwardAddress).setName(queueName1);
-      List<CoreQueueConfiguration> queueConfigs1 = new ArrayList<>();
+      QueueConfiguration queueConfig1 = QueueConfiguration.of(queueName1).setAddress(forwardAddress);
+      List<QueueConfiguration> queueConfigs1 = new ArrayList<>();
       queueConfigs1.add(queueConfig1);
-      server1.getConfiguration().setQueueConfigurations(queueConfigs1);
+      server1.getConfiguration().setQueueConfigs(queueConfigs1);
       ServerLocator locator = null;
       try {
          // Don't start server 1 yet
@@ -273,11 +274,11 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
          ClientSession session0 = sf0.createSession(false, true, true);
 
-         ClientProducer producer0 = session0.createProducer(new SimpleString(testAddress));
+         ClientProducer producer0 = session0.createProducer(SimpleString.of(testAddress));
 
          final int numMessages = 10;
 
-         final SimpleString propKey = new SimpleString("testkey");
+         final SimpleString propKey = SimpleString.of("testkey");
 
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = session0.createMessage(false);
@@ -304,14 +305,14 @@ public class BridgeStartTest extends ActiveMQTestBase {
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = consumer1.receive(1000);
 
-            Assert.assertNotNull(message);
+            assertNotNull(message);
 
-            Assert.assertEquals(i, message.getObjectProperty(propKey));
+            assertEquals(i, message.getObjectProperty(propKey));
 
             message.acknowledge();
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = session0.createMessage(false);
@@ -324,25 +325,21 @@ public class BridgeStartTest extends ActiveMQTestBase {
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = consumer1.receive(1000);
 
-            Assert.assertNotNull(message);
+            assertNotNull(message);
 
-            Assert.assertEquals(i, message.getObjectProperty(propKey));
+            assertEquals(i, message.getObjectProperty(propKey));
 
             message.acknowledge();
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          session1.close();
 
          sf1.close();
 
-         BridgeStartTest.log.info("stopping server 1");
-
          server1.stop();
 
-         BridgeStartTest.log.info("stopped server 1");
-
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = session0.createMessage(false);
 
@@ -351,13 +348,9 @@ public class BridgeStartTest extends ActiveMQTestBase {
             producer0.send(message);
          }
 
-         BridgeStartTest.log.info("sent some more messages");
-
          server1.start();
          waitForServerToStart(server1);
 
-         BridgeStartTest.log.info("started server1");
-
          sf1 = locator.createSessionFactory(server1tc);
 
          session1 = sf1.createSession(false, true, true);
@@ -366,19 +359,17 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
          session1.start();
 
-         BridgeStartTest.log.info("started session");
-
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = consumer1.receive(1000);
 
-            Assert.assertNotNull(message);
+            assertNotNull(message);
 
-            Assert.assertEquals(i, message.getObjectProperty(propKey));
+            assertEquals(i, message.getObjectProperty(propKey));
 
             message.acknowledge();
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          session1.close();
 
@@ -400,7 +391,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
       }
    }
 
-   @Test
+   @TestTemplate
    public void testTargetServerNotAvailableNoReconnectTries() throws Exception {
       Map<String, Object> server0Params = new HashMap<>();
       ActiveMQServer server0 = createClusteredServerWithParams(isNetty(), 0, false, server0Params);
@@ -426,7 +417,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
          server0.getConfiguration().setConnectorConfigurations(connectors);
 
-         ArrayList<String> staticConnectors = new ArrayList<>();
+         List<String> staticConnectors = new ArrayList<>();
          staticConnectors.add(server1tc.getName());
 
          final String bridgeName = "bridge1";
@@ -437,15 +428,15 @@ public class BridgeStartTest extends ActiveMQTestBase {
          bridgeConfigs.add(bridgeConfiguration);
          server0.getConfiguration().setBridgeConfigurations(bridgeConfigs);
 
-         CoreQueueConfiguration queueConfig0 = new CoreQueueConfiguration().setAddress(testAddress).setName(queueName0);
-         List<CoreQueueConfiguration> queueConfigs0 = new ArrayList<>();
+         QueueConfiguration queueConfig0 = QueueConfiguration.of(queueName0).setAddress(testAddress);
+         List<QueueConfiguration> queueConfigs0 = new ArrayList<>();
          queueConfigs0.add(queueConfig0);
-         server0.getConfiguration().setQueueConfigurations(queueConfigs0);
+         server0.getConfiguration().setQueueConfigs(queueConfigs0);
 
-         CoreQueueConfiguration queueConfig1 = new CoreQueueConfiguration().setAddress(forwardAddress).setName(queueName1);
-         List<CoreQueueConfiguration> queueConfigs1 = new ArrayList<>();
+         QueueConfiguration queueConfig1 = QueueConfiguration.of(queueName1).setAddress(forwardAddress);
+         List<QueueConfiguration> queueConfigs1 = new ArrayList<>();
          queueConfigs1.add(queueConfig1);
-         server1.getConfiguration().setQueueConfigurations(queueConfigs1);
+         server1.getConfiguration().setQueueConfigs(queueConfigs1);
 
          // Don't start server 1 yet
 
@@ -457,11 +448,11 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
          ClientSession session0 = sf0.createSession(false, true, true);
 
-         ClientProducer producer0 = session0.createProducer(new SimpleString(testAddress));
+         ClientProducer producer0 = session0.createProducer(SimpleString.of(testAddress));
 
          final int numMessages = 10;
 
-         final SimpleString propKey = new SimpleString("testkey");
+         final SimpleString propKey = SimpleString.of("testkey");
 
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = session0.createMessage(false);
@@ -488,7 +479,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
          session1.start();
 
          // Won't be received since the bridge was deactivated
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          // Now start the bridge manually
 
@@ -501,14 +492,14 @@ public class BridgeStartTest extends ActiveMQTestBase {
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = consumer1.receive(3000);
 
-            Assert.assertNotNull(message);
+            assertNotNull(message);
 
-            Assert.assertEquals(i, message.getObjectProperty(propKey));
+            assertEquals(i, message.getObjectProperty(propKey));
 
             message.acknowledge();
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          session1.close();
 
@@ -530,7 +521,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
    }
 
-   @Test
+   @TestTemplate
    public void testManualStopStart() throws Exception {
       Map<String, Object> server0Params = new HashMap<>();
       ActiveMQServer server0 = createClusteredServerWithParams(isNetty(), 0, false, server0Params);
@@ -556,7 +547,7 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
          server0.getConfiguration().setConnectorConfigurations(connectors);
 
-         ArrayList<String> staticConnectors = new ArrayList<>();
+         List<String> staticConnectors = new ArrayList<>();
          staticConnectors.add(server1tc.getName());
 
          final String bridgeName = "bridge1";
@@ -567,15 +558,15 @@ public class BridgeStartTest extends ActiveMQTestBase {
          bridgeConfigs.add(bridgeConfiguration);
          server0.getConfiguration().setBridgeConfigurations(bridgeConfigs);
 
-         CoreQueueConfiguration queueConfig0 = new CoreQueueConfiguration().setAddress(testAddress).setName(queueName0);
-         List<CoreQueueConfiguration> queueConfigs0 = new ArrayList<>();
+         QueueConfiguration queueConfig0 = QueueConfiguration.of(queueName0).setAddress(testAddress);
+         List<QueueConfiguration> queueConfigs0 = new ArrayList<>();
          queueConfigs0.add(queueConfig0);
-         server0.getConfiguration().setQueueConfigurations(queueConfigs0);
+         server0.getConfiguration().setQueueConfigs(queueConfigs0);
 
-         CoreQueueConfiguration queueConfig1 = new CoreQueueConfiguration().setAddress(forwardAddress).setName(queueName1);
-         List<CoreQueueConfiguration> queueConfigs1 = new ArrayList<>();
+         QueueConfiguration queueConfig1 = QueueConfiguration.of(queueName1).setAddress(forwardAddress);
+         List<QueueConfiguration> queueConfigs1 = new ArrayList<>();
          queueConfigs1.add(queueConfig1);
-         server1.getConfiguration().setQueueConfigurations(queueConfigs1);
+         server1.getConfiguration().setQueueConfigs(queueConfigs1);
 
          server1.start();
          waitForServerToStart(server1);
@@ -588,11 +579,11 @@ public class BridgeStartTest extends ActiveMQTestBase {
 
          ClientSession session0 = sf0.createSession(false, true, true);
 
-         ClientProducer producer0 = session0.createProducer(new SimpleString(testAddress));
+         ClientProducer producer0 = session0.createProducer(SimpleString.of(testAddress));
 
          final int numMessages = 10;
 
-         final SimpleString propKey = new SimpleString("testkey");
+         final SimpleString propKey = SimpleString.of("testkey");
 
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = session0.createMessage(false);
@@ -612,21 +603,19 @@ public class BridgeStartTest extends ActiveMQTestBase {
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = consumer1.receive(1000);
 
-            Assert.assertNotNull(message);
+            assertNotNull(message);
 
-            Assert.assertEquals(i, message.getObjectProperty(propKey));
+            assertEquals(i, message.getObjectProperty(propKey));
 
             message.acknowledge();
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          // Now stop the bridge manually
 
          Bridge bridge = server0.getClusterManager().getBridges().get(bridgeName);
 
-         BridgeStartTest.log.info("stopping bridge manually");
-
          bridge.stop();
 
          bridge.flushExecutor();
@@ -639,26 +628,24 @@ public class BridgeStartTest extends ActiveMQTestBase {
             producer0.send(message);
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          bridge.start();
 
-         BridgeStartTest.log.info("started bridge");
-
          // The previous messages will get resent, but with duplicate detection they will be rejected
          // at the target
 
          for (int i = numMessages; i < numMessages * 2; i++) {
             ClientMessage message = consumer1.receive(1000);
 
-            Assert.assertNotNull(message);
+            assertNotNull(message);
 
-            Assert.assertEquals(i, message.getObjectProperty(propKey));
+            assertEquals(i, message.getObjectProperty(propKey));
 
             message.acknowledge();
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          bridge.stop();
 
@@ -672,21 +659,21 @@ public class BridgeStartTest extends ActiveMQTestBase {
             producer0.send(message);
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          bridge.start();
 
          for (int i = 0; i < numMessages; i++) {
             ClientMessage message = consumer1.receive(1000);
 
-            Assert.assertNotNull(message);
+            assertNotNull(message);
 
-            Assert.assertEquals(i, message.getObjectProperty(propKey));
+            assertEquals(i, message.getObjectProperty(propKey));
 
             message.acknowledge();
          }
 
-         Assert.assertNull(consumer1.receiveImmediate());
+         assertNull(consumer1.receiveImmediate());
 
          session1.close();
 
