@@ -16,11 +16,6 @@
  */
 package org.apache.activemq.artemis.tests.integration.federation;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
 import javax.jms.JMSException;
@@ -29,6 +24,7 @@ import javax.jms.MessageConsumer;
 import javax.jms.MessageProducer;
 import javax.jms.Queue;
 import javax.jms.Session;
+import javax.jms.TextMessage;
 import javax.jms.Topic;
 
 import org.apache.activemq.artemis.api.core.RoutingType;
@@ -42,12 +38,15 @@ import org.apache.activemq.artemis.core.server.impl.AddressInfo;
 import org.apache.activemq.artemis.core.server.transformer.Transformer;
 import org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory;
 import org.apache.activemq.artemis.tests.util.Wait;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-/**
- * Federated Address Test
- */
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 public class FederatedAddressTest extends FederatedTestBase {
 
    @Override
@@ -155,7 +154,7 @@ public class FederatedAddressTest extends FederatedTestBase {
          producer1.send(session1.createTextMessage("hello"));
          Message message = consumer0.receive(1000);
          assertNotNull(message);
-         assertEquals(message.getBooleanProperty(FederatedQueueTest.TestTransformer.TEST_PROPERTY), true);
+         assertTrue(message.getBooleanProperty(FederatedQueueTest.TestTransformer.TEST_PROPERTY));
       }
    }
 
@@ -190,7 +189,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy divert at end
    @Test
    public void testDownstreamDivertAddressFirstAndDivertFirstDestroyDivert() throws Exception {
-      testFederatedAddressDivert(true,true, true, true);
+      testFederatedAddressDivert(true, true, true, true);
    }
 
    //Test creating address first followed by divert
@@ -198,7 +197,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy queue at end
    @Test
    public void testDownstreamDivertAddressFirstAndDivertFirstDestroyQueue() throws Exception {
-      testFederatedAddressDivert(true,true, true, false);
+      testFederatedAddressDivert(true, true, true, false);
    }
 
    //Test creating divert first followed by address
@@ -206,7 +205,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy divert at end
    @Test
    public void testDownstreamDivertAddressSecondDivertFirstDestroyDivert() throws Exception {
-      testFederatedAddressDivert(true,false, true, true);
+      testFederatedAddressDivert(true, false, true, true);
    }
 
    //Test creating divert first followed by address
@@ -214,7 +213,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy divert at end
    @Test
    public void testDownstreamDivertAddressSecondDivertFirstDestroyQueue() throws Exception {
-      testFederatedAddressDivert(true,false, true, false);
+      testFederatedAddressDivert(true, false, true, false);
    }
 
    //Test creating address first followed by divert
@@ -222,7 +221,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy divert at end
    @Test
    public void testDownstreamDivertAddressFirstDivertSecondDestroyDivert() throws Exception {
-      testFederatedAddressDivert(true,true, false, true);
+      testFederatedAddressDivert(true, true, false, true);
    }
 
    //Test creating address first followed by divert
@@ -230,7 +229,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy queue at end
    @Test
    public void testDownstreamDivertAddressFirstDivertSecondDestroyQueue() throws Exception {
-      testFederatedAddressDivert(true,true, false, false);
+      testFederatedAddressDivert(true, true, false, false);
    }
 
    //Test creating divert first followed by address
@@ -238,7 +237,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy divert at end
    @Test
    public void testDownstreamDivertAddressAndDivertSecondDestroyDivert() throws Exception {
-      testFederatedAddressDivert(true,false, false, true);
+      testFederatedAddressDivert(true, false, false, true);
    }
 
    //Test creating divert first followed by address
@@ -246,7 +245,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy queue at end
    @Test
    public void testDownstreamDivertAddressAndDivertSecondDestroyQueue() throws Exception {
-      testFederatedAddressDivert(true,false, false, false);
+      testFederatedAddressDivert(true, false, false, false);
    }
 
    /**
@@ -257,7 +256,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy divert at end
    @Test
    public void testUpstreamDivertAddressAndDivertFirstDestroyDivert() throws Exception {
-      testFederatedAddressDivert(false,true, true, true);
+      testFederatedAddressDivert(false, true, true, true);
    }
 
    //Test creating address first followed by divert
@@ -265,7 +264,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy queue at end
    @Test
    public void testUpstreamDivertAddressAndDivertFirstDestroyQueue() throws Exception {
-      testFederatedAddressDivert(false,true, true, false);
+      testFederatedAddressDivert(false, true, true, false);
    }
 
    //Test creating divert first followed by address
@@ -273,7 +272,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy divert at end
    @Test
    public void testUpstreamDivertAddressSecondDivertFirstDestroyDivert() throws Exception {
-      testFederatedAddressDivert(false,false, true, true);
+      testFederatedAddressDivert(false, false, true, true);
    }
 
    //Test creating divert first followed by address
@@ -281,7 +280,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy queue at end
    @Test
    public void testUpstreamDivertAddressSecondDivertFirstDestroyQueue() throws Exception {
-      testFederatedAddressDivert(false,false, true, false);
+      testFederatedAddressDivert(false, false, true, false);
    }
 
    //Test creating address first followed by divert
@@ -289,7 +288,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy divert at end
    @Test
    public void testUpstreamDivertAddressFirstDivertSecondDestroyDivert() throws Exception {
-      testFederatedAddressDivert(false,true, false, true);
+      testFederatedAddressDivert(false, true, false, true);
    }
 
    //Test creating address first followed by divert
@@ -297,7 +296,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy queue at end
    @Test
    public void testUpstreamDivertAddressFirstDivertSecondDestroyQueue() throws Exception {
-      testFederatedAddressDivert(false,true, false, false);
+      testFederatedAddressDivert(false, true, false, false);
    }
 
    //Test creating divert first followed by address
@@ -305,7 +304,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy divert at end
    @Test
    public void testUpstreamsDivertAddressAndDivertSecondDestroyDivert() throws Exception {
-      testFederatedAddressDivert(false,false, false, true);
+      testFederatedAddressDivert(false, false, false, true);
    }
 
    //Test creating divert first followed by address
@@ -313,7 +312,7 @@ public class FederatedAddressTest extends FederatedTestBase {
    //Test destroy queue at end
    @Test
    public void testUpstreamDivertAddressAndDivertSecondDestroyQueue() throws Exception {
-      testFederatedAddressDivert(false,false, false, false);
+      testFederatedAddressDivert(false, false, false, false);
    }
 
    protected void testFederatedAddressDivert(boolean downstream, boolean addressFirst, boolean divertBeforeConsumer,
@@ -373,8 +372,7 @@ public class FederatedAddressTest extends FederatedTestBase {
                                          .setRoutingType(ComponentConfigurationRoutingType.ANYCAST));
          }
 
-         assertTrue(Wait.waitFor(() -> getServer(1).getPostOffice().getBindingsForAddress(SimpleString.of(address)).getBindings().size() == 1,
-                                 1000, 100));
+         Wait.assertEquals(1L, () -> getServer(1).getPostOffice().getBindingsForAddress(SimpleString.of(address)).getBindings().size(), 10_000, 100);
          final QueueBinding remoteQueueBinding = (QueueBinding) getServer(1).getPostOffice().getBindingsForAddress(SimpleString.of(address))
             .getBindings().iterator().next();
          Wait.assertEquals(1, () -> remoteQueueBinding.getQueue().getConsumerCount());
@@ -652,6 +650,68 @@ public class FederatedAddressTest extends FederatedTestBase {
       }
    }
 
+   @Test
+   public void testUpstreamFederatedAddressWithCompressedMessage() throws Exception {
+      final String DATA_REGULAR = RandomUtil.randomAlphaNumericString(10);
+      final String DATA_COMPRESSED_REGULAR = "Compresses easily".repeat(500 * 1024);
+      final String DATA_COMPRESSED_LARGE = RandomUtil.randomAlphaNumericString(1024 * 1024);
+      final String address = getName();
+
+      FederationConfiguration federationConfiguration = FederatedTestUtil.createAddressUpstreamFederationConfiguration("server1", address);
+      getServer(0).getConfiguration().getFederationConfigurations().add(federationConfiguration);
+      getServer(0).getFederationManager().deploy();
+
+      FederationConfiguration federationConfiguration2 = FederatedTestUtil.createAddressUpstreamFederationConfiguration("server0", address);
+      getServer(1).getConfiguration().getFederationConfigurations().add(federationConfiguration2);
+      getServer(1).getFederationManager().deploy();
+
+      ActiveMQConnectionFactory cf0 = new ActiveMQConnectionFactory("vm://" + 0);
+      ActiveMQConnectionFactory cf1 = new ActiveMQConnectionFactory("vm://" + 1);
+      cf0.setCompressLargeMessage(true);
+      cf1.setCompressLargeMessage(true);
+
+      try (Connection connection1 = cf1.createConnection();
+           Connection connection0 = cf0.createConnection()) {
+         connection1.start();
+         connection0.start();
+
+         Session session0 = connection0.createSession();
+         Session session1 = connection1.createSession();
+         Topic topic0 = session0.createTopic(address);
+         Topic topic1 = session1.createTopic(address);
+         MessageConsumer consumer0 = session0.createConsumer(topic0);
+         MessageConsumer consumer1 = session1.createConsumer(topic1);
+
+         MessageProducer producer = session0.createProducer(topic0);
+
+         Wait.assertEquals(2, () -> getServer(0).getPostOffice().getBindingsForAddress(SimpleString.of(address)).getBindings().size(), 5000, 100);
+         Wait.assertEquals(2, () -> getServer(1).getPostOffice().getBindingsForAddress(SimpleString.of(address)).getBindings().size(), 5000, 100);
+
+         sendAndConsume(producer, session0, DATA_REGULAR, "regular", consumer0, consumer1);
+         sendAndConsume(producer, session0, DATA_COMPRESSED_LARGE, "compressedLarge", consumer0, consumer1);
+         sendAndConsume(producer, session0, DATA_COMPRESSED_REGULAR, "compressedRegular", consumer0, consumer1);
+      }
+   }
+
+   private void sendAndConsume(MessageProducer producer,
+                          Session session0,
+                          String data,
+                          String identification,
+                          MessageConsumer consumer0,
+                          MessageConsumer consumer1) throws Exception {
+      {
+         TextMessage message = session0.createTextMessage(data);
+         message.setStringProperty("identification", identification);
+         producer.send(message);
+      }
+      TextMessage message0 = (TextMessage) consumer0.receive(10_000);
+      TextMessage message1 = (TextMessage) consumer1.receive(10_000);
+      assertNotNull(message0);
+      assertNotNull(message1);
+      assertEquals(data, message0.getText());
+      assertEquals(data, message1.getText());
+   }
+
    private Message createTextMessage(Session session1, String group) throws JMSException {
       Message message = session1.createTextMessage("hello");
       message.setStringProperty("JMSXGroupID", group);
