@@ -53,9 +53,6 @@ import org.apache.activemq.artemis.tests.util.JMSTestBase;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
-/**
- * GroupingTest
- */
 public class GroupingTest extends JMSTestBase {
 
    private Queue queue;
@@ -366,13 +363,13 @@ public class GroupingTest extends JMSTestBase {
          assertNotNull(tm);
          tm.acknowledge();
          assertEquals("Message" + j, tm.getText());
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID1);
+         assertEquals(groupID1, tm.getStringProperty("JMSXGroupID"));
 
          tm = (TextMessage) consumer2.receive(10000);
          assertNotNull(tm);
          tm.acknowledge();
          assertEquals("Message" + (j + 10), tm.getText());
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID2);
+         assertEquals(groupID2, tm.getStringProperty("JMSXGroupID"));
 
          assertNull(consumer3.receiveNoWait());
       }
@@ -383,7 +380,7 @@ public class GroupingTest extends JMSTestBase {
          assertNotNull(tm);
          tm.acknowledge();
          assertEquals("Message" + j, tm.getText());
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID3);
+         assertEquals(groupID3, tm.getStringProperty("JMSXGroupID"));
 
          assertNull(consumer2.receiveNoWait());
          assertNull(consumer3.receiveNoWait());
@@ -442,7 +439,7 @@ public class GroupingTest extends JMSTestBase {
          assertNotNull(tm);
          tm.acknowledge();
          assertEquals("Message" + j, tm.getText());
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID1);
+         assertEquals(groupID1, tm.getStringProperty("JMSXGroupID"));
       }
 
       //Second set of msgs should go to the second consumers only
@@ -455,7 +452,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID2);
+         assertEquals(groupID2, tm.getStringProperty("JMSXGroupID"));
       }
 
       //Third set of msgs should go to the first consumer only
@@ -468,7 +465,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID3);
+         assertEquals(groupID3, tm.getStringProperty("JMSXGroupID"));
       }
       ctx.commit();
 
@@ -492,7 +489,7 @@ public class GroupingTest extends JMSTestBase {
          assertNotNull(tm);
          tm.acknowledge();
          assertEquals("Message" + j, tm.getText());
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID1);
+         assertEquals(groupID1, tm.getStringProperty("JMSXGroupID"));
       }
 
       //Second set of msgs should go to the second consumers only
@@ -505,7 +502,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID2);
+         assertEquals(groupID2, tm.getStringProperty("JMSXGroupID"));
       }
 
       //Third set of msgs should now go to the third consumer now
@@ -518,7 +515,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID3);
+         assertEquals(groupID3, tm.getStringProperty("JMSXGroupID"));
       }
 
       ctx.commit();
@@ -527,11 +524,11 @@ public class GroupingTest extends JMSTestBase {
    }
 
    /**
-    * This tests ensures that when we have group rebalance and pause dispatch,
-    * the broker pauses dispatch of new messages to consumers whilst rebalance and awaits existing inflight messages to be handled before restarting dispatch with new reblanced group allocations,
-    * this allows us to provide a guarantee of message ordering even with rebalance, at the expense that during rebalance dispatch will pause till all consumers with inflight messages are handled.
-    *
-    * @throws Exception
+    * This tests ensures that when we have group rebalance and pause dispatch, the broker pauses dispatch of new
+    * messages to consumers whilst rebalance and awaits existing inflight messages to be handled before restarting
+    * dispatch with new reblanced group allocations, this allows us to provide a guarantee of message ordering even with
+    * rebalance, at the expense that during rebalance dispatch will pause till all consumers with inflight messages are
+    * handled.
     */
    @Test
    public void testGroupRebalancePauseDispatch() throws Exception {
@@ -579,7 +576,7 @@ public class GroupingTest extends JMSTestBase {
          assertNotNull(tm);
          tm.acknowledge();
          assertEquals("Message" + j, tm.getText());
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID1);
+         assertEquals(groupID1, tm.getStringProperty("JMSXGroupID"));
       }
       ctx.commit();
 
@@ -594,7 +591,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID2);
+         assertEquals(groupID2, tm.getStringProperty("JMSXGroupID"));
       }
       ctx.commit();
 
@@ -628,7 +625,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID3);
+         assertEquals(groupID3, tm.getStringProperty("JMSXGroupID"));
       }
       ctx.commit();
 
@@ -640,7 +637,7 @@ public class GroupingTest extends JMSTestBase {
          assertNotNull(tm);
          tm.acknowledge();
          assertEquals("Message" + j, tm.getText());
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID1);
+         assertEquals(groupID1, tm.getStringProperty("JMSXGroupID"));
       }
 
       //Second set of msgs should go to the second consumers only
@@ -653,7 +650,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID2);
+         assertEquals(groupID2, tm.getStringProperty("JMSXGroupID"));
       }
 
       //Third set of msgs should now go to the third consumer now
@@ -666,7 +663,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID3);
+         assertEquals(groupID3, tm.getStringProperty("JMSXGroupID"));
       }
 
       ctx.commit();
@@ -723,7 +720,7 @@ public class GroupingTest extends JMSTestBase {
          assertNotNull(tm);
          tm.acknowledge();
          assertEquals("Message" + j, tm.getText());
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID1);
+         assertEquals(groupID1, tm.getStringProperty("JMSXGroupID"));
          if (j == 0) {
             assertTrue(tm.getBooleanProperty(customFirstGroupKey));
          } else {
@@ -741,7 +738,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID2);
+         assertEquals(groupID2, tm.getStringProperty("JMSXGroupID"));
 
          if (j == 10) {
             assertTrue(tm.getBooleanProperty(customFirstGroupKey));
@@ -760,7 +757,7 @@ public class GroupingTest extends JMSTestBase {
 
          assertEquals("Message" + j, tm.getText());
 
-         assertEquals(tm.getStringProperty("JMSXGroupID"), groupID3);
+         assertEquals(groupID3, tm.getStringProperty("JMSXGroupID"));
 
          if (j == 20) {
             assertTrue(tm.getBooleanProperty(customFirstGroupKey));
