@@ -35,7 +35,7 @@ import org.apache.activemq.artemis.spi.core.protocol.RemotingConnection;
 import org.apache.activemq.artemis.spi.core.remoting.Acceptor;
 import org.apache.activemq.artemis.spi.core.security.ActiveMQSecurityManager5;
 import org.apache.activemq.artemis.spi.core.security.jaas.UserPrincipal;
-import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.tests.util.Wait;
 import org.fusesource.mqtt.client.BlockingConnection;
 import org.fusesource.mqtt.client.MQTT;
@@ -46,7 +46,7 @@ import org.junit.jupiter.api.Timeout;
 
 public class MQTTSecurityManagerTest extends MQTTTestSupport {
 
-   private String clientID = "new-" + RandomUtil.randomString();
+   private String clientID = "new-" + RandomUtil.randomUUIDString();
    private boolean rejectClientId = false;
 
    @Override
@@ -96,7 +96,7 @@ public class MQTTSecurityManagerTest extends MQTTTestSupport {
    public void testSecurityManagerModifyClientID() throws Exception {
       BlockingConnection connection = null;
       try {
-         MQTT mqtt = createMQTTConnection(RandomUtil.randomString(), true);
+         MQTT mqtt = createMQTTConnection(RandomUtil.randomUUIDString(), true);
          mqtt.setUserName(fullUser);
          mqtt.setPassword(fullPass);
          mqtt.setConnectAttemptsMax(1);
@@ -106,14 +106,14 @@ public class MQTTSecurityManagerTest extends MQTTTestSupport {
          assertTrue(Wait.waitFor(() -> finalConnection.isConnected(), 5000, 100), "Should be connected");
          Map<String, MQTTSessionState> sessionStates = null;
          Acceptor acceptor = server.getRemotingService().getAcceptor("MQTT");
-         if (acceptor instanceof AbstractAcceptor) {
-            ProtocolManager protocolManager = ((AbstractAcceptor) acceptor).getProtocolMap().get("MQTT");
-            if (protocolManager instanceof MQTTProtocolManager) {
-               sessionStates = ((MQTTProtocolManager) protocolManager).getStateManager().getSessionStates();
+         if (acceptor instanceof AbstractAcceptor abstractAcceptor) {
+            ProtocolManager protocolManager = abstractAcceptor.getProtocolMap().get("MQTT");
+            if (protocolManager instanceof MQTTProtocolManager mqttProtocolManager) {
+               sessionStates = mqttProtocolManager.getStateManager().getSessionStates();
             }
          }
          assertEquals(1, sessionStates.size());
-         assertTrue(sessionStates.keySet().contains(clientID));
+         assertTrue(sessionStates.containsKey(clientID));
          for (MQTTSessionState state : sessionStates.values()) {
             assertEquals(clientID, state.getClientId());
          }
@@ -127,7 +127,7 @@ public class MQTTSecurityManagerTest extends MQTTTestSupport {
    public void testSecurityManagerModifyClientIDAndStealConnection() throws Exception {
       BlockingConnection connection1 = null;
       BlockingConnection connection2 = null;
-      final String CLIENT_ID = "old-" + RandomUtil.randomString();
+      final String CLIENT_ID = "old-" + RandomUtil.randomUUIDString();
       try {
          MQTT mqtt = createMQTTConnection(CLIENT_ID, true);
          mqtt.setUserName(fullUser);
@@ -139,14 +139,14 @@ public class MQTTSecurityManagerTest extends MQTTTestSupport {
          assertTrue(Wait.waitFor(() -> finalConnection.isConnected(), 5000, 100), "Should be connected");
          Map<String, MQTTSessionState> sessionStates = null;
          Acceptor acceptor = server.getRemotingService().getAcceptor("MQTT");
-         if (acceptor instanceof AbstractAcceptor) {
-            ProtocolManager protocolManager = ((AbstractAcceptor) acceptor).getProtocolMap().get("MQTT");
-            if (protocolManager instanceof MQTTProtocolManager) {
-               sessionStates = ((MQTTProtocolManager) protocolManager).getStateManager().getSessionStates();
+         if (acceptor instanceof AbstractAcceptor abstractAcceptor) {
+            ProtocolManager protocolManager = abstractAcceptor.getProtocolMap().get("MQTT");
+            if (protocolManager instanceof MQTTProtocolManager manager) {
+               sessionStates = manager.getStateManager().getSessionStates();
             }
          }
          assertEquals(1, sessionStates.size());
-         assertTrue(sessionStates.keySet().contains(clientID));
+         assertTrue(sessionStates.containsKey(clientID));
          for (MQTTSessionState state : sessionStates.values()) {
             assertEquals(clientID, state.getClientId());
          }
@@ -157,7 +157,7 @@ public class MQTTSecurityManagerTest extends MQTTTestSupport {
          assertTrue(Wait.waitFor(() -> finalConnection2.isConnected(), 5000, 100), "Should be connected");
          Wait.assertFalse(() -> finalConnection.isConnected(), 5000, 100);
          assertEquals(1, sessionStates.size());
-         assertTrue(sessionStates.keySet().contains(clientID));
+         assertTrue(sessionStates.containsKey(clientID));
          for (MQTTSessionState state : sessionStates.values()) {
             assertEquals(clientID, state.getClientId());
          }
@@ -172,7 +172,7 @@ public class MQTTSecurityManagerTest extends MQTTTestSupport {
       rejectClientId = true;
       BlockingConnection connection = null;
       try {
-         MQTT mqtt = createMQTTConnection(RandomUtil.randomString(), true);
+         MQTT mqtt = createMQTTConnection(RandomUtil.randomUUIDString(), true);
          mqtt.setUserName(fullUser);
          mqtt.setPassword(fullPass);
          mqtt.setConnectAttemptsMax(1);
