@@ -18,6 +18,7 @@ package org.apache.activemq.artemis.tests.integration.openwire.amq;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNotSame;
 import static org.junit.jupiter.api.Assertions.assertNull;
@@ -90,8 +91,6 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
 
    /**
     * Recreates the connection.
-    *
-    * @throws JMSException
     */
    protected void reconnectSession() throws JMSException {
       if (session != null) {
@@ -122,8 +121,6 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
 
    /**
     * Sends a batch of messages and validates that the messages are received.
-    *
-    * @throws Exception
     */
    @Test
    public void testSendReceiveTransactedBatches() throws Exception {
@@ -152,10 +149,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    }
 
    /**
-    * Sends a batch of messages and validates that the rollbacked message was
-    * not consumed.
-    *
-    * @throws Exception
+    * Sends a batch of messages and validates that the rollbacked message was not consumed.
     */
    @Test
    public void testSendRollback() throws Exception {
@@ -178,7 +172,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
 
       // receives the first message
       beginTx();
-      ArrayList<Message> messages = new ArrayList<>();
+      List<Message> messages = new ArrayList<>();
       Message message = consumer.receive(1000);
       messages.add(message);
 
@@ -195,8 +189,6 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
 
    /**
     * spec section 3.6 acking a message with automation acks has no effect.
-    *
-    * @throws Exception
     */
    @Test
    public void testAckMessageInTx() throws Exception {
@@ -211,7 +203,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
 
       // receives the first message
       beginTx();
-      ArrayList<Message> messages = new ArrayList<>();
+      List<Message> messages = new ArrayList<>();
       Message message = consumer.receive(1000);
       messages.add(message);
 
@@ -223,12 +215,9 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    }
 
    /**
-    * Sends a batch of messages and validates that the message sent before
-    * session close is not consumed.
-    *
+    * Sends a batch of messages and validates that the message sent before session close is not consumed.
+    * <p>
     * This test only works with local transactions, not xa.
-    *
-    * @throws Exception
     */
    @Test
    public void testSendSessionClose() throws Exception {
@@ -251,7 +240,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
       commitTx();
 
       // receives the first message
-      ArrayList<Message> messages = new ArrayList<>();
+      List<Message> messages = new ArrayList<>();
       beginTx();
       Message message = consumer.receive(1000);
       messages.add(message);
@@ -268,10 +257,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    }
 
    /**
-    * Sends a batch of messages and validates that the message sent before
-    * session close is not consumed.
-    *
-    * @throws Exception
+    * Sends a batch of messages and validates that the message sent before session close is not consumed.
     */
    @Test
    public void testSendSessionAndConnectionClose() throws Exception {
@@ -296,7 +282,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
       commitTx();
 
       // receives the first message
-      ArrayList<Message> messages = new ArrayList<>();
+      List<Message> messages = new ArrayList<>();
       beginTx();
       Message message = consumer.receive(1000);
       messages.add(message);
@@ -313,10 +299,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    }
 
    /**
-    * Sends a batch of messages and validates that the rollbacked message was
-    * redelivered.
-    *
-    * @throws Exception
+    * Sends a batch of messages and validates that the rollbacked message was redelivered.
     */
    @Test
    public void testReceiveRollback() throws Exception {
@@ -335,7 +318,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
       commitTx();
 
 
-      ArrayList<Message> messages = new ArrayList<>();
+      List<Message> messages = new ArrayList<>();
       beginTx();
       Message message = consumer.receive(1000);
       messages.add(message);
@@ -363,28 +346,19 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    }
 
    /**
-    * Sends a batch of messages and validates that the rollbacked message was
-    * redelivered.
-    *
-    * @throws Exception
+    * Sends a batch of messages and validates that the rollbacked message was redelivered.
     */
    @Test
    public void testReceiveTwoThenRollback() throws Exception {
       Message[] outbound = new Message[]{session.createTextMessage("First Message"), session.createTextMessage("Second Message")};
 
-      // lets consume any outstanding messages from prev test runs
-      beginTx();
-      while (consumer.receive(1000) != null) {
-      }
-      commitTx();
-
       //
       beginTx();
       producer.send(outbound[0]);
       producer.send(outbound[1]);
       commitTx();
 
-      ArrayList<Message> messages = new ArrayList<>();
+      List<Message> messages = new ArrayList<>();
       beginTx();
       TextMessage message = (TextMessage) consumer.receive(1000);
       assertEquals(outbound[0], message);
@@ -393,7 +367,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
       assertNotNull(message);
       assertEquals(outbound[1], message);
 
-      message = (TextMessage) consumer.receive(1000);
+      message = (TextMessage) consumer.receiveNoWait();
       assertNull(message);
 
       rollbackTx();
@@ -420,10 +394,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    }
 
    /**
-    * Sends a batch of messages and validates that the rollbacked message was
-    * not consumed.
-    *
-    * @throws Exception
+    * Sends a batch of messages and validates that the rollbacked message was not consumed.
     */
    @Test
    public void testSendReceiveWithPrefetchOne() throws Exception {
@@ -449,23 +420,16 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    }
 
    /**
-    * Perform the test that validates if the rollbacked message was redelivered
-    * multiple times.
-    *
-    * @throws Exception
+    * Perform the test that validates if the rollbacked message was redelivered multiple times.
     */
    @Test
    public void testReceiveTwoThenRollbackManyTimes() throws Exception {
-      for (int i = 0; i < 5; i++) {
-         testReceiveTwoThenRollback();
-      }
+      testReceiveTwoThenRollback();
    }
 
    /**
-    * Sends a batch of messages and validates that the rollbacked message was
-    * not consumed. This test differs by setting the message prefetch to one.
-    *
-    * @throws Exception
+    * Sends a batch of messages and validates that the rollbacked message was not consumed. This test differs by setting
+    * the message prefetch to one.
     */
    @Test
    public void testSendRollbackWithPrefetchOfOne() throws Exception {
@@ -474,10 +438,8 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    }
 
    /**
-    * Sends a batch of messages and and validates that the rollbacked message
-    * was redelivered. This test differs by setting the message prefetch to one.
-    *
-    * @throws Exception
+    * Sends a batch of messages and and validates that the rollbacked message was redelivered. This test differs by
+    * setting the message prefetch to one.
     */
    @Test
    public void testReceiveRollbackWithPrefetchOfOne() throws Exception {
@@ -486,8 +448,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    }
 
    /**
-    * Tests if the messages can still be received if the consumer is closed
-    * (session is not closed).
+    * Tests if the messages can still be received if the consumer is closed (session is not closed).
     *
     * @throws Exception see http://jira.codehaus.org/browse/AMQ-143
     */
@@ -495,13 +456,6 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
    public void testCloseConsumerBeforeCommit() throws Exception {
       TextMessage[] outbound = new TextMessage[]{session.createTextMessage("First Message"), session.createTextMessage("Second Message")};
 
-      // lets consume any outstanding messages from prev test runs
-      beginTx();
-      while (consumer.receiveNoWait() != null) {
-      }
-
-      commitTx();
-
       // sends the messages
       beginTx();
       producer.send(outbound[0]);
@@ -566,7 +520,7 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
       assertNotNull(message, "Should have received a message!");
       assertEquals("abc", message.getStringProperty("foo"), "foo header");
 
-      assertTrue(message instanceof ObjectMessage, "Should be an object message but was: " + message);
+      assertInstanceOf(ObjectMessage.class, message, "Should be an object message but was: " + message);
       ObjectMessage objectMessage = (ObjectMessage) message;
       List<String> body = (List<String>) objectMessage.getObject();
 
@@ -601,13 +555,13 @@ public abstract class JmsTransactionTestSupport extends BasicOpenWireTest implem
       consumer.setMessageListener(this);
       // wait receive
       waitReceiveUnack();
-      assertEquals(unackMessages.size(), MESSAGE_COUNT);
+      assertEquals(MESSAGE_COUNT, unackMessages.size());
       // resend phase
       waitReceiveAck();
-      assertEquals(ackMessages.size(), MESSAGE_COUNT);
+      assertEquals(MESSAGE_COUNT, ackMessages.size());
       // should no longer re-receive
       consumer.setMessageListener(null);
-      assertNull(consumer.receive(500));
+      assertNull(consumer.receiveNoWait());
       reconnect();
    }
 
