@@ -63,7 +63,7 @@ import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory;
 import org.apache.activemq.artemis.logs.AssertionLoggerHandler;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
-import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.tests.util.Wait;
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.BeforeEach;
@@ -96,8 +96,8 @@ public class JournalPagingTest extends ActiveMQTestBase {
       if (loggerHandler != null) {
          try {
             // These are the message errors for the negative size address size
-            assertFalse(loggerHandler.findText("222214"));
-            assertFalse(loggerHandler.findText("222215"));
+            assertFalse(loggerHandler.findText("AMQ222214"));
+            assertFalse(loggerHandler.findText("AMQ222215"));
          } finally {
             loggerHandler.close();
          }
@@ -148,12 +148,12 @@ public class JournalPagingTest extends ActiveMQTestBase {
       Queue queue = server.locateQueue(ADDRESS);
       queue.getPagingStore().startPaging();
 
-      queue.getPagingStore().forceAnotherPage(); // forcing an empty file, just to make it more challenging
+      queue.getPagingStore().forceAnotherPage(true); // forcing an empty file, just to make it more challenging
 
       int page = 1;
       for (int i = 0; i < numberOfMessages; i++) {
          if (i % 10 == 0 && i > 0) {
-            queue.getPagingStore().forceAnotherPage();
+            queue.getPagingStore().forceAnotherPage(true);
             page++;
          }
          message = session.createMessage(true);
@@ -215,7 +215,7 @@ public class JournalPagingTest extends ActiveMQTestBase {
       page4.delete(null);
       page4.open(true);
       for (int i = 0; i < 9; i++) {
-         page4.write(messagesRead.get(i)); // this will make message 29 disappear
+         page4.write(messagesRead.get(i), true, false); // this will make message 29 disappear
       }
       page4.close(false);
 
@@ -324,7 +324,7 @@ public class JournalPagingTest extends ActiveMQTestBase {
 
       server.start();
 
-      SimpleString queue = SimpleString.of("testPurge:" + RandomUtil.randomString());
+      SimpleString queue = SimpleString.of("testPurge:" + RandomUtil.randomUUIDString());
       server.addAddressInfo(new AddressInfo(queue, RoutingType.ANYCAST));
       QueueImpl purgeQueue = (QueueImpl) server.createQueue(QueueConfiguration.of(queue).setRoutingType(RoutingType.ANYCAST).setMaxConsumers(1).setPurgeOnNoConsumers(true).setAutoCreateAddress(false));
 
@@ -455,7 +455,7 @@ public class JournalPagingTest extends ActiveMQTestBase {
 
          if (i == 4) {
             session.commit();
-            queue.getPageSubscription().getPagingStore().forceAnotherPage();
+            queue.getPageSubscription().getPagingStore().forceAnotherPage(true);
          }
       }
 
@@ -508,10 +508,6 @@ public class JournalPagingTest extends ActiveMQTestBase {
       session.commit();
    }
 
-   /**
-    * @param queue
-    * @throws InterruptedException
-    */
    private void forcePage(Queue queue) throws InterruptedException {
       for (long timeout = System.currentTimeMillis() + 5000; timeout > System.currentTimeMillis() && !queue.getPageSubscription().getPagingStore().isPaging(); ) {
          Thread.sleep(10);
@@ -578,7 +574,8 @@ public class JournalPagingTest extends ActiveMQTestBase {
    }
 
    /**
-    * This test will remove all the page directories during a restart, simulating a crash scenario. The server should still start after this
+    * This test will remove all the page directories during a restart, simulating a crash scenario. The server should
+    * still start after this
     */
    @Test
    public void testDeletePhysicalPages() throws Exception {
