@@ -65,8 +65,8 @@ import org.apache.activemq.artemis.tests.util.Wait;
 import org.junit.jupiter.api.Test;
 
 /**
- * A PagingOrderTest. PagingTest has a lot of tests already. I decided to create a newer one more
- * specialized on Ordering and counters
+ * A PagingOrderTest. PagingTest has a lot of tests already. I decided to create a newer one more specialized on
+ * Ordering and counters
  */
 public class PagingOrderTest extends ActiveMQTestBase {
 
@@ -272,14 +272,13 @@ public class PagingOrderTest extends ActiveMQTestBase {
       q2 = null;
 
       for (Binding bind : bindings.getBindings()) {
-         if (bind instanceof LocalQueueBinding) {
-            LocalQueueBinding qb = (LocalQueueBinding) bind;
-            if (qb.getQueue().getName().equals(ADDRESS)) {
-               q1 = qb.getQueue();
+         if (bind instanceof LocalQueueBinding localQueueBinding) {
+            if (localQueueBinding.getQueue().getName().equals(ADDRESS)) {
+               q1 = localQueueBinding.getQueue();
             }
 
-            if (qb.getQueue().getName().equals(SimpleString.of("inactive"))) {
-               q2 = qb.getQueue();
+            if (localQueueBinding.getQueue().getName().equals(SimpleString.of("inactive"))) {
+               q2 = localQueueBinding.getQueue();
             }
          }
       }
