@@ -18,6 +18,7 @@ package org.apache.activemq.artemis.tests.integration.ra;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
@@ -90,7 +91,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "teststring");
+      assertEquals("teststring", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
 
@@ -163,7 +164,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "teststring");
+      assertEquals("teststring", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
 
@@ -255,7 +256,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       try {
          Object obj = objMsg.getObject();
          assertTrue(shouldSucceed, "deserialization should fail but got: " + obj);
-         assertTrue(obj instanceof DummySerializable);
+         assertInstanceOf(DummySerializable.class, obj);
       } catch (JMSException e) {
          assertFalse(shouldSucceed, "got unexpected exception: " + e);
       }
@@ -371,9 +372,6 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       qResourceAdapter.stop();
    }
 
-   /**
-    * @return
-    */
    @Override
    protected ActiveMQResourceAdapter newResourceAdapter() {
       ActiveMQResourceAdapter qResourceAdapter = new ActiveMQResourceAdapter();
@@ -426,7 +424,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "teststring");
+      assertEquals("teststring", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       server.stop();
 
@@ -484,7 +482,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "teststring");
+      assertEquals("teststring", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
       qResourceAdapter.stop();
@@ -520,7 +518,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "red");
+      assertEquals("red", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
       qResourceAdapter.stop();
@@ -542,9 +540,9 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       DummyMessageEndpointFactory endpointFactory = new DummyMessageEndpointFactory(endpoint, false);
       qResourceAdapter.endpointActivation(endpointFactory, spec);
       Binding binding = server.getPostOffice().getBinding(MDBQUEUEPREFIXEDSIMPLE);
-      assertEquals(((LocalQueueBinding) binding).getQueue().getConsumerCount(), 15);
+      assertEquals(15, ((LocalQueueBinding) binding).getQueue().getConsumerCount());
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
-      assertEquals(((LocalQueueBinding) binding).getQueue().getConsumerCount(), 0);
+      assertEquals(0, ((LocalQueueBinding) binding).getQueue().getConsumerCount());
       assertTrue(endpoint.released);
       qResourceAdapter.stop();
    }
@@ -566,7 +564,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       DummyMessageEndpointFactory endpointFactory = new DummyMessageEndpointFactory(endpoint, false);
       qResourceAdapter.endpointActivation(endpointFactory, spec);
       Binding binding = server.getPostOffice().getBinding(MDBQUEUEPREFIXEDSIMPLE);
-      assertEquals(((LocalQueueBinding) binding).getQueue().getConsumerCount(), 1);
+      assertEquals(1, ((LocalQueueBinding) binding).getQueue().getConsumerCount());
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
       qResourceAdapter.stop();
    }
@@ -595,7 +593,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "test");
+      assertEquals("test", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
       qResourceAdapter.stop();
@@ -628,7 +626,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "1");
+      assertEquals("1", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
 
@@ -643,7 +641,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "2");
+      assertEquals("2", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
       latch = new CountDownLatch(1);
       endpoint.reset(latch);
       message = session.createMessage(true);
@@ -652,7 +650,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "3");
+      assertEquals("3", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
       qResourceAdapter.stop();
    }
@@ -681,7 +679,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "1");
+      assertEquals("1", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
 
@@ -699,12 +697,11 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "3");
+      assertEquals("3", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
       qResourceAdapter.stop();
    }
 
-   //https://issues.jboss.org/browse/JBPAPP-8017
    @Test
    public void testNonDurableSubscriptionDeleteAfterCrash() throws Exception {
       ActiveMQResourceAdapter qResourceAdapter = newResourceAdapter();
@@ -730,7 +727,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "1");
+      assertEquals("1", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       ActiveMQActivation activation = lookupActivation(qResourceAdapter);
 
@@ -783,7 +780,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "1");
+      assertEquals("1", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
 
@@ -805,7 +802,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "3");
+      assertEquals("3", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
       qResourceAdapter.stop();
    }
@@ -895,7 +892,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
          qResourceAdapter.endpointActivation(endpointFactory, spec);
          fail();
       } catch (Exception e) {
-         assertTrue(e instanceof InvalidPropertyException);
+         assertInstanceOf(InvalidPropertyException.class, e);
          assertEquals("subscriptionName", ((InvalidPropertyException) e).getInvalidPropertyDescriptors()[0].getName());
       }
    }
@@ -922,7 +919,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
          qResourceAdapter.endpointActivation(endpointFactory, spec);
          fail();
       } catch (Exception e) {
-         assertTrue(e instanceof InvalidPropertyException);
+         assertInstanceOf(InvalidPropertyException.class, e);
          assertEquals("destinationType", ((InvalidPropertyException) e).getInvalidPropertyDescriptors()[0].getName());
       }
    }
@@ -956,7 +953,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "1");
+      assertEquals("1", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
 
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
 
@@ -972,7 +969,7 @@ public class ActiveMQMessageHandlerTest extends ActiveMQRATestBase {
       latch.await(5, TimeUnit.SECONDS);
 
       assertNotNull(endpoint.lastMessage);
-      assertEquals(endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString(), "2");
+      assertEquals("2", endpoint.lastMessage.getCoreMessage().getBodyBuffer().readString());
       qResourceAdapter.endpointDeactivation(endpointFactory, spec);
       qResourceAdapter.stop();
 
