@@ -16,13 +16,6 @@
  */
 package org.apache.activemq.artemis.tests.integration.ra;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
-
 import javax.jms.Connection;
 import javax.resource.ResourceException;
 import javax.resource.spi.endpoint.MessageEndpoint;
@@ -58,6 +51,13 @@ import org.apache.activemq.artemis.utils.DefaultSensitiveStringCodec;
 import org.apache.activemq.artemis.utils.PasswordMaskingUtil;
 import org.junit.jupiter.api.Test;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
 public class ResourceAdapterTest extends ActiveMQRATestBase {
 
    @Test
@@ -372,7 +372,6 @@ public class ResourceAdapterTest extends ActiveMQRATestBase {
       assertEquals(qResourceAdapter.getUserName(), testuser);
    }
 
-   // https://issues.jboss.org/browse/JBPAPP-5790
    @Test
    public void testResourceAdapterSetup() throws Exception {
       ActiveMQResourceAdapter adapter = new ActiveMQResourceAdapter();
@@ -425,7 +424,6 @@ public class ResourceAdapterTest extends ActiveMQRATestBase {
 
    }
 
-   // https://issues.jboss.org/browse/JBPAPP-5836
    @Test
    public void testResourceAdapterSetupOverrideCFParams() throws Exception {
       ActiveMQResourceAdapter qResourceAdapter = new ActiveMQResourceAdapter();
@@ -519,10 +517,10 @@ public class ResourceAdapterTest extends ActiveMQRATestBase {
       ActiveMQConnectionFactory fac = qResourceAdapter.getConnectionFactory(spec);
       DiscoveryGroupConfiguration dc = fac.getServerLocator().getDiscoveryGroupConfiguration();
       UDPBroadcastEndpointFactory udpDg = (UDPBroadcastEndpointFactory) dc.getBroadcastEndpointFactory();
-      assertEquals(udpDg.getGroupAddress(), "231.6.6.6");
-      assertEquals(udpDg.getGroupPort(), 1234);
-      assertEquals(dc.getRefreshTimeout(), 1L);
-      assertEquals(dc.getDiscoveryInitialWaitTimeout(), 1L);
+      assertEquals("231.6.6.6", udpDg.getGroupAddress());
+      assertEquals(1234, udpDg.getGroupPort());
+      assertEquals(1L, dc.getRefreshTimeout());
+      assertEquals(1L, dc.getDiscoveryInitialWaitTimeout());
       qResourceAdapter.stop();
    }
 
@@ -547,10 +545,10 @@ public class ResourceAdapterTest extends ActiveMQRATestBase {
       ActiveMQConnectionFactory fac = qResourceAdapter.getConnectionFactory(spec);
       DiscoveryGroupConfiguration dc = fac.getServerLocator().getDiscoveryGroupConfiguration();
       UDPBroadcastEndpointFactory udpDg = (UDPBroadcastEndpointFactory) dc.getBroadcastEndpointFactory();
-      assertEquals(udpDg.getGroupAddress(), "231.6.6.6");
-      assertEquals(udpDg.getGroupPort(), 1234);
-      assertEquals(dc.getRefreshTimeout(), 1L);
-      assertEquals(dc.getDiscoveryInitialWaitTimeout(), 1L);
+      assertEquals("231.6.6.6", udpDg.getGroupAddress());
+      assertEquals(1234, udpDg.getGroupPort());
+      assertEquals(1L, dc.getRefreshTimeout());
+      assertEquals(1L, dc.getDiscoveryInitialWaitTimeout());
       qResourceAdapter.stop();
    }
 
@@ -848,10 +846,10 @@ public class ResourceAdapterTest extends ActiveMQRATestBase {
    public void testConnectionParameterStringParsing() throws Exception {
       ActiveMQResourceAdapter resourceAdapter = new ActiveMQResourceAdapter();
       resourceAdapter.setConnectionParameters("enabledProtocols=TLS1\\,TLS1.2;sslEnabled=true");
-      assertEquals(resourceAdapter.getProperties().getParsedConnectionParameters().get(0).get("enabledProtocols"), "TLS1,TLS1.2");
+      assertEquals("TLS1,TLS1.2", resourceAdapter.getProperties().getParsedConnectionParameters().get(0).get("enabledProtocols"));
       resourceAdapter.setConnectionParameters("enabledProtocols=TLS1\\,TLS1.2;sslEnabled=true,enabledProtocols=TLS1.3\\,TLS1.4\\,TLS1.5;sslEnabled=true");
-      assertEquals(resourceAdapter.getProperties().getParsedConnectionParameters().get(0).get("enabledProtocols"), "TLS1,TLS1.2");
-      assertEquals(resourceAdapter.getProperties().getParsedConnectionParameters().get(1).get("enabledProtocols"), "TLS1.3,TLS1.4,TLS1.5");
+      assertEquals("TLS1,TLS1.2", resourceAdapter.getProperties().getParsedConnectionParameters().get(0).get("enabledProtocols"));
+      assertEquals("TLS1.3,TLS1.4,TLS1.5", resourceAdapter.getProperties().getParsedConnectionParameters().get(1).get("enabledProtocols"));
 
       try {
          resourceAdapter.setConnectionParameters("enabledProtocols=TLS1,TLS1.2;sslEnabled=true,enabledProtocols=TLS1,TLS1.2;sslEnabled=true");
