@@ -16,14 +16,17 @@
  */
 package org.apache.activemq.artemis.tests.integration.server;
 
+import org.apache.activemq.artemis.logs.AssertionLoggerHandler;
 import org.junit.jupiter.api.Test;
 
 public class NIOFileLockTimeoutTest extends FileLockTimeoutTest {
 
    /**
-    * When running this test from an IDE add this to the test command line so that the AssertionLoggerHandler works properly:
-    *
-    *   -Dlog4j2.configurationFile=file:<path_to_source>/tests/config/log4j2-tests-config.properties
+    * When running this test from an IDE add this to the test command line so that the {@link AssertionLoggerHandler} works
+    * properly:
+    * <pre>
+    * -Dlog4j2.configurationFile=file:${path-to-source}/tests/config/log4j2-tests-config.properties
+    * </pre>
     */
    @Test
    public void testNIOFileLockExpiration() throws Exception {
