@@ -16,12 +16,16 @@
  */
 package org.apache.activemq.artemis.tests.performance.storage;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+
 import java.io.File;
 import java.util.Collection;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.LinkedBlockingDeque;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
+import java.util.function.Consumer;
+import java.util.function.Function;
 
 import org.apache.activemq.artemis.api.config.ActiveMQDefaultConfiguration;
 import org.apache.activemq.artemis.api.core.Message;
@@ -44,8 +48,8 @@ import org.apache.activemq.artemis.core.settings.impl.PageFullMessagePolicy;
 import org.apache.activemq.artemis.core.transaction.Transaction;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.utils.actors.ArtemisExecutor;
-import org.junit.Assert;
-import org.junit.Test;
+import org.apache.activemq.artemis.utils.runnables.AtomicRunnable;
+import org.junit.jupiter.api.Test;
 
 public class PersistMultiThreadTest extends ActiveMQTestBase {
 
@@ -109,11 +113,11 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
 
       for (MyThread t : threads) {
          t.join();
-         Assert.assertEquals(0, t.errors.get());
+         assertEquals(0, t.errors.get());
       }
 
       deleteThread.join();
-      Assert.assertEquals(0, deleteThread.errors.get());
+      assertEquals(0, deleteThread.errors.get());
 
    }
 
@@ -267,6 +271,11 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
 
       }
 
+      @Override
+      public Page usePage(long page, boolean createEntry, boolean createFile) {
+         return null;
+      }
+
       @Override
       public boolean isPageFull() {
          return false;
@@ -277,6 +286,21 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
 
       }
 
+      @Override
+      public void readLock() {
+
+      }
+
+      @Override
+      public boolean readLock(long timeout) {
+         return true;
+      }
+
+      @Override
+      public void readUnlock() {
+
+      }
+
       @Override
       public void counterSnapshot() {
       }
@@ -361,6 +385,11 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
          return 0;
       }
 
+      @Override
+      public long getAddressElements() {
+         return 0;
+      }
+
       @Override
       public long getMaxSize() {
          return 0;
@@ -387,8 +416,8 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
       }
 
       @Override
-      public void addSyncPoint(OperationContext context) throws Exception {
-
+      public boolean isStorePaging() {
+         return false;
       }
 
       @Override
@@ -421,6 +450,16 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
          return 0;
       }
 
+      @Override
+      public int getPrefetchPageBytes() {
+         return 0;
+      }
+
+      @Override
+      public int getPrefetchPageMessages() {
+         return 0;
+      }
+
       @Override
       public boolean page(Message message,
                           Transaction tx,
@@ -428,6 +467,15 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
          return false;
       }
 
+      @Override
+      public int page(Message message,
+                          Transaction tx,
+                          RouteContextList listCtx,
+                          Function<Message, Message> pageDecorator,
+                          boolean useFlowControl) throws Exception {
+         return -1;
+      }
+
       @Override
       public boolean checkPageFileExists(long page) throws Exception {
          return false;
@@ -454,7 +502,7 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
       }
 
       @Override
-      public void forceAnotherPage() throws Exception {
+      public void forceAnotherPage(boolean useExecutor) throws Exception {
 
       }
 
@@ -470,11 +518,10 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
 
       @Override
       public void stopPaging() throws Exception {
-
       }
 
       @Override
-      public void addSize(int size, boolean sizeOnly) {
+      public void addSize(int size, boolean sizeOnly, boolean affectGlobal) {
       }
 
       @Override
@@ -483,22 +530,26 @@ public class PersistMultiThreadTest extends ActiveMQTestBase {
       }
 
       @Override
-      public boolean checkMemory(boolean runOnFailure, Runnable runnable, Runnable ignoredRunnable) {
+      public boolean checkMemory(boolean runOnFailure, Runnable runnable, Runnable ignoredRunnable, Consumer<AtomicRunnable> accepted) {
          return false;
       }
 
       @Override
-      public boolean checkMemory(Runnable runnable) {
+      public boolean checkMemory(Runnable runnable, Consumer<AtomicRunnable> accepted) {
          return false;
       }
 
       @Override
-      public boolean lock(long timeout) {
+      public void writeLock() {
+      }
+
+      @Override
+      public boolean writeLock(long timeout) {
          return false;
       }
 
       @Override
-      public void unlock() {
+      public void writeUnlock() {
 
       }
 
