@@ -1,23 +1,25 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * <br>
- * http://www.apache.org/licenses/LICENSE-2.0
- * <br>
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
+ * Licensed to the Apache Software Foundation (ASF) under one
+ * or more contributor license agreements.  See the NOTICE file
+ * distributed with this work for additional information
+ * regarding copyright ownership.  The ASF licenses this file
+ * to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance
+ * with the License.  You may obtain a copy of the License at
+ *
+ *   http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
  */
-
 package org.apache.activemq.artemis.tests.smoke.jmx;
 
 import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertInstanceOf;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.Assertions.fail;
@@ -36,7 +38,7 @@ import java.rmi.server.RemoteRef;
 
 import io.netty.util.internal.PlatformDependent;
 import org.apache.activemq.artemis.tests.smoke.common.SmokeTestBase;
-import org.apache.activemq.artemis.utils.cli.helper.HelperCreate;
+import org.apache.activemq.artemis.cli.commands.helper.HelperCreate;
 import org.jctools.util.UnsafeAccess;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
@@ -64,7 +66,7 @@ public class JmxConnectionTest extends SmokeTestBase {
       deleteDirectory(server0Location);
 
       {
-         HelperCreate cliCreateServer = new HelperCreate();
+         HelperCreate cliCreateServer = helperCreate();
          cliCreateServer.setUser("admin").setPassword("admin").setAllowAnonymous(true).setNoWeb(true).setArtemisInstance(server0Location).
             setConfiguration("./src/main/resources/servers/jmx").setArgs("--java-options", "-Djava.rmi.server.hostname=localhost");
          cliCreateServer.createServer();
@@ -116,11 +118,12 @@ public class JmxConnectionTest extends SmokeTestBase {
 
          try {
 
-         /* Now I need to extract the RMI registry port to make sure it's equal to the configured one. It's gonna be
+         /*
+          * Now I need to extract the RMI registry port to make sure it's equal to the configured one. It's gonna be
           * messy because I have to use reflection to reach the information.
           */
 
-            assertTrue(jmxConnector instanceof RMIConnector);
+            assertInstanceOf(RMIConnector.class, jmxConnector);
 
             // 1. RMIConnector::connection is expected to be RMIConnectionImpl_Stub
             Field connectionField = RMIConnector.class.getDeclaredField("connection");
@@ -128,7 +131,7 @@ public class JmxConnectionTest extends SmokeTestBase {
             RMIConnection rmiConnection = (RMIConnection) connectionField.get(jmxConnector);
 
             // 2. RMIConnectionImpl_Stub extends RemoteStub which extends RemoteObject
-            assertTrue(rmiConnection instanceof RemoteObject);
+            assertInstanceOf(RemoteObject.class, rmiConnection);
             RemoteObject remoteObject = (RemoteObject) rmiConnection;
 
             // 3. RemoteObject::getRef is hereby expected to return ProxyRef
