@@ -38,6 +38,7 @@ import java.io.StringWriter;
 import java.lang.invoke.MethodHandles;
 import java.util.HashSet;
 import java.util.Properties;
+import java.util.Set;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.Executor;
 import java.util.concurrent.ExecutorService;
@@ -54,7 +55,7 @@ import org.apache.activemq.artemis.core.server.ActiveMQServer;
 import org.apache.activemq.artemis.core.server.impl.AddressInfo;
 import org.apache.activemq.artemis.tests.soak.SoakTestBase;
 import org.apache.activemq.artemis.tests.util.CFUtil;
-import org.apache.activemq.artemis.tests.util.RandomUtil;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.util.ServerUtil;
 import org.apache.activemq.artemis.utils.FileUtil;
 import org.apache.activemq.artemis.utils.Wait;
@@ -291,7 +292,7 @@ public class ClusteredMirrorSoakTest extends SoakTestBase {
 
       final int numberOfMessages = 200;
 
-      assertTrue(numberOfMessages % 2 == 0, "numberOfMessages must be even");
+      assertEquals(0, numberOfMessages % 2, "numberOfMessages must be even");
 
       ConnectionFactory connectionFactoryDC1A = CFUtil.createConnectionFactory("amqp", DC1_NODEA_URI);
       ConnectionFactory connectionFactoryDC2A = CFUtil.createConnectionFactory("amqp", DC2_NODEA_URI);
@@ -366,7 +367,7 @@ public class ClusteredMirrorSoakTest extends SoakTestBase {
    private CountDownLatch startConsumer(Executor executor, ConnectionFactory factory, String queue, AtomicBoolean running, AtomicInteger errorCount, AtomicInteger receivedCount) {
       CountDownLatch done = new CountDownLatch(1);
 
-      HashSet<Integer> receivedMessages = new HashSet<>();
+      Set<Integer> receivedMessages = new HashSet<>();
 
       executor.execute(() -> {
          try {
@@ -444,7 +445,7 @@ public class ClusteredMirrorSoakTest extends SoakTestBase {
       createRealServers(false);
       startServers();
 
-      String queueName = "testqueue" + RandomUtil.randomString();
+      String queueName = "testqueue" + RandomUtil.randomUUIDString();
 
       final int numberOfMessages = 50;
 
@@ -514,7 +515,7 @@ public class ClusteredMirrorSoakTest extends SoakTestBase {
 
       final int numberOfMessages = 200;
 
-      assertTrue(numberOfMessages % 2 == 0, "numberOfMessages must be even");
+      assertEquals(0, numberOfMessages % 2, "numberOfMessages must be even");
 
       String clientIDA = "nodeA";
       String clientIDB = "nodeB";
