@@ -42,6 +42,8 @@ import org.apache.activemq.artemis.api.core.management.ObjectNameBuilder;
 import org.apache.activemq.artemis.api.core.management.QueueControl;
 import org.apache.activemq.artemis.tests.soak.SoakTestBase;
 import org.apache.activemq.artemis.tests.util.CFUtil;
+import org.apache.activemq.artemis.util.ServerUtil;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.utils.Wait;
 import org.apache.activemq.artemis.cli.commands.helper.HelperCreate;
 import org.junit.jupiter.api.BeforeAll;
@@ -55,7 +57,6 @@ public class LargeMessageInterruptTest extends SoakTestBase {
 
    public static final String SERVER_NAME_0 = "interruptlm";
 
-
    @BeforeAll
    public static void createServers() throws Exception {
       {
@@ -63,14 +64,13 @@ public class LargeMessageInterruptTest extends SoakTestBase {
          deleteDirectory(serverLocation);
 
          HelperCreate cliCreateServer = helperCreate();
-         cliCreateServer.setRole("amq").setUser("artemis").setPassword("artemis").setAllowAnonymous(true).setNoWeb(false).setArtemisInstance(serverLocation).
+         cliCreateServer.setRole("amq").setUser("artemis").setPassword("artemis").setAllowAnonymous(true).setArtemisInstance(serverLocation).
             setConfiguration("./src/main/resources/servers/interruptlm");
          cliCreateServer.setArgs("--java-options", "-Djava.rmi.server.hostname=localhost", "--clustered", "--static-cluster", "tcp://localhost:61716", "--queues", "ClusteredLargeMessageInterruptTest", "--name", "lmbroker1");
          cliCreateServer.createServer();
       }
    }
 
-
    private static final String JMX_SERVER_HOSTNAME = "localhost";
    private static final int JMX_SERVER_PORT_0 = 1099;
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
@@ -78,10 +78,6 @@ public class LargeMessageInterruptTest extends SoakTestBase {
    static ObjectNameBuilder nameBuilder = ObjectNameBuilder.create(ActiveMQDefaultConfiguration.getDefaultJmxDomain(), "lminterrupt", true);
    Process serverProcess;
 
-   public ConnectionFactory createConnectionFactory(String protocol) {
-      return CFUtil.createConnectionFactory(protocol, "tcp://localhost:61616");
-   }
-
    @BeforeEach
    public void before() throws Exception {
       cleanupData(SERVER_NAME_0);
@@ -89,93 +85,38 @@ public class LargeMessageInterruptTest extends SoakTestBase {
       disableCheckThread();
    }
 
-   @Test
-   public void testInterruptLargeMessageAMQPTX() throws Throwable {
-      testInterruptLM("AMQP", true, false);
-   }
-
-   @Test
-   public void testInterruptLargeMessageAMQPTXPaging() throws Throwable {
-      testInterruptLM("AMQP", true, true);
-   }
-
-   @Test
-   public void testInterruptLargeMessageCORETX() throws Throwable {
-      testInterruptLM("CORE", true, false);
-   }
-
-   @Test
-   public void testInterruptLargeMessageCORETXPaging() throws Throwable {
-      testInterruptLM("CORE", true, true);
-   }
-
-
-   @Test
-   public void testInterruptLargeMessageOPENWIRETX() throws Throwable {
-      testInterruptLM("OPENWIRE", true, false);
-   }
-
-   @Test
-   public void testInterruptLargeMessageOPENWIRETXPaging() throws Throwable {
-      testInterruptLM("OPENWIRE", true, true);
-   }
-
-
-   @Test
-   public void testInterruptLargeMessageAMQPNonTX() throws Throwable {
-      testInterruptLM("AMQP", false, false);
-   }
-
-   @Test
-   public void testInterruptLargeMessageAMQPNonTXPaging() throws Throwable {
-      testInterruptLM("AMQP", false, true);
-   }
-
-   @Test
-   public void testInterruptLargeMessageCORENonTX() throws Throwable {
-      testInterruptLM("CORE", false, false);
-   }
-
-   @Test
-   public void testInterruptLargeMessageCORENonTXPaging() throws Throwable {
-      testInterruptLM("CORE", false, true);
-   }
-
    private void killProcess(Process process) throws Exception {
       Runtime.getRuntime().exec("kill -SIGINT " + process.pid());
    }
 
-
-   private void testInterruptLM(String protocol, boolean tx, boolean paging) throws Throwable {
+   @Test
+   public void testInterrupt() throws Throwable {
       final int BODY_SIZE = 500 * 1024;
       final int NUMBER_OF_MESSAGES = 10; // this is per producer
-      final int SENDING_THREADS = 10;
+
+      // SENDING_THREADS must have the number of tasks submitted on executorService as we will use a CyclicBarrier to align
+      // start and other controls. If you change the logic on the loop please update this number here.
+      final int SENDING_THREADS = 12;
+
       CyclicBarrier startFlag = new CyclicBarrier(SENDING_THREADS);
       final CountDownLatch done = new CountDownLatch(SENDING_THREADS);
       final AtomicInteger produced = new AtomicInteger(0);
-      final ConnectionFactory factory = createConnectionFactory(protocol);
       final AtomicInteger errors = new AtomicInteger(0); // I don't expect many errors since this test is disconnecting and reconnecting the server
-      final CountDownLatch killAt = new CountDownLatch(40);
+      final CountDownLatch killAt = new CountDownLatch(10);
 
       ExecutorService executorService = Executors.newFixedThreadPool(SENDING_THREADS);
       runAfter(executorService::shutdownNow);
 
       String queueName = "LargeMessageInterruptTest";
+      String pagedQueueName = "LargeMessageInterruptTestPaged";
 
-      String largebody;
+      String largebody = RandomUtil.randomAlphaNumericString(BODY_SIZE);
 
       {
-         StringBuffer buffer = new StringBuffer();
-         while (buffer.length() < BODY_SIZE) {
-            buffer.append("LOREM IPSUM WHATEVER THEY SAY IN THERE I DON'T REALLY CARE. I'M NOT SURE IF IT'S LOREM, LAUREM, LAUREN, IPSUM OR YPSUM AND I DON'T REALLY CARE ");
-         }
-         largebody = buffer.toString();
-      }
-
-      if (paging) {
+         ConnectionFactory factory = CFUtil.createConnectionFactory("core", "tcp://localhost:61616");
          try (Connection connection = factory.createConnection()) {
             Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
-            MessageProducer producer = session.createProducer(session.createQueue(queueName));
+            MessageProducer producer = session.createProducer(session.createQueue(pagedQueueName));
             for (int i = 0; i < 1000; i++) {
                producer.send(session.createTextMessage("forcePage"));
             }
@@ -183,60 +124,67 @@ public class LargeMessageInterruptTest extends SoakTestBase {
          }
       }
 
-      for (int i = 0; i < SENDING_THREADS; i++) {
-         executorService.execute(() -> {
-            int numberOfMessages = 0;
-            try {
-               Connection connection = factory.createConnection();
-               Session session = connection.createSession(tx, tx ? Session.SESSION_TRANSACTED : Session.AUTO_ACKNOWLEDGE);
-               MessageProducer producer = session.createProducer(session.createQueue(queueName));
+      String[] protocols = new String[]{"CORE", "AMQP", "OPENWIRE"};
+      String[] destinations = new String[] {queueName, pagedQueueName};
 
-               startFlag.await(10, TimeUnit.SECONDS);
-               while (numberOfMessages < NUMBER_OF_MESSAGES) {
+      for (String queueUsed : destinations) {
+         for (String protocolUsed : protocols) {
+            for (int i = 0; i <= 1; i++) {
+               boolean tx = i > 0;
+               logger.info("sending protocol {}, destination {}, tx={}", protocolUsed, queueUsed, tx);
+               executorService.execute(() -> {
+                  int numberOfMessages = 0;
                   try {
-                     producer.send(session.createTextMessage(largebody));
-                     if (tx) {
-                        session.commit();
-                     }
-                     produced.incrementAndGet();
-                     killAt.countDown();
-                     if (numberOfMessages++ % 10 == 0) {
-                        logger.info("Sent {}", numberOfMessages);
-                     }
-                  } catch (Exception e) {
-                     logger.warn(e.getMessage(), e);
+                     final ConnectionFactory factory = CFUtil.createConnectionFactory(protocolUsed, "tcp://localhost:61616");
+                     Connection connection = factory.createConnection();
+                     Session session = connection.createSession(tx, tx ? Session.SESSION_TRANSACTED : Session.AUTO_ACKNOWLEDGE);
+                     MessageProducer producer = session.createProducer(session.createQueue(queueUsed));
 
-                     logger.warn(e.getMessage(), e);
-                     try {
-                        connection.close();
-                     } catch (Throwable ignored) {
-                     }
-
-                     for (int retryNumber = 0; retryNumber < 100; retryNumber++) {
+                     startFlag.await(10, TimeUnit.SECONDS);
+                     while (numberOfMessages < NUMBER_OF_MESSAGES) {
                         try {
-                           Connection ctest = factory.createConnection();
-                           ctest.close();
-                           break;
-                        } catch (Throwable retry) {
-                           Thread.sleep(100);
+                           producer.send(session.createTextMessage(largebody));
+                           if (tx) {
+                              session.commit();
+                           }
+                           produced.incrementAndGet();
+                           killAt.countDown();
+                           if (numberOfMessages++ % 10 == 0) {
+                              logger.info("Sent {}", numberOfMessages);
+                           }
+                        } catch (Exception e) {
+                           logger.warn(e.getMessage(), e);
+                           try {
+                              connection.close();
+                           } catch (Throwable ignored) {
+                           }
+
+                           for (int retryNumber = 0; retryNumber < 100; retryNumber++) {
+                              try {
+                                 connection = factory.createConnection();
+                              } catch (Throwable retry) {
+                                 connection = null;
+                                 Thread.sleep(500);
+                              }
+                           }
+
+                           assertNotNull(connection, "retry did not work on createConnection");
+                           session = connection.createSession(tx, tx ? Session.SESSION_TRANSACTED : Session.AUTO_ACKNOWLEDGE);
+                           producer = session.createProducer(session.createQueue(queueName));
+                           connection.start();
+
                         }
                      }
-
-                     connection = factory.createConnection();
-                     session = connection.createSession(tx, tx ? Session.SESSION_TRANSACTED : Session.AUTO_ACKNOWLEDGE);
-                     producer = session.createProducer(session.createQueue(queueName));
-                     connection.start();
-
+                  } catch (Throwable e) {
+                     logger.warn("Error while sending protocol {}, destination {}, tx={}", protocolUsed, queueUsed, tx, e);
+                     errors.incrementAndGet();
                   }
-               }
-            } catch (Exception e) {
-               logger.warn("Error getting the initial connection", e);
-               errors.incrementAndGet();
-            }
 
-            logger.info("Done sending");
-            done.countDown();
-         });
+                  logger.info("Done sending");
+                  done.countDown();
+               });
+            }
+         }
       }
 
       assertTrue(killAt.await(60, TimeUnit.SECONDS));
@@ -247,11 +195,23 @@ public class LargeMessageInterruptTest extends SoakTestBase {
       assertTrue(done.await(60, TimeUnit.SECONDS));
       assertEquals(0, errors.get());
 
+      ServerUtil.waitForServerToStart(0, 60_000);
+
+      verifyQueue(queueName, largebody);
+      verifyQueue(pagedQueueName, largebody);
+
+      File lmFolder = new File(getServerLocation(SERVER_NAME_0) + "/data/large-messages");
+      assertTrue(lmFolder.exists());
+      Wait.assertEquals(0, () -> lmFolder.listFiles().length);
+   }
+
+   private static void verifyQueue(String queueName, String largebody) throws Throwable {
       QueueControl queueControl = getQueueControl(liveURI, nameBuilder, queueName, queueName, RoutingType.ANYCAST, 5000);
 
       long numberOfMessages = queueControl.getMessageCount();
       logger.info("there are {} messages", numberOfMessages);
 
+      ConnectionFactory factory = CFUtil.createConnectionFactory("CORE", "tcp://localhost:61616");
       try (Connection connection = factory.createConnection()) {
          Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
          MessageConsumer consumer = session.createConsumer(session.createQueue(queueName));
@@ -262,11 +222,6 @@ public class LargeMessageInterruptTest extends SoakTestBase {
             assertTrue(message.getText().equals("forcePage") || message.getText().equals(largebody));
          }
       }
-
-      File lmFolder = new File(getServerLocation(SERVER_NAME_0) + "/data/large-messages");
-      assertTrue(lmFolder.exists());
-      Wait.assertEquals(0, () -> lmFolder.listFiles().length);
-
    }
 
 }
\ No newline at end of file
