@@ -31,6 +31,7 @@ import javax.jms.TextMessage;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.List;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
@@ -40,8 +41,9 @@ import org.apache.activemq.artemis.tests.extensions.parameterized.ParameterizedT
 import org.apache.activemq.artemis.tests.extensions.parameterized.Parameters;
 import org.apache.activemq.artemis.tests.soak.SoakTestBase;
 import org.apache.activemq.artemis.tests.util.CFUtil;
+import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.utils.TestParameters;
-import org.apache.activemq.artemis.utils.cli.helper.HelperCreate;
+import org.apache.activemq.artemis.cli.commands.helper.HelperCreate;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.TestTemplate;
@@ -53,9 +55,9 @@ import java.lang.invoke.MethodHandles;
 import static org.apache.activemq.artemis.utils.TestParameters.testProperty;
 
 /**
- * Refer to ./scripts/parameters.sh for suggested parameters
- * #You may choose to use zip files to save some time on producing if you want to run this test over and over when debugging
- * export TEST_FLOW_ZIP_LOCATION=a folder */
+ * Refer to ./scripts/parameters.sh for suggested parameters #You may choose to use zip files to save some time on
+ * producing if you want to run this test over and over when debugging export TEST_FLOW_ZIP_LOCATION=a folder
+ */
 @ExtendWith(ParameterizedTestExtension.class)
 public class FlowControlPagingTest extends SoakTestBase {
 
@@ -87,7 +89,7 @@ public class FlowControlPagingTest extends SoakTestBase {
          File serverLocation = getFileServerLocation(SERVER_NAME_0);
          deleteDirectory(serverLocation);
 
-         HelperCreate cliCreateServer = new HelperCreate();
+         HelperCreate cliCreateServer = helperCreate();
          cliCreateServer.setRole("amq").setUser("admin").setPassword("admin").setAllowAnonymous(true).setNoWeb(false).setArtemisInstance(serverLocation);
          // some limited memory to make it more likely to fail
          cliCreateServer.setArgs("--java-memory", "512M");
@@ -101,7 +103,7 @@ public class FlowControlPagingTest extends SoakTestBase {
    public static Collection<Object[]> parameters() {
       String[] protocols = PROTOCOL_LIST.split(",");
 
-      ArrayList<Object[]> parameters = new ArrayList<>();
+      List<Object[]> parameters = new ArrayList<>();
       for (String str : protocols) {
          logger.info("Adding {} to the list for the test", str);
          parameters.add(new Object[]{str});
@@ -157,15 +159,7 @@ public class FlowControlPagingTest extends SoakTestBase {
          Connection connection = factory.createConnection();
          runAfter(connection::close);
 
-         String text;
-         {
-            StringBuffer buffer = new StringBuffer();
-            while (buffer.length() < MESSAGE_SIZE) {
-               buffer.append("a big string...");
-            }
-
-            text = buffer.toString();
-         }
+         String text = RandomUtil.randomAlphaNumericString(MESSAGE_SIZE);
 
          Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
          Queue queue = session.createQueue(QUEUE_NAME);
@@ -205,7 +199,7 @@ public class FlowControlPagingTest extends SoakTestBase {
       } else if (protocol.equals("OPENWIRE")) {
          factoryClient = CFUtil.createConnectionFactory("OPENWIRE", "tcp://localhost:61616");  // no flow control on openwire by default
       } else {
-         factoryClient = CFUtil.createConnectionFactory("OPENWIRE", "tcp://localhost:61616");  // no flow control on openwire by default
+         throw new IllegalStateException("protocol not defined!");
       }
 
       Connection connectionConsumer = factoryClient.createConnection();
