@@ -93,6 +93,7 @@ public class PageTimedWriterUnitTest extends ArtemisTestCase {
 
    private static final SimpleString ADDRESS = SimpleString.of("someAddress");
 
+   AtomicInteger outOfContextWrite = new AtomicInteger(0);
    ScheduledExecutorService scheduledExecutorService;
    ExecutorService executorService;
    OrderedExecutorFactory executorFactory;
@@ -189,8 +190,14 @@ public class PageTimedWriterUnitTest extends ArtemisTestCase {
       return numberOfPreparesMessageJournal.incrementAndGet();
    }
 
+   @AfterEach
+   public void validateWrites() {
+      assertEquals(0, outOfContextWrite.get(), "Wrong executor in use at page writes");
+   }
+
    @BeforeEach
    public void setupMocks() throws Exception {
+      outOfContextWrite.set(0);
       configuration = new ConfigurationImpl();
       configuration.setJournalType(JournalType.NIO);
       scheduledExecutorService = Executors.newScheduledThreadPool(10);
@@ -241,7 +248,7 @@ public class PageTimedWriterUnitTest extends ArtemisTestCase {
 
       AddressSettings settings = new AddressSettings().setPageSizeBytes(MAX_SIZE).setAddressFullMessagePolicy(AddressFullMessagePolicy.PAGE);
 
-      pageStore = new PagingStoreImpl(ADDRESS, scheduledExecutorService, 100, mockPagingManager, realJournalStorageManager, inMemoryFileFactory, mockPageStoreFactory, ADDRESS, settings, executorFactory.getExecutor(), false) {
+      pageStore = new PagingStoreImpl(ADDRESS, scheduledExecutorService, 100, mockPagingManager, realJournalStorageManager, inMemoryFileFactory, mockPageStoreFactory, ADDRESS, settings, executorFactory.getExecutor(), false, () -> true) {
          @Override
          protected PageTimedWriter createPageTimedWriter(ScheduledExecutorService scheduledExecutor, long syncTimeout) {
 
@@ -284,7 +291,8 @@ public class PageTimedWriterUnitTest extends ArtemisTestCase {
             }
 
             if (!pageStore.getExecutor().inHandler()) {
-               logger.warn("WHAT????", new Exception("trace"));
+               logger.warn("directWritePage is not using the correct executor", new Exception("trace"));
+               outOfContextWrite.incrementAndGet();
             }
             super.directWritePage(pagedMessage, lineUp, originalReplicated);
          }
@@ -926,8 +934,6 @@ public class PageTimedWriterUnitTest extends ArtemisTestCase {
 
    @Test
    public void testLockWhileFlowControlled() throws Exception {
-      AtomicBoolean notSupposedToWrite = new AtomicBoolean(false);
-
       AtomicInteger errors = new AtomicInteger(0);
 
       LinkedHashSet<String> interceptedWrite = new LinkedHashSet<>();
@@ -939,10 +945,6 @@ public class PageTimedWriterUnitTest extends ArtemisTestCase {
             logger.warn("no messageID defined on message");
             errors.incrementAndGet();
          }
-         if (notSupposedToWrite.get()) {
-            logger.warn("Not supposed to write message {}", m.getMessage().getStringProperty("testId"));
-            errors.incrementAndGet();
-         }
          interceptedWrite.add(m.getMessage().getStringProperty("testId"));
       };
 
