@@ -1,12 +1,12 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with
+ * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
+ * the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,9 +16,11 @@
  */
 package org.apache.activemq.artemis.tests.unit.core.util;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 import org.apache.activemq.artemis.utils.RandomUtil;
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class RandomUtilTest {
 
@@ -26,14 +28,14 @@ public class RandomUtilTest {
    @Test
    public void testInterval() {
       int i = RandomUtil.randomInterval(0, 1000);
-      Assert.assertTrue(i <= 1000);
-      Assert.assertTrue(i >= 0);
+      assertTrue(i <= 1000);
+      assertTrue(i >= 0);
 
       i = RandomUtil.randomInterval(0, 0);
-      Assert.assertEquals(0, i);
+      assertEquals(0, i);
 
       i = RandomUtil.randomInterval(10, 10);
-      Assert.assertEquals(10, i);
+      assertEquals(10, i);
 
    }
 }
