@@ -16,20 +16,15 @@
  */
 package org.apache.activemq.artemis.tests.unit.util;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
-
 import java.lang.invoke.MethodHandles;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Map;
 import java.util.NoSuchElementException;
+import java.util.Set;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.CyclicBarrier;
 import java.util.concurrent.ExecutorService;
@@ -48,6 +43,13 @@ import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+
 public class LinkedListTest extends ActiveMQTestBase {
 
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
@@ -158,12 +160,68 @@ public class LinkedListTest extends ActiveMQTestBase {
       }
    }
 
+   @Test
+   public void testDuplicateSorted() {
+      list.addSorted(1);
+      list.addSorted(2);
+      list.addSorted(1);
+
+      try (LinkedListIterator<Integer> listIterator = list.iterator()) {
+         assertEquals(1, listIterator.next().intValue());
+         assertEquals(1, listIterator.next().intValue());
+         assertEquals(2, listIterator.next().intValue());
+      }
+
+      list.clear();
+
+      list.addSorted(10);
+      list.addSorted(2);
+      list.addSorted(1);
+      list.addSorted(2);
+
+      try (LinkedListIterator<Integer> listIterator = list.iterator()) {
+         assertEquals(1, listIterator.next().intValue());
+         assertEquals(2, listIterator.next().intValue());
+         assertEquals(2, listIterator.next().intValue());
+         assertEquals(10, listIterator.next().intValue());
+      }
+
+   }
+
+   @Test
+   public void testDuplicateScan() {
+      list.addSorted(0);
+      list.addSorted(1);
+      list.addSorted(2);
+      list.addSorted(3);
+
+      try (LinkedListIterator<Integer> listIterator = list.iterator()) {
+         assertEquals(0, listIterator.next().intValue());
+         assertEquals(1, listIterator.next().intValue());
+         assertEquals(2, listIterator.next().intValue());
+         assertEquals(3, listIterator.next().intValue());
+         // removing an element to clear the lastAdded element from the List
+         assertEquals(3, listIterator.removeLastElement().intValue());
+      }
+
+      scans = 0;
+      list.addSorted(1);
+      assertEquals(1, scans, "The test expects a scan to be made");
+
+      try (LinkedListIterator<Integer> listIterator = list.iterator()) {
+         assertEquals(0, listIterator.next().intValue());
+         assertEquals(1, listIterator.next().intValue());
+         assertEquals(1, listIterator.next().intValue());
+         assertEquals(2, listIterator.next().intValue());
+      }
+   }
+
    @Test
    public void randomSorted() {
 
       int elements = 10_000;
 
-      HashSet<Integer> values = new HashSet<>();
+      Set<Integer> values = new HashSet<>();
       for (int i = 0; i < elements; i++) {
          for (;;) { // a retry loop, if a random give me the same value twice, I would retry
             int value = RandomUtil.randomInt();
@@ -186,7 +244,7 @@ public class LinkedListTest extends ActiveMQTestBase {
 
    }
 
-   private void validateOrder(HashSet<Integer> values) {
+   private void validateOrder(Set<Integer> values) {
       Integer previous = null;
       LinkedListIterator<Integer> integerIterator = list.iterator();
       while (integerIterator.hasNext()) {
@@ -228,7 +286,7 @@ public class LinkedListTest extends ActiveMQTestBase {
       // this is for serverID = null;
       LongObjectHashMap<LinkedListImpl.Node<ObservableNode>> nodeLongObjectHashMap = new LongObjectHashMap<>();
 
-      HashMap<Object, LongObjectHashMap<LinkedListImpl.Node<ObservableNode>>> mapList = new HashMap<>();
+      Map<Object, LongObjectHashMap<LinkedListImpl.Node<ObservableNode>>> mapList = new HashMap<>();
 
       @Override
       public void storeNode(ObservableNode element, LinkedListImpl.Node<ObservableNode> node) {
@@ -378,7 +436,7 @@ public class LinkedListTest extends ActiveMQTestBase {
 
          assertEquals(1000, nodeStore.size());
 
-         /** remove all even items */
+         // remove all even items
          for (int i = 1; i <= 1000; i += 2) {
             objs.removeWithID(serverID, i);
          }
@@ -417,7 +475,7 @@ public class LinkedListTest extends ActiveMQTestBase {
          LinkedListImpl<ObservableNode> objs = new LinkedListImpl<>();
          ListNodeStore nodeStore = new ListNodeStore();
          objs.setNodeStore(nodeStore);
-         final String serverID = RandomUtil.randomString();
+         final String serverID = RandomUtil.randomUUIDString();
 
          for (int i = 0; i < elements; i++) {
             objs.addHead(new ObservableNode(serverID, i));
@@ -767,9 +825,6 @@ public class LinkedListTest extends ActiveMQTestBase {
       assertNoSuchElementIsThrown(iter);
    }
 
-   /**
-    * @param iter
-    */
    private void assertNoSuchElementIsThrown(LinkedListIterator<Integer> iter) {
       try {
          iter.next();
